<?php
namespace WSCOMUN\AEAT\IRPF;

use Exception;
use SoapVar;
use ArrayObject;
use stdClass;


const unbounded = 'unbounded';


class objSolicitudTransmision
{
	/**
	 * Contantes para los NS
	 */
	private static $NAMESPACE_ESP  = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	private static $NAMESPACE_PET  = 'http://intermediacion.redsara.es/scsp/esquemas/V3/peticion';
	private static $NAMESPACE_SR   = 'http://intermediacion.redsara.es/scsp/esquemas/V3/solicitudRespuesta';
	private static $NAMESPACE_RESP = 'http://intermediacion.redsara.es/scsp/esquemas/V3/respuesta';

	/**
	 * @var String
	 * Nif del Emisor
	 */
	private $nifEmisor = null;

	/**
	 * @var String
	 * Nombre o razn social del emisor
	 */
	private $nombreEmisor = null;

	/**
	 * @var String
	 * Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $codProcedimiento = null;

	/**
	 * @var String
	 * Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $nombreProcedimiento = null;

	/**
	 * @var String
	 * Nombre completo del empleado pblico que realiza la solicitud.
	 */
	private $nombreCompletoFuncionario = null;

	/**
	 * @var String
	 * NIF del empleado pblico que realiza la solicitud.
	 */
	private $nifFuncionario = null;

	/**
	 * @var String
	 * Documentacin identificativa del titular. Puede ser: NIF, NIE, CIF
	 */
	private $tipoDocumentacion = null;

	/**
	 * @var String
	 * Nmero de documento segn el <TipoDocumentacion>
	 */
	private $documentacion = null;

	/**
	 * @var String
	 * Nombre completo del titular de la solicitud
	 */
	private $nombreCompleto = null;

	/**
	 * @var String
	 * Nombre del titular de la solicitud
	 */
	private $nombre = null;

	/**
	 * @var String
	 * Primer Apellido del titular de la solicitud
	 */
	private $apellido1 = null;

	/**
	 * @var String
	 * Segundo Apellido del titular de la solicitud
	 */
	private $apellido2 = null;

	/**
	 * @var String
	 * NIF del organismo
	 */
	private $identificadorSolicitante = null;

	/**
	 * @var String
	 * Nombre o razn social del organismo
	 */
	private $nombreSolicitante = null;

	/**
	 * @var String
	 * Nombre de la Unidad Tramitadora que realiza la peticin
	 */
	private $unidadTramitadora = null;

	/**
	 * @var String
	 * Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 */
	private $finalidad = null;

	/**
	 * @var String
	 * Valores admitidos: Si, Ley
	 */
	private $consentimiento = null;

	/**
	 * @var String
	 * Identificador del Expediente que justifica la consulta.
	 */
	private $idExpediente = null;

	/**
	 * @var int
	 * Ao fiscal sobre el que se realiza la consulta
	 */
	private $ejercicio = null;

	/**
	 * @var DatosEspecificos
	 * Datos especficos de la peticion
	 */
	private $oEspecifico = null;



	/**
	 * Establece los datos del ejercicio fiscal a consultar
	 *
	 * @access	public
	 * @param int $ejercicio Ao fiscal sobre el que se realiza la consulta
	 */
	public function setEjercicio($ejercicio) {
		$this->ejercicio = $ejercicio;
	}

	/**
	 * Establece los datos del organismo emisor que ofrece el servicio.
	 *
	 * @access	public
	 * @param String $nif Nif del Emisor
	 * @param String $nombre Nombre o razn social del emisor
	 */
	public function setEmisor($nif, $nombre) {
		$this->nifEmisor = $nif;
		$this->nombreEmisor = $nombre;
	}

	/**
	 * Establece los datos del procedimiento que autoriza la consulta.
	 *
	 * @access	public
	 * @param String $codigo Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 * @param String $nombre Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	public function setProcedimiento($codigo, $nombre) {
		$this->codProcedimiento = $codigo;
		$this->nombreProcedimiento = $nombre;
	}

	/**
	 * Establece los datos del empleado pblico que realiza la solicitud.
	 *
	 * @access	public
	 * @param String $nombreCompleto Nombre completo del empleado pblico que realiza la solicitud.
	 * @param String $nif NIF del empleado pblico que realiza la solicitud.
	 */
	public function setFuncionario($nombreCompleto, $nif) {
		$this->nombreCompletoFuncionario = $nombreCompleto;
		$this->nifFuncionario = $nif;
	}

	/**
	 * Establece los datos del ciudadano sobre el que se va a realizar la consulta.
	 *
	 * @access	public
	 * @param String $tipoDocumentacion Documentacin identificativa del titular. Puede ser: NIF, NIE, CIF
	 * @param String $documentacion Nmero de documento segn el tipo de documentacin indicado.
	 * @param String $nombreCompleto Nombre completo del titular de la solicitud
	 * @param String $nombre Nombre del titular de la solicitud
	 * @param String $apellido1 Primer Apellido del titular de la solicitud
	 * @param String $apellido2 Segundo Apellido del titular de la solicitud
	 */
	public function setTitular($tipoDocumentacion, $documentacion, $nombreCompleto = null, $nombre = null, $apellido1 = null, $apellido2 = null) {
		$this->tipoDocumentacion = $tipoDocumentacion;
		$this->documentacion = $documentacion;
		$this->nombreCompleto = $nombreCompleto;
		$this->nombre = $nombre;
		$this->apellido1 = $apellido1;
		$this->apellido2 = $apellido2;
	}

	/**
	 * Establece los datos del solicitante de la transmisin, as como la finalidad del mismo.
	 *
	 * @access	public
	 * @param String $identificadorSolicitante NIF del organismo solicitante
	 * @param String $nombreSolicitante Nombre o razn social del organismo solicitante
	 * @param String $consentimiento Valores admitidos: Si, Ley
	 * @param String $finalidad Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 * @param String $unidadTramitadora Nombre de la Unidad Tramitadora que realiza la peticin
	 * @param String $idExpediente Identificador del Expediente que justifica la consulta.
	 */
	public function setSolicitante($identificadorSolicitante, $nombreSolicitante, $consentimiento, $finalidad, $unidadTramitadora = null, $idExpediente = null) {
		$this->identificadorSolicitante = $identificadorSolicitante;
		$this->nombreSolicitante = $nombreSolicitante;
		$this->consentimiento = $consentimiento;
		$this->finalidad = $finalidad;
		$this->unidadTramitadora = $unidadTramitadora;
		$this->idExpediente = $idExpediente;
	}


	/**
	 * Establece los datos especificos de la peticin.
	 *
	 * @access	public
	 * @param DatosEspecificos $oEspecifico Datos especficos de la consulta
	 */
	public function setEspecifico($oEspecifico) {
		$this->oEspecifico = $oEspecifico;
	}


	/**
	 * Devuelve una copia del objeto, que mantiene los datos generales de la peticin: Emisor, procedimiento, funcionario, titular y solicitante
	 *
	 * @access	public
	 * @return	objSolicitudTransmision	Nueva instancia con los datos copiados
	 */
	public function duplicarCabecera() {
		$oClon = new objSolicitudTransmision();
		$oClon->setEmisor($this->nifEmisor, $this->nombreEmisor);
		$oClon->setProcedimiento($this->codProcedimiento, $this->nombreProcedimiento);
		$oClon->setFuncionario($this->nombreCompletoFuncionario, $this->nifFuncionario);
		$oClon->setTitular($this->tipoDocumentacion, $this->documentacion, $this->nombreCompleto, $this->nombre, $this->apellido1, $this->apellido2);
		$oClon->setSolicitante($this->identificadorSolicitante, $this->nombreSolicitante, $this->consentimiento, $this->finalidad, $this->unidadTramitadora, $this->idExpediente);

		return $oClon;
	}


	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @access 	public
	 * @param string $IdPeticion Identificador de la peticin
	 * @param string $CodigoCertificado Cdigo del certificado del servicio que solicita la peticion
	 * @param string $numParcial Subidentificador de la peticin. Cuando se suministra, se concatena al identificador de la peticion.
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 */
	public function toSoap($IdPeticion, $CodigoCertificado, $numParcial = null)
	{
		$IdSolicitud = $IdPeticion;
		if (!is_null($numParcial)) {
			$IdSolicitud = $IdPeticion . '_' . $numParcial;
		}

		// $CodigoCertificado debera ser auto-generado
		// IdentificadorSolicitante = (Sugerido) CODxxxxxx
		// Consentimiento = Si | Ley
		// TipoDocumentacion = NIF | CIF | DNI | Pasaporte | NIE

		// Emisor
		$EmisorWSRequest = new ArrayObject();
		$EmisorWSRequest->append(new SoapVar($this->nifEmisor, XSD_STRING, null, null,'NifEmisor', self::$NAMESPACE_PET));
		$EmisorWSRequest->append(new SoapVar($this->nombreEmisor, XSD_STRING, null, null,'NombreEmisor', self::$NAMESPACE_PET));

		// Procedimiento
		$ProcedimientoWSRequest = new ArrayObject();
		$ProcedimientoWSRequest->append(new SoapVar($this->codProcedimiento, XSD_STRING, null, null,'CodProcedimiento', self::$NAMESPACE_PET));
		$ProcedimientoWSRequest->append(new SoapVar($this->nombreProcedimiento, XSD_STRING, null, null,'NombreProcedimiento', self::$NAMESPACE_PET));

		// Funcionario
		$FuncionarioWSRequest = new ArrayObject();
		$FuncionarioWSRequest->append(new SoapVar($this->nombreCompletoFuncionario, XSD_STRING, null, null,'NombreCompletoFuncionario', self::$NAMESPACE_PET));
		$FuncionarioWSRequest->append(new SoapVar($this->nifFuncionario, XSD_STRING, null, null,'NifFuncionario', self::$NAMESPACE_PET));

		// Solicitante
		$SolicitanteWSRequest = new ArrayObject();
		$SolicitanteWSRequest->append(new SoapVar($this->identificadorSolicitante, XSD_STRING, null, null,'IdentificadorSolicitante', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->nombreSolicitante, XSD_STRING, null, null,'NombreSolicitante', self::$NAMESPACE_PET));
		if (!is_null($this->unidadTramitadora)) {
			$SolicitanteWSRequest->append(new SoapVar($this->unidadTramitadora, XSD_STRING, null, null,'UnidadTramitadora', self::$NAMESPACE_PET));
		}
		$SolicitanteWSRequest->append(new SoapVar($ProcedimientoWSRequest, SOAP_ENC_OBJECT,null,null,'Procedimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->finalidad, XSD_STRING, null, null,'Finalidad', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->consentimiento, XSD_STRING, null, null,'Consentimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($FuncionarioWSRequest, SOAP_ENC_OBJECT,null,null,'Funcionario', self::$NAMESPACE_PET));
		if (!is_null($this->idExpediente)) {
			$SolicitanteWSRequest->append(new SoapVar($this->idExpediente, XSD_STRING, null, null,'IdExpediente', self::$NAMESPACE_PET));
		}

		// Titular
		$TitularWSRequest = new ArrayObject();
		$TitularWSRequest->append(new SoapVar($this->tipoDocumentacion, XSD_STRING, null, null,'TipoDocumentacion', self::$NAMESPACE_PET));
		$TitularWSRequest->append(new SoapVar($this->documentacion, XSD_STRING, null, null,'Documentacion', self::$NAMESPACE_PET));
		if (!is_null($this->nombreCompleto)) {
			$TitularWSRequest->append(new SoapVar($this->nombreCompleto, XSD_STRING, null, null,'NombreCompleto', self::$NAMESPACE_PET));
		}
		if (!is_null($this->nombre)) {
			$TitularWSRequest->append(new SoapVar($this->nombre, XSD_STRING, null, null,'Nombre', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido1)) {
			$TitularWSRequest->append(new SoapVar($this->apellido1, XSD_STRING, null, null,'Apellido1', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido2)) {
			$TitularWSRequest->append(new SoapVar($this->apellido2, XSD_STRING, null, null,'Apellido2', self::$NAMESPACE_PET));
		}

		// Transmision
		$TransmisionWSRequest = new ArrayObject();
		$TransmisionWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_PET));
		$TransmisionWSRequest->append(new SoapVar($IdSolicitud, XSD_STRING, null, null,'IdSolicitud', self::$NAMESPACE_PET));

		// DatosGenericos
		$DatosGenericosWSRequest = new ArrayObject();
		$DatosGenericosWSRequest->append(new SoapVar($EmisorWSRequest, SOAP_ENC_OBJECT,null,null,'Emisor', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($SolicitanteWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitante', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TitularWSRequest, SOAP_ENC_OBJECT,null,null,'Titular', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'Transmision', self::$NAMESPACE_PET));

		// DatosGenericos
		$DatosEspecificosWSRequest = new ArrayObject();
		$DatosEspecificosWSRequest->append(new SoapVar($this->ejercicio, XSD_INTEGER, null, null,'Ejercicio', self::$NAMESPACE_ESP));

		// SolicitudTransmision
		$SolicitudTransmisionWSRequest = new ArrayObject();
		$SolicitudTransmisionWSRequest->append(new SoapVar($DatosGenericosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosGenericos', self::$NAMESPACE_PET));
		$SolicitudTransmisionWSRequest->append(new SoapVar($DatosEspecificosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosEspecificos', self::$NAMESPACE_ESP));

		// Devuelve la solicitud ya generada
		return new SoapVar($SolicitudTransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudTransmision', self::$NAMESPACE_PET);
	}

}


class SoapObject
{
	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new \stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array


	private function __anyType_SoapVar($childData, $fieldName, $namespace) {
		//var_dump($childData);
		if (is_a($childData, 'DateTime')) {
			//var_dump($childData);
			//die('DateTime: ' . $fieldName);
			return new \SoapVar($childData->format(\DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		} elseif (is_int($childData)) {
			//die('Integer: ' . $fieldName);
			return new \SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}

		//die('Generic: ' . $fieldName);
		return new \SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}

	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace) {
		switch ($basicType) {
			case XSD_DATETIME:
				return new \SoapVar($childData->format(\DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);

			default:
				return new \SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $value, $fieldName, $type, $namespace, $minOccurs, $maxOccurs)
	{
		//echo("__doChild: $type [$fieldName]<br>");
		$fieldSet = isset($value);
		if (!$fieldSet) {
			if ($minOccurs > 0) {
				throw new \Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			} else {
				return true;
			}
		}

		$vChildData = $value;
		if ($maxOccurs == 1) {
			$vChildData = array( $value );
		} else {
			if ($maxOccurs != 'unbounded') {
				if ($maxOccurs > sizeof($vChildData)) {
					throw new \Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			} else {
				//				var_dump($vChildData);die;
			}
		}

		//var_dump(array_keys($vChildData));
		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++) {
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet) {
				if (is_int($type) && $type != SOAP_ENC_OBJECT) {

					$basicType = $type;
					//echo("Basic: $type | $basicType [$fieldName]<br>");
					if ($basicType !== XSD_ANYTYPE) {
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					} else {
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append( $childSOAP );
					//					return true;

				} else { //if (isset($this->$funcName)) {
					$childSOAP = $childData->toSoap($fieldName, $namespace);
					$parentTag->append( $childSOAP );
					//					return true;
				}
			} else {
				return false;
			}

		}

		// TODO: HACER EL MULTIAPARICION!!!
		/*
		 var_dump($parentTag);
		 var_dump($vData);
		 var_dump($fieldName);
		 var_dump($type);
		 var_dump($namespace);
		 var_dump($minOccurs);
		 var_dump($maxOccurs);

		 die("FAIL!!!");
		 */

		return true;
	}



	static public function is_assoc($array) {
		foreach(array_keys($array) as $key) {
			if (!is_int($key)) return true;
		}
		return false;
	}

	static public function endsWith($haystack, $needle) {
		// search forward starting from end minus needle length characters
		return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
	}
}









class Cabecera extends SoapObject {


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="CodRet" type="134"[134] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_codRet = null;
	private $_hasCodRet = false;
	public function setCodRet($value) {
		$this->_codRet = $value;
		$this->_hasCodRet = ($value !== null);
	}
	public function hasCodRet() {
		return $this->_hasCodRet;
	}
	public function getCodRet() {
		return $this->_codRet;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DescripcionError" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_descripcionError = null;
	private $_hasDescripcionError = false;
	public function setDescripcionError($value) {
		$this->_descripcionError = $value;
		$this->_hasDescripcionError = ($value !== null);
	}
	public function hasDescripcionError() {
		return $this->_hasDescripcionError;
	}
	public function getDescripcionError() {
		return $this->_descripcionError;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Referencia" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_referencia = null;
	private $_hasReferencia = false;
	public function setReferencia($value) {
		$this->_referencia = $value;
		$this->_hasReferencia = ($value !== null);
	}
	public function hasReferencia() {
		return $this->_hasReferencia;
	}
	public function getReferencia() {
		return $this->_referencia;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="FechaEmision" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_fechaEmision = null;
	private $_hasFechaEmision = false;
	public function setFechaEmision($value) {
		$this->_fechaEmision = $value;
		$this->_hasFechaEmision = ($value !== null);
	}
	public function hasFechaEmision() {
		return $this->_hasFechaEmision;
	}
	public function getFechaEmision() {
		return $this->_fechaEmision;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Ejercicio" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_ejercicio = null;
	private $_hasEjercicio = false;
	public function setEjercicio($value) {
		$this->_ejercicio = $value;
		$this->_hasEjercicio = ($value !== null);
	}
	public function hasEjercicio() {
		return $this->_hasEjercicio;
	}
	public function getEjercicio() {
		return $this->_ejercicio;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="TipoRespuesta" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_tipoRespuesta = null;
	private $_hasTipoRespuesta = false;
	public function setTipoRespuesta($value) {
		$this->_tipoRespuesta = $value;
		$this->_hasTipoRespuesta = ($value !== null);
	}
	public function hasTipoRespuesta() {
		return $this->_hasTipoRespuesta;
	}
	public function getTipoRespuesta() {
		return $this->_tipoRespuesta;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Cabecera con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Cabecera 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Cabecera();
		if (!isset($vData['CodRet'])) {
			throw new Exception('El parametro CodRet es obligatorio');
		}
		if (isset($vData['CodRet'])) {

			$newItem->setCodRet($vData['CodRet']);
		}
		if (!isset($vData['DescripcionError'])) {
			throw new Exception('El parametro DescripcionError es obligatorio');
		}
		if (isset($vData['DescripcionError'])) {

			$newItem->setDescripcionError($vData['DescripcionError']);
		}
		if (!isset($vData['Referencia'])) {
			throw new Exception('El parametro Referencia es obligatorio');
		}
		if (isset($vData['Referencia'])) {

			$newItem->setReferencia($vData['Referencia']);
		}
		if (!isset($vData['FechaEmision'])) {
			throw new Exception('El parametro FechaEmision es obligatorio');
		}
		if (isset($vData['FechaEmision'])) {

			$newItem->setFechaEmision($vData['FechaEmision']);
		}
		if (!isset($vData['Ejercicio'])) {
			throw new Exception('El parametro Ejercicio es obligatorio');
		}
		if (isset($vData['Ejercicio'])) {

			$newItem->setEjercicio($vData['Ejercicio']);
		}
		if (!isset($vData['TipoRespuesta'])) {
			throw new Exception('El parametro TipoRespuesta es obligatorio');
		}
		if (isset($vData['TipoRespuesta'])) {

			$newItem->setTipoRespuesta($vData['TipoRespuesta']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codRet, 'CodRet', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_descripcionError, 'DescripcionError', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_referencia, 'Referencia', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_fechaEmision, 'FechaEmision', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_ejercicio, 'Ejercicio', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_tipoRespuesta, 'TipoRespuesta', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DatosEconomicos extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DEGrupo" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dEGrupo = null;
	private $_hasDEGrupo = false;
	public function setDEGrupo($value) {
		$this->_dEGrupo = $value;
		$this->_hasDEGrupo = ($value !== null);
	}
	public function hasDEGrupo() {
		return $this->_hasDEGrupo;
	}
	public function getDEGrupo() {
		return $this->_dEGrupo;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="DECasilla" type="134"[134] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_dECasilla = null;
	private $_hasDECasilla = false;
	public function setDECasilla($value) {
		$this->_dECasilla = $value;
		$this->_hasDECasilla = ($value !== null);
	}
	public function hasDECasilla() {
		return $this->_hasDECasilla;
	}
	public function getDECasilla() {
		return $this->_dECasilla;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DESigno" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dESigno = null;
	private $_hasDESigno = false;
	public function setDESigno($value) {
		$this->_dESigno = $value;
		$this->_hasDESigno = ($value !== null);
	}
	public function hasDESigno() {
		return $this->_hasDESigno;
	}
	public function getDESigno() {
		return $this->_dESigno;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="DEEnteros" type="134"[134] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_dEEnteros = null;
	private $_hasDEEnteros = false;
	public function setDEEnteros($value) {
		$this->_dEEnteros = $value;
		$this->_hasDEEnteros = ($value !== null);
	}
	public function hasDEEnteros() {
		return $this->_hasDEEnteros;
	}
	public function getDEEnteros() {
		return $this->_dEEnteros;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="DEDecimales" type="134"[134] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_dEDecimales = null;
	private $_hasDEDecimales = false;
	public function setDEDecimales($value) {
		$this->_dEDecimales = $value;
		$this->_hasDEDecimales = ($value !== null);
	}
	public function hasDEDecimales() {
		return $this->_hasDEDecimales;
	}
	public function getDEDecimales() {
		return $this->_dEDecimales;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DatosEconomicos con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DatosEconomicos 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DatosEconomicos();
		if (isset($vData['DEGrupo'])) {

			$newItem->setDEGrupo($vData['DEGrupo']);
		}
		if (!isset($vData['DECasilla'])) {
			throw new Exception('El parametro DECasilla es obligatorio');
		}
		if (isset($vData['DECasilla'])) {

			$newItem->setDECasilla($vData['DECasilla']);
		}
		if (isset($vData['DESigno'])) {

			$newItem->setDESigno($vData['DESigno']);
		}
		if (!isset($vData['DEEnteros'])) {
			throw new Exception('El parametro DEEnteros es obligatorio');
		}
		if (isset($vData['DEEnteros'])) {

			$newItem->setDEEnteros($vData['DEEnteros']);
		}
		if (!isset($vData['DEDecimales'])) {
			throw new Exception('El parametro DEDecimales es obligatorio');
		}
		if (isset($vData['DEDecimales'])) {

			$newItem->setDEDecimales($vData['DEDecimales']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dEGrupo, 'DEGrupo', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dECasilla, 'DECasilla', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_dESigno, 'DESigno', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dEEnteros, 'DEEnteros', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_dEDecimales, 'DEDecimales', 134, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class Imputaciones extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Cabecera" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_cabecera = null;
	private $_hasCabecera = false;
	public function setCabecera($value) {
		$this->_cabecera = $value;
		$this->_hasCabecera = ($value !== null);
	}
	public function hasCabecera() {
		return $this->_hasCabecera;
	}
	public function getCabecera() {
		return $this->_cabecera;
	}

	/**
	 * @var DatosEconomicos Propiedad de navegacion entre objetos SOAP
	 * name="DatosEconomicos" type="DatosEconomicos"[COMPLEXTYPE] minOccurs="0" maxOccurs="100" nillable="false"
	 */
	private $_datosEconomicos = array();
	private $_hasDatosEconomicos = false;
	public function replaceArrayDatosEconomicos($value) {
		$this->_datosEconomicos = $value;
		$this->_hasDatosEconomicos = (isset($this->_datosEconomicos) && !empty($this->_datosEconomicos));
	}
	public function retrieveArrayDatosEconomicos() {
		return $this->_datosEconomicos;
	}
	public function addDatosEconomicos($value) {
		array_push($this->_datosEconomicos, $value);
		$this->_hasDatosEconomicos = (isset($this->_datosEconomicos) && !empty($this->_datosEconomicos));
	}
	public function hasDatosEconomicos() {
		return $this->_hasDatosEconomicos;
	}
	public function getDatosEconomicos($index) {
		return $this->_datosEconomicos[$index];
	}
	public function countDatosEconomicos() {
		return count($this->_datosEconomicos);
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Cola" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_cola = null;
	private $_hasCola = false;
	public function setCola($value) {
		$this->_cola = $value;
		$this->_hasCola = ($value !== null);
	}
	public function hasCola() {
		return $this->_hasCola;
	}
	public function getCola() {
		return $this->_cola;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Imputaciones con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Imputaciones 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Imputaciones();
		if (!isset($vData['Cabecera'])) {
			throw new Exception('El parametro Cabecera es obligatorio');
		}
		if (isset($vData['Cabecera'])) {

			$newItem->setCabecera($vData['Cabecera']);
		}
		if (isset($vData['DatosEconomicos']) && !empty($vData['DatosEconomicos'])) {
			if (SoapObject::is_assoc($vData['DatosEconomicos'])) {

				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = DatosEconomicos::fromSoap($vData['DatosEconomicos']);
				$newItem->addDatosEconomicos($newClass);
			} else {

				foreach ($vData['DatosEconomicos'] as $oVar) {
					$newClass = DatosEconomicos::fromSoap($oVar);
					$newItem->addDatosEconomicos($newClass);
				}
			}
		}
		if (isset($vData['Cola'])) {

			$newItem->setCola($vData['Cola']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_cabecera, 'Cabecera', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_datosEconomicos, 'DatosEconomicos', SOAP_ENC_OBJECT, $namespace, 0, 100, false);
		$this->__doChild($myLevel, $this->_cola, 'Cola', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class CabeceraRenta extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="NifSolicitante" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_nifSolicitante = null;
	private $_hasNifSolicitante = false;
	public function setNifSolicitante($value) {
		$this->_nifSolicitante = $value;
		$this->_hasNifSolicitante = ($value !== null);
	}
	public function hasNifSolicitante() {
		return $this->_hasNifSolicitante;
	}
	public function getNifSolicitante() {
		return $this->_nifSolicitante;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="NombreSolicitante" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_nombreSolicitante = null;
	private $_hasNombreSolicitante = false;
	public function setNombreSolicitante($value) {
		$this->_nombreSolicitante = $value;
		$this->_hasNombreSolicitante = ($value !== null);
	}
	public function hasNombreSolicitante() {
		return $this->_hasNombreSolicitante;
	}
	public function getNombreSolicitante() {
		return $this->_nombreSolicitante;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="PrimerDeclarante" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_primerDeclarante = null;
	private $_hasPrimerDeclarante = false;
	public function setPrimerDeclarante($value) {
		$this->_primerDeclarante = $value;
		$this->_hasPrimerDeclarante = ($value !== null);
	}
	public function hasPrimerDeclarante() {
		return $this->_hasPrimerDeclarante;
	}
	public function getPrimerDeclarante() {
		return $this->_primerDeclarante;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="SegundoTitular" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_segundoTitular = null;
	private $_hasSegundoTitular = false;
	public function setSegundoTitular($value) {
		$this->_segundoTitular = $value;
		$this->_hasSegundoTitular = ($value !== null);
	}
	public function hasSegundoTitular() {
		return $this->_hasSegundoTitular;
	}
	public function getSegundoTitular() {
		return $this->_segundoTitular;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Modelo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_modelo = null;
	private $_hasModelo = false;
	public function setModelo($value) {
		$this->_modelo = $value;
		$this->_hasModelo = ($value !== null);
	}
	public function hasModelo() {
		return $this->_hasModelo;
	}
	public function getModelo() {
		return $this->_modelo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Tributacion" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_tributacion = null;
	private $_hasTributacion = false;
	public function setTributacion($value) {
		$this->_tributacion = $value;
		$this->_hasTributacion = ($value !== null);
	}
	public function hasTributacion() {
		return $this->_hasTributacion;
	}
	public function getTributacion() {
		return $this->_tributacion;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="OrigenDatos" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_origenDatos = null;
	private $_hasOrigenDatos = false;
	public function setOrigenDatos($value) {
		$this->_origenDatos = $value;
		$this->_hasOrigenDatos = ($value !== null);
	}
	public function hasOrigenDatos() {
		return $this->_hasOrigenDatos;
	}
	public function getOrigenDatos() {
		return $this->_origenDatos;
	}


	/**
	 *
	 * Devuelve una instancia de la clase CabeceraRenta con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	CabeceraRenta 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new CabeceraRenta();
		if (!isset($vData['NifSolicitante'])) {
			throw new Exception('El parametro NifSolicitante es obligatorio');
		}
		if (isset($vData['NifSolicitante'])) {

			$newItem->setNifSolicitante($vData['NifSolicitante']);
		}
		if (!isset($vData['NombreSolicitante'])) {
			throw new Exception('El parametro NombreSolicitante es obligatorio');
		}
		if (isset($vData['NombreSolicitante'])) {

			$newItem->setNombreSolicitante($vData['NombreSolicitante']);
		}
		if (!isset($vData['PrimerDeclarante'])) {
			throw new Exception('El parametro PrimerDeclarante es obligatorio');
		}
		if (isset($vData['PrimerDeclarante'])) {

			$newItem->setPrimerDeclarante($vData['PrimerDeclarante']);
		}
		if (isset($vData['SegundoTitular'])) {

			$newItem->setSegundoTitular($vData['SegundoTitular']);
		}
		if (!isset($vData['Modelo'])) {
			throw new Exception('El parametro Modelo es obligatorio');
		}
		if (isset($vData['Modelo'])) {

			$newItem->setModelo($vData['Modelo']);
		}
		if (!isset($vData['Tributacion'])) {
			throw new Exception('El parametro Tributacion es obligatorio');
		}
		if (isset($vData['Tributacion'])) {

			$newItem->setTributacion($vData['Tributacion']);
		}
		if (!isset($vData['OrigenDatos'])) {
			throw new Exception('El parametro OrigenDatos es obligatorio');
		}
		if (isset($vData['OrigenDatos'])) {

			$newItem->setOrigenDatos($vData['OrigenDatos']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_nifSolicitante, 'NifSolicitante', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_nombreSolicitante, 'NombreSolicitante', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_primerDeclarante, 'PrimerDeclarante', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_segundoTitular, 'SegundoTitular', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_modelo, 'Modelo', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_tributacion, 'Tributacion', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_origenDatos, 'OrigenDatos', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class OtrosDatos extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="ODDescripcion" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_oDDescripcion = null;
	private $_hasODDescripcion = false;
	public function setODDescripcion($value) {
		$this->_oDDescripcion = $value;
		$this->_hasODDescripcion = ($value !== null);
	}
	public function hasODDescripcion() {
		return $this->_hasODDescripcion;
	}
	public function getODDescripcion() {
		return $this->_oDDescripcion;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="ODSigno" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_oDSigno = null;
	private $_hasODSigno = false;
	public function setODSigno($value) {
		$this->_oDSigno = $value;
		$this->_hasODSigno = ($value !== null);
	}
	public function hasODSigno() {
		return $this->_hasODSigno;
	}
	public function getODSigno() {
		return $this->_oDSigno;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="ODEnteros" type="134"[134] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_oDEnteros = null;
	private $_hasODEnteros = false;
	public function setODEnteros($value) {
		$this->_oDEnteros = $value;
		$this->_hasODEnteros = ($value !== null);
	}
	public function hasODEnteros() {
		return $this->_hasODEnteros;
	}
	public function getODEnteros() {
		return $this->_oDEnteros;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="ODDecimales" type="134"[134] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_oDDecimales = null;
	private $_hasODDecimales = false;
	public function setODDecimales($value) {
		$this->_oDDecimales = $value;
		$this->_hasODDecimales = ($value !== null);
	}
	public function hasODDecimales() {
		return $this->_hasODDecimales;
	}
	public function getODDecimales() {
		return $this->_oDDecimales;
	}


	/**
	 *
	 * Devuelve una instancia de la clase OtrosDatos con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	OtrosDatos 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new OtrosDatos();
		if (!isset($vData['ODDescripcion'])) {
			throw new Exception('El parametro ODDescripcion es obligatorio');
		}
		if (isset($vData['ODDescripcion'])) {

			$newItem->setODDescripcion($vData['ODDescripcion']);
		}
		if (isset($vData['ODSigno'])) {

			$newItem->setODSigno($vData['ODSigno']);
		}
		if (!isset($vData['ODEnteros'])) {
			throw new Exception('El parametro ODEnteros es obligatorio');
		}
		if (isset($vData['ODEnteros'])) {

			$newItem->setODEnteros($vData['ODEnteros']);
		}
		if (!isset($vData['ODDecimales'])) {
			throw new Exception('El parametro ODDecimales es obligatorio');
		}
		if (isset($vData['ODDecimales'])) {

			$newItem->setODDecimales($vData['ODDecimales']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_oDDescripcion, 'ODDescripcion', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_oDSigno, 'ODSigno', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_oDEnteros, 'ODEnteros', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_oDDecimales, 'ODDecimales', 134, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCEstadoCivil extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCFecha" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_dCFecha = null;
	private $_hasDCFecha = false;
	public function setDCFecha($value) {
		$this->_dCFecha = $value;
		$this->_hasDCFecha = ($value !== null);
	}
	public function hasDCFecha() {
		return $this->_hasDCFecha;
	}
	public function getDCFecha() {
		return $this->_dCFecha;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCContenido" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_dCContenido = null;
	private $_hasDCContenido = false;
	public function setDCContenido($value) {
		$this->_dCContenido = $value;
		$this->_hasDCContenido = ($value !== null);
	}
	public function hasDCContenido() {
		return $this->_hasDCContenido;
	}
	public function getDCContenido() {
		return $this->_dCContenido;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCEstadoCivil con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCEstadoCivil 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCEstadoCivil();
		if (!isset($vData['DCFecha'])) {
			throw new Exception('El parametro DCFecha es obligatorio');
		}
		if (isset($vData['DCFecha'])) {

			$newItem->setDCFecha($vData['DCFecha']);
		}
		if (!isset($vData['DCContenido'])) {
			throw new Exception('El parametro DCContenido es obligatorio');
		}
		if (isset($vData['DCContenido'])) {

			$newItem->setDCContenido($vData['DCContenido']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCFecha, 'DCFecha', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_dCContenido, 'DCContenido', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCDatosPersonales extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCLiteral" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCLiteral = null;
	private $_hasDCLiteral = false;
	public function setDCLiteral($value) {
		$this->_dCLiteral = $value;
		$this->_hasDCLiteral = ($value !== null);
	}
	public function hasDCLiteral() {
		return $this->_hasDCLiteral;
	}
	public function getDCLiteral() {
		return $this->_dCLiteral;
	}


	/**
	 * @var DCEstadoCivil Propiedad de navegacion entre objetos SOAP
	 * name="DCEstadoCivil" type="DCEstadoCivil"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCEstadoCivil = null;
	private $_hasDCEstadoCivil = false;
	public function setDCEstadoCivil($value) {
		$this->_dCEstadoCivil = $value;
		$this->_hasDCEstadoCivil = ($value !== null);
	}
	public function hasDCEstadoCivil() {
		return $this->_hasDCEstadoCivil;
	}
	public function getDCEstadoCivil() {
		return $this->_dCEstadoCivil;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCFechaNac" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCFechaNac = null;
	private $_hasDCFechaNac = false;
	public function setDCFechaNac($value) {
		$this->_dCFechaNac = $value;
		$this->_hasDCFechaNac = ($value !== null);
	}
	public function hasDCFechaNac() {
		return $this->_hasDCFechaNac;
	}
	public function getDCFechaNac() {
		return $this->_dCFechaNac;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCMinusvalia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCMinusvalia = null;
	private $_hasDCMinusvalia = false;
	public function setDCMinusvalia($value) {
		$this->_dCMinusvalia = $value;
		$this->_hasDCMinusvalia = ($value !== null);
	}
	public function hasDCMinusvalia() {
		return $this->_hasDCMinusvalia;
	}
	public function getDCMinusvalia() {
		return $this->_dCMinusvalia;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCDatosPersonales con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCDatosPersonales 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCDatosPersonales();
		if (isset($vData['DCLiteral'])) {

			$newItem->setDCLiteral($vData['DCLiteral']);
		}
		if (isset($vData['DCEstadoCivil'])) {

			$newClass = DCEstadoCivil::fromSoap($vData['DCEstadoCivil']);
			$newItem->setDCEstadoCivil($newClass);
		}
		if (isset($vData['DCFechaNac'])) {

			$newItem->setDCFechaNac($vData['DCFechaNac']);
		}
		if (isset($vData['DCMinusvalia'])) {

			$newItem->setDCMinusvalia($vData['DCMinusvalia']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCLiteral, 'DCLiteral', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCEstadoCivil, 'DCEstadoCivil', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCFechaNac, 'DCFechaNac', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCMinusvalia, 'DCMinusvalia', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCDatosConyuge extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCLiteral" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCLiteral = null;
	private $_hasDCLiteral = false;
	public function setDCLiteral($value) {
		$this->_dCLiteral = $value;
		$this->_hasDCLiteral = ($value !== null);
	}
	public function hasDCLiteral() {
		return $this->_hasDCLiteral;
	}
	public function getDCLiteral() {
		return $this->_dCLiteral;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCFechaNac" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCFechaNac = null;
	private $_hasDCFechaNac = false;
	public function setDCFechaNac($value) {
		$this->_dCFechaNac = $value;
		$this->_hasDCFechaNac = ($value !== null);
	}
	public function hasDCFechaNac() {
		return $this->_hasDCFechaNac;
	}
	public function getDCFechaNac() {
		return $this->_dCFechaNac;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCMinusvalia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCMinusvalia = null;
	private $_hasDCMinusvalia = false;
	public function setDCMinusvalia($value) {
		$this->_dCMinusvalia = $value;
		$this->_hasDCMinusvalia = ($value !== null);
	}
	public function hasDCMinusvalia() {
		return $this->_hasDCMinusvalia;
	}
	public function getDCMinusvalia() {
		return $this->_dCMinusvalia;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCDatosConyuge con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCDatosConyuge 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCDatosConyuge();
		if (isset($vData['DCLiteral'])) {

			$newItem->setDCLiteral($vData['DCLiteral']);
		}
		if (isset($vData['DCFechaNac'])) {

			$newItem->setDCFechaNac($vData['DCFechaNac']);
		}
		if (isset($vData['DCMinusvalia'])) {

			$newItem->setDCMinusvalia($vData['DCMinusvalia']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCLiteral, 'DCLiteral', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCFechaNac, 'DCFechaNac', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCMinusvalia, 'DCMinusvalia', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCNumHijos extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCNombreHijo" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCNombreHijo = null;
	private $_hasDCNombreHijo = false;
	public function setDCNombreHijo($value) {
		$this->_dCNombreHijo = $value;
		$this->_hasDCNombreHijo = ($value !== null);
	}
	public function hasDCNombreHijo() {
		return $this->_hasDCNombreHijo;
	}
	public function getDCNombreHijo() {
		return $this->_dCNombreHijo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCFechaNacim" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCFechaNacim = null;
	private $_hasDCFechaNacim = false;
	public function setDCFechaNacim($value) {
		$this->_dCFechaNacim = $value;
		$this->_hasDCFechaNacim = ($value !== null);
	}
	public function hasDCFechaNacim() {
		return $this->_hasDCFechaNacim;
	}
	public function getDCFechaNacim() {
		return $this->_dCFechaNacim;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCFechaAdopc" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCFechaAdopc = null;
	private $_hasDCFechaAdopc = false;
	public function setDCFechaAdopc($value) {
		$this->_dCFechaAdopc = $value;
		$this->_hasDCFechaAdopc = ($value !== null);
	}
	public function hasDCFechaAdopc() {
		return $this->_hasDCFechaAdopc;
	}
	public function getDCFechaAdopc() {
		return $this->_dCFechaAdopc;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCMinusvalia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCMinusvalia = null;
	private $_hasDCMinusvalia = false;
	public function setDCMinusvalia($value) {
		$this->_dCMinusvalia = $value;
		$this->_hasDCMinusvalia = ($value !== null);
	}
	public function hasDCMinusvalia() {
		return $this->_hasDCMinusvalia;
	}
	public function getDCMinusvalia() {
		return $this->_dCMinusvalia;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCVinculacion" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCVinculacion = null;
	private $_hasDCVinculacion = false;
	public function setDCVinculacion($value) {
		$this->_dCVinculacion = $value;
		$this->_hasDCVinculacion = ($value !== null);
	}
	public function hasDCVinculacion() {
		return $this->_hasDCVinculacion;
	}
	public function getDCVinculacion() {
		return $this->_dCVinculacion;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCNumHijos con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCNumHijos 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCNumHijos();
		if (isset($vData['DCNombreHijo'])) {

			$newItem->setDCNombreHijo($vData['DCNombreHijo']);
		}
		if (isset($vData['DCFechaNacim'])) {

			$newItem->setDCFechaNacim($vData['DCFechaNacim']);
		}
		if (isset($vData['DCFechaAdopc'])) {

			$newItem->setDCFechaAdopc($vData['DCFechaAdopc']);
		}
		if (isset($vData['DCMinusvalia'])) {

			$newItem->setDCMinusvalia($vData['DCMinusvalia']);
		}
		if (isset($vData['DCVinculacion'])) {

			$newItem->setDCVinculacion($vData['DCVinculacion']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCNombreHijo, 'DCNombreHijo', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCFechaNacim, 'DCFechaNacim', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCFechaAdopc, 'DCFechaAdopc', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCMinusvalia, 'DCMinusvalia', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCVinculacion, 'DCVinculacion', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCDatosHijos extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCLiteral" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCLiteral = null;
	private $_hasDCLiteral = false;
	public function setDCLiteral($value) {
		$this->_dCLiteral = $value;
		$this->_hasDCLiteral = ($value !== null);
	}
	public function hasDCLiteral() {
		return $this->_hasDCLiteral;
	}
	public function getDCLiteral() {
		return $this->_dCLiteral;
	}

	/**
	 * @var DCNumHijos Propiedad de navegacion entre objetos SOAP
	 * name="DCNumHijos" type="DCNumHijos"[COMPLEXTYPE] minOccurs="0" maxOccurs="15" nillable="false"
	 */
	private $_dCNumHijos = array();
	private $_hasDCNumHijos = false;
	public function replaceArrayDCNumHijos($value) {
		$this->_dCNumHijos = $value;
		$this->_hasDCNumHijos = (isset($this->_dCNumHijos) && !empty($this->_dCNumHijos));
	}
	public function retrieveArrayDCNumHijos() {
		return $this->_dCNumHijos;
	}
	public function addDCNumHijos($value) {
		array_push($this->_dCNumHijos, $value);
		$this->_hasDCNumHijos = (isset($this->_dCNumHijos) && !empty($this->_dCNumHijos));
	}
	public function hasDCNumHijos() {
		return $this->_hasDCNumHijos;
	}
	public function getDCNumHijos($index) {
		return $this->_dCNumHijos[$index];
	}
	public function countDCNumHijos() {
		return count($this->_dCNumHijos);
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCDatosHijos con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCDatosHijos 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCDatosHijos();
		if (isset($vData['DCLiteral'])) {

			$newItem->setDCLiteral($vData['DCLiteral']);
		}
		if (isset($vData['DCNumHijos']) && !empty($vData['DCNumHijos'])) {
			if (SoapObject::is_assoc($vData['DCNumHijos'])) {

				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = DCNumHijos::fromSoap($vData['DCNumHijos']);
				$newItem->addDCNumHijos($newClass);
			} else {

				foreach ($vData['DCNumHijos'] as $oVar) {
					$newClass = DCNumHijos::fromSoap($oVar);
					$newItem->addDCNumHijos($newClass);
				}
			}
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCLiteral, 'DCLiteral', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCNumHijos, 'DCNumHijos', SOAP_ENC_OBJECT, $namespace, 0, 15, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCNumAscend extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCNombreAscend" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCNombreAscend = null;
	private $_hasDCNombreAscend = false;
	public function setDCNombreAscend($value) {
		$this->_dCNombreAscend = $value;
		$this->_hasDCNombreAscend = ($value !== null);
	}
	public function hasDCNombreAscend() {
		return $this->_hasDCNombreAscend;
	}
	public function getDCNombreAscend() {
		return $this->_dCNombreAscend;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCFechaNacim" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCFechaNacim = null;
	private $_hasDCFechaNacim = false;
	public function setDCFechaNacim($value) {
		$this->_dCFechaNacim = $value;
		$this->_hasDCFechaNacim = ($value !== null);
	}
	public function hasDCFechaNacim() {
		return $this->_hasDCFechaNacim;
	}
	public function getDCFechaNacim() {
		return $this->_dCFechaNacim;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCMinusvalia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCMinusvalia = null;
	private $_hasDCMinusvalia = false;
	public function setDCMinusvalia($value) {
		$this->_dCMinusvalia = $value;
		$this->_hasDCMinusvalia = ($value !== null);
	}
	public function hasDCMinusvalia() {
		return $this->_hasDCMinusvalia;
	}
	public function getDCMinusvalia() {
		return $this->_dCMinusvalia;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCVinculacion" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCVinculacion = null;
	private $_hasDCVinculacion = false;
	public function setDCVinculacion($value) {
		$this->_dCVinculacion = $value;
		$this->_hasDCVinculacion = ($value !== null);
	}
	public function hasDCVinculacion() {
		return $this->_hasDCVinculacion;
	}
	public function getDCVinculacion() {
		return $this->_dCVinculacion;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCConvivencia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCConvivencia = null;
	private $_hasDCConvivencia = false;
	public function setDCConvivencia($value) {
		$this->_dCConvivencia = $value;
		$this->_hasDCConvivencia = ($value !== null);
	}
	public function hasDCConvivencia() {
		return $this->_hasDCConvivencia;
	}
	public function getDCConvivencia() {
		return $this->_dCConvivencia;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCNumAscend con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCNumAscend 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCNumAscend();
		if (isset($vData['DCNombreAscend'])) {

			$newItem->setDCNombreAscend($vData['DCNombreAscend']);
		}
		if (isset($vData['DCFechaNacim'])) {

			$newItem->setDCFechaNacim($vData['DCFechaNacim']);
		}
		if (isset($vData['DCMinusvalia'])) {

			$newItem->setDCMinusvalia($vData['DCMinusvalia']);
		}
		if (isset($vData['DCVinculacion'])) {

			$newItem->setDCVinculacion($vData['DCVinculacion']);
		}
		if (isset($vData['DCConvivencia'])) {

			$newItem->setDCConvivencia($vData['DCConvivencia']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCNombreAscend, 'DCNombreAscend', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCFechaNacim, 'DCFechaNacim', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCMinusvalia, 'DCMinusvalia', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCVinculacion, 'DCVinculacion', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCConvivencia, 'DCConvivencia', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCDatosAscend extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCLiteral" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCLiteral = null;
	private $_hasDCLiteral = false;
	public function setDCLiteral($value) {
		$this->_dCLiteral = $value;
		$this->_hasDCLiteral = ($value !== null);
	}
	public function hasDCLiteral() {
		return $this->_hasDCLiteral;
	}
	public function getDCLiteral() {
		return $this->_dCLiteral;
	}

	/**
	 * @var DCNumAscend Propiedad de navegacion entre objetos SOAP
	 * name="DCNumAscend" type="DCNumAscend"[COMPLEXTYPE] minOccurs="0" maxOccurs="6" nillable="false"
	 */
	private $_dCNumAscend = array();
	private $_hasDCNumAscend = false;
	public function replaceArrayDCNumAscend($value) {
		$this->_dCNumAscend = $value;
		$this->_hasDCNumAscend = (isset($this->_dCNumAscend) && !empty($this->_dCNumAscend));
	}
	public function retrieveArrayDCNumAscend() {
		return $this->_dCNumAscend;
	}
	public function addDCNumAscend($value) {
		array_push($this->_dCNumAscend, $value);
		$this->_hasDCNumAscend = (isset($this->_dCNumAscend) && !empty($this->_dCNumAscend));
	}
	public function hasDCNumAscend() {
		return $this->_hasDCNumAscend;
	}
	public function getDCNumAscend($index) {
		return $this->_dCNumAscend[$index];
	}
	public function countDCNumAscend() {
		return count($this->_dCNumAscend);
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCDatosAscend con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCDatosAscend 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCDatosAscend();
		if (isset($vData['DCLiteral'])) {

			$newItem->setDCLiteral($vData['DCLiteral']);
		}
		if (isset($vData['DCNumAscend']) && !empty($vData['DCNumAscend'])) {
			if (SoapObject::is_assoc($vData['DCNumAscend'])) {

				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = DCNumAscend::fromSoap($vData['DCNumAscend']);
				$newItem->addDCNumAscend($newClass);
			} else {

				foreach ($vData['DCNumAscend'] as $oVar) {
					$newClass = DCNumAscend::fromSoap($oVar);
					$newItem->addDCNumAscend($newClass);
				}
			}
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCLiteral, 'DCLiteral', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCNumAscend, 'DCNumAscend', SOAP_ENC_OBJECT, $namespace, 0, 6, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCNumViviendas extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCContrib" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCContrib = null;
	private $_hasDCContrib = false;
	public function setDCContrib($value) {
		$this->_dCContrib = $value;
		$this->_hasDCContrib = ($value !== null);
	}
	public function hasDCContrib() {
		return $this->_hasDCContrib;
	}
	public function getDCContrib() {
		return $this->_dCContrib;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCParticipac" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCParticipac = null;
	private $_hasDCParticipac = false;
	public function setDCParticipac($value) {
		$this->_dCParticipac = $value;
		$this->_hasDCParticipac = ($value !== null);
	}
	public function hasDCParticipac() {
		return $this->_hasDCParticipac;
	}
	public function getDCParticipac() {
		return $this->_dCParticipac;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCRefCatastr" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCRefCatastr = null;
	private $_hasDCRefCatastr = false;
	public function setDCRefCatastr($value) {
		$this->_dCRefCatastr = $value;
		$this->_hasDCRefCatastr = ($value !== null);
	}
	public function hasDCRefCatastr() {
		return $this->_hasDCRefCatastr;
	}
	public function getDCRefCatastr() {
		return $this->_dCRefCatastr;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCSituacion" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCSituacion = null;
	private $_hasDCSituacion = false;
	public function setDCSituacion($value) {
		$this->_dCSituacion = $value;
		$this->_hasDCSituacion = ($value !== null);
	}
	public function hasDCSituacion() {
		return $this->_hasDCSituacion;
	}
	public function getDCSituacion() {
		return $this->_dCSituacion;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCTitularidad" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCTitularidad = null;
	private $_hasDCTitularidad = false;
	public function setDCTitularidad($value) {
		$this->_dCTitularidad = $value;
		$this->_hasDCTitularidad = ($value !== null);
	}
	public function hasDCTitularidad() {
		return $this->_hasDCTitularidad;
	}
	public function getDCTitularidad() {
		return $this->_dCTitularidad;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCNumViviendas con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCNumViviendas 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCNumViviendas();
		if (isset($vData['DCContrib'])) {

			$newItem->setDCContrib($vData['DCContrib']);
		}
		if (isset($vData['DCParticipac'])) {

			$newItem->setDCParticipac($vData['DCParticipac']);
		}
		if (isset($vData['DCRefCatastr'])) {

			$newItem->setDCRefCatastr($vData['DCRefCatastr']);
		}
		if (isset($vData['DCSituacion'])) {

			$newItem->setDCSituacion($vData['DCSituacion']);
		}
		if (isset($vData['DCTitularidad'])) {

			$newItem->setDCTitularidad($vData['DCTitularidad']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCContrib, 'DCContrib', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCParticipac, 'DCParticipac', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCRefCatastr, 'DCRefCatastr', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCSituacion, 'DCSituacion', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCTitularidad, 'DCTitularidad', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCDatosVivienda extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCLiteral" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCLiteral = null;
	private $_hasDCLiteral = false;
	public function setDCLiteral($value) {
		$this->_dCLiteral = $value;
		$this->_hasDCLiteral = ($value !== null);
	}
	public function hasDCLiteral() {
		return $this->_hasDCLiteral;
	}
	public function getDCLiteral() {
		return $this->_dCLiteral;
	}

	/**
	 * @var DCNumViviendas Propiedad de navegacion entre objetos SOAP
	 * name="DCNumViviendas" type="DCNumViviendas"[COMPLEXTYPE] minOccurs="0" maxOccurs="12" nillable="false"
	 */
	private $_dCNumViviendas = array();
	private $_hasDCNumViviendas = false;
	public function replaceArrayDCNumViviendas($value) {
		$this->_dCNumViviendas = $value;
		$this->_hasDCNumViviendas = (isset($this->_dCNumViviendas) && !empty($this->_dCNumViviendas));
	}
	public function retrieveArrayDCNumViviendas() {
		return $this->_dCNumViviendas;
	}
	public function addDCNumViviendas($value) {
		array_push($this->_dCNumViviendas, $value);
		$this->_hasDCNumViviendas = (isset($this->_dCNumViviendas) && !empty($this->_dCNumViviendas));
	}
	public function hasDCNumViviendas() {
		return $this->_hasDCNumViviendas;
	}
	public function getDCNumViviendas($index) {
		return $this->_dCNumViviendas[$index];
	}
	public function countDCNumViviendas() {
		return count($this->_dCNumViviendas);
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCDatosVivienda con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCDatosVivienda 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCDatosVivienda();
		if (isset($vData['DCLiteral'])) {

			$newItem->setDCLiteral($vData['DCLiteral']);
		}
		if (isset($vData['DCNumViviendas']) && !empty($vData['DCNumViviendas'])) {
			if (SoapObject::is_assoc($vData['DCNumViviendas'])) {

				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = DCNumViviendas::fromSoap($vData['DCNumViviendas']);
				$newItem->addDCNumViviendas($newClass);
			} else {

				foreach ($vData['DCNumViviendas'] as $oVar) {
					$newClass = DCNumViviendas::fromSoap($oVar);
					$newItem->addDCNumViviendas($newClass);
				}
			}
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCLiteral, 'DCLiteral', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCNumViviendas, 'DCNumViviendas', SOAP_ENC_OBJECT, $namespace, 0, 12, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCNumInmuebles extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCContrib" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCContrib = null;
	private $_hasDCContrib = false;
	public function setDCContrib($value) {
		$this->_dCContrib = $value;
		$this->_hasDCContrib = ($value !== null);
	}
	public function hasDCContrib() {
		return $this->_hasDCContrib;
	}
	public function getDCContrib() {
		return $this->_dCContrib;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCTitularidad" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCTitularidad = null;
	private $_hasDCTitularidad = false;
	public function setDCTitularidad($value) {
		$this->_dCTitularidad = $value;
		$this->_hasDCTitularidad = ($value !== null);
	}
	public function hasDCTitularidad() {
		return $this->_hasDCTitularidad;
	}
	public function getDCTitularidad() {
		return $this->_dCTitularidad;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCSituacion" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCSituacion = null;
	private $_hasDCSituacion = false;
	public function setDCSituacion($value) {
		$this->_dCSituacion = $value;
		$this->_hasDCSituacion = ($value !== null);
	}
	public function hasDCSituacion() {
		return $this->_hasDCSituacion;
	}
	public function getDCSituacion() {
		return $this->_dCSituacion;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCRefCatastr" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCRefCatastr = null;
	private $_hasDCRefCatastr = false;
	public function setDCRefCatastr($value) {
		$this->_dCRefCatastr = $value;
		$this->_hasDCRefCatastr = ($value !== null);
	}
	public function hasDCRefCatastr() {
		return $this->_hasDCRefCatastr;
	}
	public function getDCRefCatastr() {
		return $this->_dCRefCatastr;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCUso" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCUso = null;
	private $_hasDCUso = false;
	public function setDCUso($value) {
		$this->_dCUso = $value;
		$this->_hasDCUso = ($value !== null);
	}
	public function hasDCUso() {
		return $this->_hasDCUso;
	}
	public function getDCUso() {
		return $this->_dCUso;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCRentaImputada" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCRentaImputada = null;
	private $_hasDCRentaImputada = false;
	public function setDCRentaImputada($value) {
		$this->_dCRentaImputada = $value;
		$this->_hasDCRentaImputada = ($value !== null);
	}
	public function hasDCRentaImputada() {
		return $this->_hasDCRentaImputada;
	}
	public function getDCRentaImputada() {
		return $this->_dCRentaImputada;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCNumInmuebles con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCNumInmuebles 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCNumInmuebles();
		if (isset($vData['DCContrib'])) {

			$newItem->setDCContrib($vData['DCContrib']);
		}
		if (isset($vData['DCTitularidad'])) {

			$newItem->setDCTitularidad($vData['DCTitularidad']);
		}
		if (isset($vData['DCSituacion'])) {

			$newItem->setDCSituacion($vData['DCSituacion']);
		}
		if (isset($vData['DCRefCatastr'])) {

			$newItem->setDCRefCatastr($vData['DCRefCatastr']);
		}
		if (isset($vData['DCUso'])) {

			$newItem->setDCUso($vData['DCUso']);
		}
		if (isset($vData['DCRentaImputada'])) {

			$newItem->setDCRentaImputada($vData['DCRentaImputada']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCContrib, 'DCContrib', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCTitularidad, 'DCTitularidad', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCSituacion, 'DCSituacion', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCRefCatastr, 'DCRefCatastr', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCUso, 'DCUso', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCRentaImputada, 'DCRentaImputada', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DCDatosInmuebles extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="DCLiteral" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCLiteral = null;
	private $_hasDCLiteral = false;
	public function setDCLiteral($value) {
		$this->_dCLiteral = $value;
		$this->_hasDCLiteral = ($value !== null);
	}
	public function hasDCLiteral() {
		return $this->_hasDCLiteral;
	}
	public function getDCLiteral() {
		return $this->_dCLiteral;
	}

	/**
	 * @var DCNumInmuebles Propiedad de navegacion entre objetos SOAP
	 * name="DCNumInmuebles" type="DCNumInmuebles"[COMPLEXTYPE] minOccurs="0" maxOccurs="66" nillable="false"
	 */
	private $_dCNumInmuebles = array();
	private $_hasDCNumInmuebles = false;
	public function replaceArrayDCNumInmuebles($value) {
		$this->_dCNumInmuebles = $value;
		$this->_hasDCNumInmuebles = (isset($this->_dCNumInmuebles) && !empty($this->_dCNumInmuebles));
	}
	public function retrieveArrayDCNumInmuebles() {
		return $this->_dCNumInmuebles;
	}
	public function addDCNumInmuebles($value) {
		array_push($this->_dCNumInmuebles, $value);
		$this->_hasDCNumInmuebles = (isset($this->_dCNumInmuebles) && !empty($this->_dCNumInmuebles));
	}
	public function hasDCNumInmuebles() {
		return $this->_hasDCNumInmuebles;
	}
	public function getDCNumInmuebles($index) {
		return $this->_dCNumInmuebles[$index];
	}
	public function countDCNumInmuebles() {
		return count($this->_dCNumInmuebles);
	}


	/**
	 *
	 * Devuelve una instancia de la clase DCDatosInmuebles con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DCDatosInmuebles 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DCDatosInmuebles();
		if (isset($vData['DCLiteral'])) {

			$newItem->setDCLiteral($vData['DCLiteral']);
		}
		if (isset($vData['DCNumInmuebles']) && !empty($vData['DCNumInmuebles'])) {
			if (SoapObject::is_assoc($vData['DCNumInmuebles'])) {

				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = DCNumInmuebles::fromSoap($vData['DCNumInmuebles']);
				$newItem->addDCNumInmuebles($newClass);
			} else {

				foreach ($vData['DCNumInmuebles'] as $oVar) {
					$newClass = DCNumInmuebles::fromSoap($oVar);
					$newItem->addDCNumInmuebles($newClass);
				}
			}
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCLiteral, 'DCLiteral', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCNumInmuebles, 'DCNumInmuebles', SOAP_ENC_OBJECT, $namespace, 0, 66, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DatosCola extends SoapObject {


	/**
	 * @var DCDatosPersonales Propiedad de navegacion entre objetos SOAP
	 * name="DCDatosPersonales" type="DCDatosPersonales"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCDatosPersonales = null;
	private $_hasDCDatosPersonales = false;
	public function setDCDatosPersonales($value) {
		$this->_dCDatosPersonales = $value;
		$this->_hasDCDatosPersonales = ($value !== null);
	}
	public function hasDCDatosPersonales() {
		return $this->_hasDCDatosPersonales;
	}
	public function getDCDatosPersonales() {
		return $this->_dCDatosPersonales;
	}


	/**
	 * @var DCDatosConyuge Propiedad de navegacion entre objetos SOAP
	 * name="DCDatosConyuge" type="DCDatosConyuge"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCDatosConyuge = null;
	private $_hasDCDatosConyuge = false;
	public function setDCDatosConyuge($value) {
		$this->_dCDatosConyuge = $value;
		$this->_hasDCDatosConyuge = ($value !== null);
	}
	public function hasDCDatosConyuge() {
		return $this->_hasDCDatosConyuge;
	}
	public function getDCDatosConyuge() {
		return $this->_dCDatosConyuge;
	}


	/**
	 * @var DCDatosHijos Propiedad de navegacion entre objetos SOAP
	 * name="DCDatosHijos" type="DCDatosHijos"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCDatosHijos = null;
	private $_hasDCDatosHijos = false;
	public function setDCDatosHijos($value) {
		$this->_dCDatosHijos = $value;
		$this->_hasDCDatosHijos = ($value !== null);
	}
	public function hasDCDatosHijos() {
		return $this->_hasDCDatosHijos;
	}
	public function getDCDatosHijos() {
		return $this->_dCDatosHijos;
	}


	/**
	 * @var DCDatosAscend Propiedad de navegacion entre objetos SOAP
	 * name="DCDatosAscend" type="DCDatosAscend"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCDatosAscend = null;
	private $_hasDCDatosAscend = false;
	public function setDCDatosAscend($value) {
		$this->_dCDatosAscend = $value;
		$this->_hasDCDatosAscend = ($value !== null);
	}
	public function hasDCDatosAscend() {
		return $this->_hasDCDatosAscend;
	}
	public function getDCDatosAscend() {
		return $this->_dCDatosAscend;
	}


	/**
	 * @var DCDatosVivienda Propiedad de navegacion entre objetos SOAP
	 * name="DCDatosVivienda" type="DCDatosVivienda"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCDatosVivienda = null;
	private $_hasDCDatosVivienda = false;
	public function setDCDatosVivienda($value) {
		$this->_dCDatosVivienda = $value;
		$this->_hasDCDatosVivienda = ($value !== null);
	}
	public function hasDCDatosVivienda() {
		return $this->_hasDCDatosVivienda;
	}
	public function getDCDatosVivienda() {
		return $this->_dCDatosVivienda;
	}


	/**
	 * @var DCDatosInmuebles Propiedad de navegacion entre objetos SOAP
	 * name="DCDatosInmuebles" type="DCDatosInmuebles"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_dCDatosInmuebles = null;
	private $_hasDCDatosInmuebles = false;
	public function setDCDatosInmuebles($value) {
		$this->_dCDatosInmuebles = $value;
		$this->_hasDCDatosInmuebles = ($value !== null);
	}
	public function hasDCDatosInmuebles() {
		return $this->_hasDCDatosInmuebles;
	}
	public function getDCDatosInmuebles() {
		return $this->_dCDatosInmuebles;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DatosCola con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DatosCola 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DatosCola();
		if (isset($vData['DCDatosPersonales'])) {

			$newClass = DCDatosPersonales::fromSoap($vData['DCDatosPersonales']);
			$newItem->setDCDatosPersonales($newClass);
		}
		if (isset($vData['DCDatosConyuge'])) {

			$newClass = DCDatosConyuge::fromSoap($vData['DCDatosConyuge']);
			$newItem->setDCDatosConyuge($newClass);
		}
		if (isset($vData['DCDatosHijos'])) {

			$newClass = DCDatosHijos::fromSoap($vData['DCDatosHijos']);
			$newItem->setDCDatosHijos($newClass);
		}
		if (isset($vData['DCDatosAscend'])) {

			$newClass = DCDatosAscend::fromSoap($vData['DCDatosAscend']);
			$newItem->setDCDatosAscend($newClass);
		}
		if (isset($vData['DCDatosVivienda'])) {

			$newClass = DCDatosVivienda::fromSoap($vData['DCDatosVivienda']);
			$newItem->setDCDatosVivienda($newClass);
		}
		if (isset($vData['DCDatosInmuebles'])) {

			$newClass = DCDatosInmuebles::fromSoap($vData['DCDatosInmuebles']);
			$newItem->setDCDatosInmuebles($newClass);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_dCDatosPersonales, 'DCDatosPersonales', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCDatosConyuge, 'DCDatosConyuge', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCDatosHijos, 'DCDatosHijos', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCDatosAscend, 'DCDatosAscend', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCDatosVivienda, 'DCDatosVivienda', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_dCDatosInmuebles, 'DCDatosInmuebles', SOAP_ENC_OBJECT, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class irpf extends SoapObject {


	/**
	 * @var CabeceraRenta Propiedad de navegacion entre objetos SOAP
	 * name="CabeceraRenta" type="CabeceraRenta"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_cabeceraRenta = null;
	private $_hasCabeceraRenta = false;
	public function setCabeceraRenta($value) {
		$this->_cabeceraRenta = $value;
		$this->_hasCabeceraRenta = ($value !== null);
	}
	public function hasCabeceraRenta() {
		return $this->_hasCabeceraRenta;
	}
	public function getCabeceraRenta() {
		return $this->_cabeceraRenta;
	}

	/**
	 * @var DatosEconomicos Propiedad de navegacion entre objetos SOAP
	 * name="DatosEconomicos" type="DatosEconomicos"[COMPLEXTYPE] minOccurs="0" maxOccurs="2000" nillable="false"
	 */
	private $_datosEconomicos = array();
	private $_hasDatosEconomicos = false;
	public function replaceArrayDatosEconomicos($value) {
		$this->_datosEconomicos = $value;
		$this->_hasDatosEconomicos = (isset($this->_datosEconomicos) && !empty($this->_datosEconomicos));
	}
	public function retrieveArrayDatosEconomicos() {
		return $this->_datosEconomicos;
	}
	public function addDatosEconomicos($value) {
		array_push($this->_datosEconomicos, $value);
		$this->_hasDatosEconomicos = (isset($this->_datosEconomicos) && !empty($this->_datosEconomicos));
	}
	public function hasDatosEconomicos() {
		return $this->_hasDatosEconomicos;
	}
	public function getDatosEconomicos($index) {
		return $this->_datosEconomicos[$index];
	}
	public function countDatosEconomicos() {
		return count($this->_datosEconomicos);
	}

	/**
	 * @var OtrosDatos Propiedad de navegacion entre objetos SOAP
	 * name="OtrosDatos" type="OtrosDatos"[COMPLEXTYPE] minOccurs="0" maxOccurs="10" nillable="false"
	 */
	private $_otrosDatos = array();
	private $_hasOtrosDatos = false;
	public function replaceArrayOtrosDatos($value) {
		$this->_otrosDatos = $value;
		$this->_hasOtrosDatos = (isset($this->_otrosDatos) && !empty($this->_otrosDatos));
	}
	public function retrieveArrayOtrosDatos() {
		return $this->_otrosDatos;
	}
	public function addOtrosDatos($value) {
		array_push($this->_otrosDatos, $value);
		$this->_hasOtrosDatos = (isset($this->_otrosDatos) && !empty($this->_otrosDatos));
	}
	public function hasOtrosDatos() {
		return $this->_hasOtrosDatos;
	}
	public function getOtrosDatos($index) {
		return $this->_otrosDatos[$index];
	}
	public function countOtrosDatos() {
		return count($this->_otrosDatos);
	}


	/**
	 * @var DatosCola Propiedad de navegacion entre objetos SOAP
	 * name="DatosCola" type="DatosCola"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_datosCola = null;
	private $_hasDatosCola = false;
	public function setDatosCola($value) {
		$this->_datosCola = $value;
		$this->_hasDatosCola = ($value !== null);
	}
	public function hasDatosCola() {
		return $this->_hasDatosCola;
	}
	public function getDatosCola() {
		return $this->_datosCola;
	}


	/**
	 *
	 * Devuelve una instancia de la clase irpf con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	irpf 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new irpf();
		if (!isset($vData['CabeceraRenta'])) {
			throw new Exception('El parametro CabeceraRenta es obligatorio');
		}
		if (isset($vData['CabeceraRenta'])) {

			$newClass = CabeceraRenta::fromSoap($vData['CabeceraRenta']);
			$newItem->setCabeceraRenta($newClass);
		}
		if (isset($vData['DatosEconomicos']) && !empty($vData['DatosEconomicos'])) {
			if (SoapObject::is_assoc($vData['DatosEconomicos'])) {

				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = DatosEconomicos::fromSoap($vData['DatosEconomicos']);
				$newItem->addDatosEconomicos($newClass);
			} else {

				foreach ($vData['DatosEconomicos'] as $oVar) {
					$newClass = DatosEconomicos::fromSoap($oVar);
					$newItem->addDatosEconomicos($newClass);
				}
			}
		}
		if (isset($vData['OtrosDatos']) && !empty($vData['OtrosDatos'])) {
			if (SoapObject::is_assoc($vData['OtrosDatos'])) {

				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = OtrosDatos::fromSoap($vData['OtrosDatos']);
				$newItem->addOtrosDatos($newClass);
			} else {

				foreach ($vData['OtrosDatos'] as $oVar) {
					$newClass = OtrosDatos::fromSoap($oVar);
					$newItem->addOtrosDatos($newClass);
				}
			}
		}
		if (!isset($vData['DatosCola'])) {
			throw new Exception('El parametro DatosCola es obligatorio');
		}
		if (isset($vData['DatosCola'])) {

			$newClass = DatosCola::fromSoap($vData['DatosCola']);
			$newItem->setDatosCola($newClass);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_cabeceraRenta, 'CabeceraRenta', SOAP_ENC_OBJECT, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_datosEconomicos, 'DatosEconomicos', SOAP_ENC_OBJECT, $namespace, 0, 2000, false);
		$this->__doChild($myLevel, $this->_otrosDatos, 'OtrosDatos', SOAP_ENC_OBJECT, $namespace, 0, 10, false);
		$this->__doChild($myLevel, $this->_datosCola, 'DatosCola', SOAP_ENC_OBJECT, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DatosEspecificos extends SoapObject {
	// MODE: choice

	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="Ejercicio" type="135"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_ejercicio = null;
	private $_hasEjercicio = false;
	public function setEjercicio($value) {
		$this->_ejercicio = $value;
		$this->_hasEjercicio = ($value !== null);
	}
	public function hasEjercicio() {
		return $this->_hasEjercicio;
	}
	public function getEjercicio() {
		return $this->_ejercicio;
	}


	/**
	 * @var Cabecera Propiedad de navegacion entre objetos SOAP
	 * name="Cabecera" type="Cabecera"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_cabecera = null;
	private $_hasCabecera = false;
	public function setCabecera($value) {
		$this->_cabecera = $value;
		$this->_hasCabecera = ($value !== null);
	}
	public function hasCabecera() {
		return $this->_hasCabecera;
	}
	public function getCabecera() {
		return $this->_cabecera;
	}


	/**
	 * @var Imputaciones Propiedad de navegacion entre objetos SOAP
	 * name="Imputaciones" type="Imputaciones"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_imputaciones = null;
	private $_hasImputaciones = false;
	public function setImputaciones($value) {
		$this->_imputaciones = $value;
		$this->_hasImputaciones = ($value !== null);
	}
	public function hasImputaciones() {
		return $this->_hasImputaciones;
	}
	public function getImputaciones() {
		return $this->_imputaciones;
	}


	/**
	 * @var irpf Propiedad de navegacion entre objetos SOAP
	 * name="irpf" type="irpf"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_irpf = null;
	private $_hasIrpf = false;
	public function setIrpf($value) {
		$this->_irpf = $value;
		$this->_hasIrpf = ($value !== null);
	}
	public function hasIrpf() {
		return $this->_hasIrpf;
	}
	public function getIrpf() {
		return $this->_irpf;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DatosEspecificos con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DatosEspecificos 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DatosEspecificos();
		$choiceSetted = false;

		if (isset($vData['Ejercicio'])) {
			if ($choiceSetted) {
				throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
			}
			$choiceSetted = true;

			$newItem->setEjercicio($vData['Ejercicio']);
		}
		if (isset($vData['Cabecera'])) {
			if ($choiceSetted) {
				throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
			}

			$newClass = Cabecera::fromSoap($vData['Cabecera']);
			$newItem->setCabecera($newClass);
		}
		if (isset($vData['Imputaciones'])) {
			if ($choiceSetted) {
				throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
			}

			$newClass = Imputaciones::fromSoap($vData['Imputaciones']);
			$newItem->setImputaciones($newClass);
		}
		if (isset($vData['irpf'])) {
			if ($choiceSetted) {
				throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
			}

			$newClass = irpf::fromSoap($vData['irpf']);
			$newItem->setIrpf($newClass);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_ejercicio, 'Ejercicio', 135, $namespace, 1, 1, true);
		$this->__doChild($myLevel, $this->_cabecera, 'Cabecera', SOAP_ENC_OBJECT, $namespace, 1, 1, true);
		$this->__doChild($myLevel, $this->_imputaciones, 'Imputaciones', SOAP_ENC_OBJECT, $namespace, 0, 1, true);
		$this->__doChild($myLevel, $this->_irpf, 'irpf', SOAP_ENC_OBJECT, $namespace, 0, 1, true);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}


?>