<?php
namespace WSCOMUN\GDE;

/**
 * Clase para la insercin y lectura de documetos en GDE SIN pasar por la PAI.
 * @author dpascual
 *
 */
class AlfrescoClient
{
	/** @var string url donde realizar el login */
	private $loginURL;

	/** @var string url donde realizar la subida */
	private $uploadURL;

	/** @var string URL de descarga */
	private $downloadURL;

	/** @var string usuario */
	private $user;

	/** @var string contrasea del usuario */
	private $password;

	/** @var string Almacena el ticket generado */
	private $ticket;

	/** @var string idd de la aplicacin */
	private $idApp;

	/** @var boolean Flag que indica si est o no disponible CURL */
	private $curlEnabled;

	/** @var integer Indica el nmero de segundos hasta timeout */
	private $timeout;

	/**
	 * Construye un objeto
	 *
	 * @param string $user Usuario de acceso
	 * @param string $password Contrasea de acceso
	 * @param string $loginURL URL de LOGIN
	 * @param string $uploadURL URL de subida
	 * @param string $downloadURL URL de bajada
	 */
	public function __construct($user, $password, $loginURL, $uploadURL, $downloadURL, $timeOut=90)
	{
		$this->timeout = max(
			array(
				$timeOut //segundos
				,(ini_get('max_execution_time')+0)
				,(ini_get('max_input_time')+0)
			)
		);

		$this->user = $user;
		$this->password = $password;
		$this->ticket=null;
		$this->loginURL = $loginURL;
		$this->downloadURL = $downloadURL;
		$this->uploadURL = $uploadURL;
		$this->curlEnabled = function_exists('curl_version');
	}


	/**
	 * Devuelve un tickeck temporal de session
	 * @return string ticket temporal para uso de la API
	 * @throws \Exception
	 */
	public function getTicket()
	{
		//Si ya tenemos un ticket vlido, lo reutilizamos
		if (!empty($this->ticket))
		{
			return $this->ticket;
		}

		$passEncoded = urlencode($this->password);
		$userEncode = urlencode($this->user);
		//Si no hay ticket lo obtenemos
		$url = $this->loginURL.'?u='.$userEncode.'&pw='.$passEncoded;
		try
		{
			$xmlString = $this->urlGetContents($url);
		}
		catch (\Exception $e)
		{
			throw $e;
		}

		if ($xmlString === false)
		{
			$errorMsg = error_get_last();
			throw new \Exception(__CLASS__.'::'.__METHOD__.": No puede alcanzarse la URL de login: ".$url." Error: ".print_r($errorMsg, true));
		}
		try
		{
			$xml = simplexml_load_string($xmlString);
		}
		catch (\Exception $e)
		{
			$mensaje = "Error en el parseo del XML. ".$e->getMessage();
			throw new \Exception($mensaje);
		}


		if (isset($xml->response))
		{
			$errorCode = (integer) $xml->response->status->code;
			$descError = (string) $xml->response->status->name . '-' . (string) $xml->response->status->description;
			throw new \Exception("Error del login: ".$descError, $errorCode);
		}

		$this->ticket = (string) $xml[0];
		return ($this->ticket);
	}//getTicket


	/**
	 * Obtiene el documento a partir de la referencia GDE
	 * @param string $refGDE
	 * @throws \Exception
	 */
	public function getDocument($refGDE)
	{
		$doc = null;
		try
		{
			$ticket = $this->getTicket();
			$url = $this->downloadURL.'?alf_ticket='.$ticket.'&referenciaGDE='.$refGDE;
			$doc = $this->urlGetContents($url);
		}
		catch (\Exception $e)
		{
			throw $e;
		}

		if (empty($doc))//REVIEW Retorno si no existe?
		{
			$mensaje = "No existe el documento con referencia GDE: $refGDE";
			throw new \Exception($mensaje);
		}
		return ($doc);
	}//getDocument()


	/**
	 * Obtiene una URL de descarga temporal del documento (segn caducidad del token)
	 * @param string $refGDE
	 * @param string $tmp Directorio temporal para gestin de ficheros. Si no se indica sys_get_temp_dir()
	 * @return string Nombre del ficero (temporal) creado
	 * @throws \Exception
	 */
	public function getDocumentAsURL($refGDE)
	{
		try
		{
			$ticket = $this->getTicket();
			$url = $this->downloadURL.'?alf_ticket='.$ticket.'&referenciaGDE='.$refGDE;
			return $url;
		}
		catch (\Exception $e)
		{
			throw $e;
		}
	}//getDocumentAsURL()



	/**
	 * Obtiene el fichero y lo ubica en un directorio temporal para su descarga por bloques
	 * @param string $refGDE
	 * @param string $tmp Directorio temporal para gestin de ficheros. Si no se indica sys_get_temp_dir()
	 * @return string Nombre del ficero (temporal) creado
	 * @throws \Exception
	 */
	public function getDocumentAsFile($refGDE, $tmp=null)
	{
		try
		{
			if (empty($tmp))
			{
				$tmp = sys_get_temp_dir();
			}
			$ticket = $this->getTicket();
			$url = $this->downloadURL.'?alf_ticket='.$ticket.'&referenciaGDE='.$refGDE;
			$fileName = $this->urlGetContentInFile($url, $tmp);
			return $fileName;
		}
		catch (\Exception $e)
		{
			throw $e;
		}
	}//getDocumentAsFile()


	/**
	 * Inserta un documento ubicado en el sistema de ficheros del servidor Apache/PHP en Alfresco
	 *
	 * @param string $idApp Identificador de la APP en el espacio de nombres correspondiente
	 * @param string $rutaFicheroEnServer Ubicacin del fichero a insertar en Alfresco en el servidor HTTP
	 * @param string $rutaDestinoAlf Ruta de alfresco donde ubicar el fichero
	 * @param string $nombreDoc Nombre del documento en alfresco
	 * @param string $descDoc Descripcin del documento
	 * @throws \Exception
	 */
	public function insertDocument($idApp, $rutaFicheroEnServer, $rutaDestinoAlf = '/', $nombreDoc = '', $descDoc = '')
	{
		$vFileParts = pathinfo($rutaFicheroEnServer);

		$nombreDoc = empty($nombreDoc)?$vFileParts['basename']:$nombreDoc;
		$descDoc = empty($descDoc)?$vFileParts['basename']:$descDoc;

		try
		{
			if ($this->curlEnabled)
			{
				$respuesta = $this->insertDocumentCURL($idApp, $rutaFicheroEnServer, $rutaDestinoAlf, $nombreDoc, $descDoc);
			}
			else
			{
				$respuesta = $this->insertDocumentHTTPRequest($idApp, $rutaFicheroEnServer, $rutaDestinoAlf, $nombreDoc, $descDoc);
			}
		}
		catch (\Exception $e)
		{
			throw $e;
		}

		$refGDE = '';

		//Parseamos la referencia GDE
		$respuesta = ' '.$respuesta;
		$ini = strpos($respuesta, 'Referencia GDE: ');
		if ($ini == 0)
		{
			$mensaje = "No se obtuvo referencia GDE";
			throw new \Exception($mensaje);
		}
		$ini += strlen('Referencia GDE: ');
		$len = stripos($respuesta, '</td></tr>', $ini) - $ini;
		$refGDE = substr($respuesta, $ini, $len);

		return $refGDE;

	}//insertDocument()


	public function getLoginUrl() {
		return $this->loginUrl;
	}

	public function setLoginUrl($loginUrl) {
		$this->loginUrl = $loginUrl;
	}

	public function getUser() {
		return $this->user;
	}

	public function setUser($user) {
		$this->user = $user;
	}

	public function getPassword() {
		return password;
	}

	public function setPassword($password) {
		$this->password = $password;
	}

	public function getUploadUrl() {
		return $this->uploadUrl;
	}

	public function setUploadUrl($uploadUrl) {
		$this->uploadUrl = $uploadUrl;
	}

	public function getDownloadUrl() {
		return $this->downloadUrl;
	}

	public function setDownloadUrl($downloadUrl) {
		$this->downloadUrl = downloadUrl;
	}

	public function getIdApp() {
		return $this->idApp;
	}

	public function setIdApp($idApp) {
		$this->idApp = $idApp;
	}




	/**
	 * Inserta u documento en Alfresco/GDE va CURL
	 *
	 * @param string $idApp
	 * @param string $rutaFicheroEnServer
	 * @param string $rutaDestinoAlf
	 * @param string $nombreDoc
	 * @param string $descDoc
	 * @throws \Exception
	 */
	private function insertDocumentCURL($idApp, $rutaFicheroEnServer, $rutaDestinoAlf, $nombreDoc, $descDoc)
	{
		try
		{
			$ticket = $this->getTicket();
			if (function_exists('curl_file_create')) // php >= 5.5
			{
				$cFile = curl_file_create($rutaFicheroEnServer);
			}
			else
			{
				//VER: http://php.net/manual/es/function.curl-file-create.php#114538
				$cFile = '@' . realpath($rutaFicheroEnServer).';filename='.$nombreDoc;
			}

			$url = $this->uploadURL.'?alf_ticket='.$ticket;
			$postFields = array (
					'idApp'			=> $idApp,
					'alf_ticket'	=> $ticket,
					'file'			=> $cFile,
					'title'			=> $nombreDoc,
					'desc'			=> $descDoc,
					'rutaDestino'	=> $rutaDestinoAlf
			);

			$curl = curl_init();
			curl_setopt($curl, CURLOPT_URL,$url);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, CURLOPT_POST, true);
			curl_setopt($curl, CURLOPT_POSTFIELDS, $postFields);
			curl_setopt($curl, CURLOPT_TIMEOUT, $this->timeout); // The maximum number of seconds to allow cURL functions to execute.
			set_time_limit($this->timeout);
			$response = curl_exec($curl);
			$status = curl_getinfo($curl, CURLINFO_HTTP_CODE);

			switch ($status)
			{
				case 200:
				case 202:
					; //Todo Ok
				break;

				default:
					$mensaje = "Error: la llamada a URL $url ha fallado con estado $status, respuesta $response, Error CURL: " . curl_error($curl);
					throw new \Exception($mensaje, $status);
				break;
			}

			curl_close($curl);
			return $response;

		}
		catch (\Exception $e)
		{
			throw $e;
		}
	}//Fin insertDocumentCURL


	/**
	 * Inserta u documento en Alfresco/GDE va HTTP Request
	 * @param string $idApp
	 * @param string $rutaFicheroEnServer
	 * @param string $rutaDestinoAlf
	 * @param string $nombreDoc
	 * @param string $descDoc
	 * @throws \Exception
	 * @return string
	 */
	private function insertDocumentHTTPRequest($idApp, $rutaFicheroEnServer, $rutaDestinoAlf, $nombreDoc, $descDoc)
	{
		$ticket = $this->getTicket();//Obtenemos el acceso a Alfresco
		$url = $this->uploadURL.'?alf_ticket='.$ticket;

		//Preparamos campos del formulario
		$postFields = array (
			'idApp'			=> $idApp,
			'title'			=> $nombreDoc,
			'desc'			=> $descDoc,
			'rutaDestino'	=> $rutaDestinoAlf,
		);

		$vURL = parse_url($url);
		if (! (($vURL['scheme'] == 'http') || ($vURL['scheme'] == 'https')) )
		{
			$mensaje = "Solo se soporta POST hacia HTTP/HTTPS.";
			throw new \Exception ($mensaje);
		}
		$port = (isset($vURL['port']) ? $vURL['port'] : 80);

		$hostURL = $vURL['host'];
		$pathURL = $vURL['path'];
		$queryURL = $vURL['query'];

		$errno = null; $errstr = '';
		$fp = fsockopen($hostURL, $port, $errno, $errstr, $this->timeout);
		if(!$fp)
		{
			$mensaje ="Error al acceder a $url. $errstr ($errno)";
			throw new \Exception($mensaje);
		}

		$boundary = '--'.uniqid();//Generamos un boundary
		$crlf = "\r\n";
		//Request principal
		$httpRequest = "POST $pathURL?$queryURL HTTP/1.1" . $crlf;
		$httpRequest.= "Host: $hostURL" . $crlf;
		$httpRequest.= "User-Agent: " . $_SERVER['HTTP_USER_AGENT'] . $crlf;
		$httpRequest.= empty($ticket)?"(Authorization: Basic ".base64_encode($this->user.':'.$this->password) . $crlf:'';//Autorizacin alternativa
		$httpRequest.= "Content-type: multipart/form-data; boundary=$boundary" . $crlf;

		//Sub request
		$body = '';

		//Para cada elemento del formulario
		foreach($postFields as $key => $value)
		{
			$valueLength = strlen($value);
			$body .= '--'.$boundary.$crlf
			.'Content-Disposition: form-data; name="'.$key.'"'.$crlf
			.'Content-Length: '.$valueLength.$crlf
			.$crlf.$value.$crlf;
		}

		//Anexamos el fichero
		$mimetype = self::getMimeType(basename($rutaFicheroEnServer));
		//TODO: Revisar y cambiar por lectira por bloques
		//REVIEW: Revisar y cambiar por lectura por bloques
		/*
		$fd = @fopen($rutaFicheroEnServer, "r");
		if($fd === false)
		{
			$mensaje =__CLASS__.'::'.__METHOD__.":: Error al leer el fichero $rutaFicheroEnServer";
			throw new \Exception($mensaje);
		}
		while (($buffer = fgets($fd, 4096)) !== false)
		{
			echo $buffer;
		}
		if (!feof($fd))
		{
			$mensaje ="Error al leer el fichero $rutaFicheroEnServer";
			throw new \Exception($mensaje);
		}
		fclose($fd);
		*/

		$file_contents = file_get_contents($rutaFicheroEnServer);
		if($file_contents === false)
		{
			$mensaje ="Error al leer el fichero $rutaFicheroEnServer";
			throw new \Exception($mensaje);
		}


		$body .= '--'.$boundary.$crlf
		.'Content-Disposition: form-data; name="file"; filename="'.$nombreDoc.'"'.$crlf
			.'Content-Type: '.$mimetype.$crlf
			.'Content-Transfer-Encoding : base64'.$crlf
			.'Content-Length: '.strlen($file_contents).$crlf
			.$crlf.$file_contents.$crlf;
		$body .= '--'.$boundary.'--';
		unset($file_contents); $file_contents = null; gc_collect_cycles();//Liberamos memoria
		$httpRequest.= "Content-length: ". strlen($body) . $crlf;
		$httpRequest.= "Connection: close\r\n\r\n";
		$httpRequest .= $body . $crlf.$crlf;

		//Envo de la request
		$write = fwrite($fp, $httpRequest);
		if($write === false)
		{
			$mensaje ="Error al enviar la REQUEST";
			throw new \Exception($mensaje);
		}

		//Liberamos memoria
		unset($httpRequest); $httpRequest = null; gc_collect_cycles();

		//Leemos la respuesta
		$response = '';
		while(!feof($fp))//Mientras no finalice la recepcin...
		{
			set_time_limit($this->timeout);
			$response .= fgets($fp);
		}
		fclose($fp); // Cerramos el socket

		// Separamos cabecera y contenido
		$result = explode($crlf.$crlf, $response, 2);
		$content = isset($result[1]) ? $result[1] : '';

		return $content;

	}//Fin insertDocumentHTTPRequest


	/**
	 * Devuelve el mimeType a partir de la extensin del nombre de fichero
	 * @param string $fileName
	 * @return string
	 */
	public static function getMimeType($fileName)
	{
		$vExt = explode('.',$fileName);
		$fileExtension = trim(strtolower(array_pop($vExt)));
		//Vector de tipos MIME
		$mime_types = array
		(
				//texto
				'txt' => 'text/plain',
				'htm' => 'text/html',
				'html' => 'text/html',
				'php' => 'text/html',
				'css' => 'text/css',
				'js' => 'application/javascript',
				'json' => 'application/json',
				'xml' => 'application/xml',
				'csv' => 'text/csv',

				// imgenes
				'png' => 'image/png',
				'jpe' => 'image/jpeg',
				'jpeg' => 'image/jpeg',
				'jpg' => 'image/jpeg',
				'gif' => 'image/gif',
				'bmp' => 'image/bmp',
				'ico' => 'image/vnd.microsoft.icon',
				'tiff' => 'image/tiff',
				'tif' => 'image/tiff',
				'svg' => 'image/svg+xml',
				'svgz' => 'image/svg+xml',

				// archivos
				'zip' => 'application/zip',
				'rar' => 'application/x-rar-compressed',
				'exe' => 'application/x-msdownload',
				'msi' => 'application/x-msdownload',
				'cab' => 'application/vnd.ms-cab-compressed',
				'tgz' => 'application/tar+gzip',
				'tar.gz' => 'application/tar+gzip',
				'tar' => 'application/tar',
				'gz' => 'application/gzip',
				'7z' => 'application/x-7z-compressed',
				's7z' => 'application/x-7z-compressed',

				// audio/video
				'mp3' => 'audio/mpeg',
				'qt' => 'video/quicktime',
				'mov' => 'video/quicktime',
				'mpeg' => 'video/mpeg',
				'avi' => 'video/x-msvideo',
				'swf' => 'application/x-shockwave-flash',
				'flv' => 'video/x-flv',

				// adobe
				'pdf' => 'application/pdf',
				'psd' => 'image/vnd.adobe.photoshop',
				'ai' => 'application/postscript',
				'eps' => 'application/postscript',
				'ps' => 'application/postscript',

				// MSOffice
				'doc' => 'application/msword',
				'dot' => 'application/msword',
				'docx' => 'application/msword',
				'rtf' => 'application/rtf',

				'xls' => 'application/vnd.ms-excel',
				'xlsx' => 'application/vnd.ms-excel',
				'xlm' => 'application/vnd.ms-excel',
				'xla' => 'application/vnd.ms-excel',
				'xlc' => 'application/vnd.ms-excel',
				'xlt' => 'application/vnd.ms-excel',
				'xlw' => 'application/vnd.ms-excel',

				'ppt' => 'application/vnd.ms-powerpoint',
				'pptx' => 'application/vnd.ms-powerpoint',
				'pps' => 'application/vnd.ms-powerpoint',
				'pot' => 'application/vnd.ms-powerpoint',

				// libreOffice
				'odc' => 'application/vnd.oasis.opendocument.chart',
				'otc' => 'application/vnd.oasis.opendocument.chart-template',
				'odf' => 'application/vnd.oasis.opendocument.formula',
				'otf' => 'application/vnd.oasis.opendocument.formula-template',
				'odg' => 'application/vnd.oasis.opendocument.graphics',
				'otg' => 'application/vnd.oasis.opendocument.graphics-template',
				'odi' => 'application/vnd.oasis.opendocument.image',
				'oti' => 'application/vnd.oasis.opendocument.image-template',
				'odp' => 'application/vnd.oasis.opendocument.presentation',
				'otp' => 'application/vnd.oasis.opendocument.presentation-template',
				'ods' => 'application/vnd.oasis.opendocument.spreadsheet',
				'ots' => 'application/vnd.oasis.opendocument.spreadsheet-template',
				'odt' => 'application/vnd.oasis.opendocument.text',
				'otm' => 'application/vnd.oasis.opendocument.text-master',
				'ott' => 'application/vnd.oasis.opendocument.text-template',
				'oth' => 'application/vnd.oasis.opendocument.text-web',

				//VCards...
				'vcf' => 'text/vcard',
				'ics' => 'text/calendar',
		);

		//Si la extensin se contempla en nuestro vector de tipos...
		if (array_key_exists($fileExtension, $mime_types))
		{
			$tipoMime = $mime_types[$fileExtension];
		}
		else //En cualquier otro caso, lo servimos como binario...
		{
			$tipoMime = 'application/octet-stream';
		}
		return $tipoMime;
	}//Fin getMimeType


	/**
	 * Devuelve el contenido de una URL de peticion de Alfresco (documento completo)
	 * @param string $url URL a abrir
	 * @param array $options Array de opciones adicionales
	 * @return string Doocumento (completo)
	 * @throws \Exception
	 */
	public function urlGetContents ($url, $options = null)
	{
		$output = null;
		if ($this->curlEnabled === true)//Por CURLS
		{
			$ch = curl_init();
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_FAILONERROR, TRUE); // To fail silently if the HTTP code returned is greater than or equal to 400.
			curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE); // To follow any "Location: " header that the server sends as part of the HTTP header.
			curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE); // To automatically set the Referer: field in requests where it follows a Location: redirect.
			curl_setopt($ch, CURLOPT_TIMEOUT, $this->timeout); // The maximum number of seconds to allow cURL functions to execute.
			curl_setopt($ch, CURLOPT_MAXREDIRS, 5); // The maximum number of redirects
			$output = curl_exec($ch);

			if($output === false)
			{
				$errorMsg = 'ERROR CURL: Sin acceso a '.$url.' : ' . curl_error($ch);
				throw new \Exception(__CLASS__.'::'.__METHOD__.": $errorMsg");
			}
			curl_close($ch);
		}
		else
		{
			$output = file_get_contents($url, false, $options);
			if ($output === false)
			{
				$errorMsg = 'ERROR file_get_content(). Sin acceso a '.$url.' : ' .print_r($errorMsg, true);
				throw new \Exception(__CLASS__.'::'.__METHOD__.': '.$errorMsg);
			}
		}
		return $output;
	}//urlGetContents


	/**
	 * Dada una URL de Alfresco crea un fichero (temporal) con el contenido. Devuelve el nombre de fichero
	 *
	 * En el caso de grandes descargas, este mtodo consume menos memoria.
	 *
	 * @param string $url URL a abrir
	 * @param string $tmp Directorio temporal para gestin de ficheros. Si no se indica sys_get_temp_dir()
	 * @return string Nombre del fichero con el contenido
	 * @throws \Exception
	 */
	public function urlGetContentInFile($url, $tmp=null)
	{
		set_time_limit($this->timeout);
		if (empty($tmp))
		{
			$tmp = sys_get_temp_dir();
		}
		$file = tempnam($tmp, 'GDE');
		$fdOut = fopen($file, 'w');
		if ($fdOut === false)
		{
			$errorMsg = "ERROR DE ESCRITURA ESCRITURA fopen($file). ";
			throw new \Exception(__CLASS__.'::'.__METHOD__.': '.$errorMsg);
		}
		if (($this->curlEnabled === true))
		{
			$ch = curl_init();
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_FILE, $fdOut);
			curl_setopt($ch, CURLOPT_FAILONERROR, TRUE); // To fail silently if the HTTP code returned is greater than or equal to 400.
			curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE); // To follow any "Location: " header that the server sends as part of the HTTP header.
			curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE); // To automatically set the Referer: field in requests where it follows a Location: redirect.
			curl_setopt($ch, CURLOPT_TIMEOUT, $this->timeout); // The maximum number of seconds to allow cURL functions to execute.
			curl_setopt($ch, CURLOPT_MAXREDIRS, 7); // The maximum number of redirects
			set_time_limit($this->timeout);
			$output = curl_exec($ch);
			if($output === false)
			{
				$errorMsg = 'ERROR CURL: Sin acceso a '.$url.' : ' . curl_error($ch);
				throw new \Exception(__CLASS__.'::'.__METHOD__.": $errorMsg");
			}
			curl_close($ch);
		}
		else
		{
			$options = array
			(
				'http' => array
				(
					'user_agent'	=> 'WSCOMUN',
					'max_redirects'	=> 7,
					'timeout'	=> $this->timeout,
				)
				,'ssl' => array
				(
					'verify_peer' => false,
					'verify_peer_name' => false,
					'allow_self_signed' => true
				)
				,'https' => array
				(
					'user_agent'	=> 'WSCOMUN',
					'max_redirects'	=> 7,
					'timeout'	=> $this->timeout,
				)
			);
			$contexto = stream_context_create($options);

			$source = fopen($url, 'r', false, $contexto);
			if ($source === false)
			{
				$errorMsg = 'ERROR LECTURA con fopen(). Sin acceso a '.$url.' : ' .print_r($errorMsg, true);
				throw new \Exception(__CLASS__.'::'.__METHOD__.': '.$errorMsg);
			}

			while (!feof($source))
			{
				set_time_limit($this->timeout);
				fwrite($fdOut, fread($source, 1024));
			}
			fclose($source);
		}
		fclose($fdOut);
		return $file;
	}//urlGetContentInFile



}//End AlfrescoClient