<?php
namespace WSCOMUN\INE\VERIFICACION_RESIDENCIA;

use Exception;
use SoapVar;
use ArrayObject;
use stdClass;


const unbounded = 'unbounded';


class objSolicitudTransmision
{
	/**
	 * Contantes para los NS
	 */
	private static $NAMESPACE_ESP  = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	private static $NAMESPACE_PET  = 'http://intermediacion.redsara.es/scsp/esquemas/V3/peticion';
	private static $NAMESPACE_SR   = 'http://intermediacion.redsara.es/scsp/esquemas/V3/solicitudRespuesta';
	private static $NAMESPACE_RESP = 'http://intermediacion.redsara.es/scsp/esquemas/V3/respuesta';

	/**
	 * @var String
	 * Nif del Emisor
	 */
	private $nifEmisor = null;

	/**
	 * @var String
	 * Nombre o razn social del emisor
	 */
	private $nombreEmisor = null;

	/**
	 * @var String
	 * Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $codProcedimiento = null;

	/**
	 * @var String
	 * Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $nombreProcedimiento = null;

	/**
	 * @var String
	 * Nombre completo del empleado pblico que realiza la solicitud.
	 */
	private $nombreCompletoFuncionario = null;

	/**
	 * @var String
	 * NIF del empleado pblico que realiza la solicitud.
	 */
	private $nifFuncionario = null;

	/**
	 * @var String
	 * Documentacin identificativa del titular. Puede ser: NIF, NIE, CIF
	 */
	private $tipoDocumentacion = null;

	/**
	 * @var String
	 * Nmero de documento segn el <TipoDocumentacion>
	 */
	private $documentacion = null;

	/**
	 * @var String
	 * Nombre completo del titular de la solicitud
	 */
	private $nombreCompleto = null;

	/**
	 * @var String
	 * Nombre del titular de la solicitud
	 */
	private $nombre = null;

	/**
	 * @var String
	 * Primer Apellido del titular de la solicitud
	 */
	private $apellido1 = null;

	/**
	 * @var String
	 * Segundo Apellido del titular de la solicitud
	 */
	private $apellido2 = null;

	/**
	 * @var String
	 * NIF del organismo
	 */
	private $identificadorSolicitante = null;

	/**
	 * @var String
	 * Nombre o razn social del organismo
	 */
	private $nombreSolicitante = null;

	/**
	 * @var String
	 * Nombre de la Unidad Tramitadora que realiza la peticin
	 */
	private $unidadTramitadora = null;

	/**
	 * @var String
	 * Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 */
	private $finalidad = null;

	/**
	 * @var String
	 * Valores admitidos: Si, Ley
	 */
	private $consentimiento = null;

	/**
	 * @var String
	 * Identificador del Expediente que justifica la consulta.
	 */
	private $idExpediente = null;

	/**
	 * @var string 
	 * Indica si la persona de la que se verifican los datos es de nacionalidad espaola (s/n)
	 */
	private $espanol = null;

	/**
	 * @var string
	 * Cdigo INE de la Provincia en la que reside el ciudadano
	 */
	private $provinciaResidencia = null;

	/**
	 * @var string
	 * Cdigo INE del Municipio de residencia del ciudadano
	 */
	private $municipioResidencia = null;

	/**
	 * @var string
	 * Fecha de nacimiento del ciudadano (Formato: AAAAMMDD)
	 */
	private $fechaNacimiento = null;

	/**
	 * @var string
	 * Cdigo INE de la Provincia de nacimiento del ciudadano (66=extranjero)
	 */
	private $provinciaNacimiento = null;

	/**
	 * @var string
	 * Cdigo INE del Municipio de nacimiento del ciudadano (o INE de pas para extranjeros)
	 */
	private $municipioNacimiento = null;



	/**
	 * Establece los especificos de la consulta
	 *
	 * @access	public
	 * @param string $espanol Indica si la persona de la que se verifican los datos es de nacionalidad espaola (s/n)
	 * @param string $provinciaResidencia Cdigo INE de la Provincia en la que reside el ciudadano
	 * @param string $municipioResidencia Cdigo INE del Municipio de residencia del ciudadano
	 * @param string $fechaNacimiento Fecha de nacimiento del ciudadano (Formato: AAAAMMDD)
	 * @param string $provinciaNacimiento Cdigo INE de la Provincia de nacimiento del ciudadano (66=extranjero)
	 * @param string $municipioNacimiento Cdigo INE del Municipio de nacimiento del ciudadano (o INE de pas para extranjeros)
	 */
	public function setDatosEspecificos($espanol, $provinciaResidencia = null, $municipioResidencia = null, $fechaNacimiento = null, $provinciaNacimiento = null, $municipioNacimiento = null) {
		$this->espanol = $espanol;
		$this->provinciaResidencia = $provinciaResidencia;
		$this->municipioResidencia = $municipioResidencia;
		$this->fechaNacimiento = $fechaNacimiento;
		$this->provinciaNacimiento = $provinciaNacimiento;
		$this->municipioNacimiento = $municipioNacimiento;
	}

	/**
	 * Establece los datos del organismo emisor que ofrece el servicio.
	 *
	 * @access	public
	 * @param String $nif Nif del Emisor
	 * @param String $nombre Nombre o razn social del emisor
	 */
	public function setEmisor($nif, $nombre) {
		$this->nifEmisor = $nif;
		$this->nombreEmisor = $nombre;
	}

	/**
	 * Establece los datos del procedimiento que autoriza la consulta.
	 *
	 * @access	public
	 * @param String $codigo Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 * @param String $nombre Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	public function setProcedimiento($codigo, $nombre) {
		$this->codProcedimiento = $codigo;
		$this->nombreProcedimiento = $nombre;
	}

	/**
	 * Establece los datos del empleado pblico que realiza la solicitud.
	 *
	 * @access	public
	 * @param String $nombreCompleto Nombre completo del empleado pblico que realiza la solicitud.
	 * @param String $nif NIF del empleado pblico que realiza la solicitud.
	 */
	public function setFuncionario($nombreCompleto, $nif) {
		$this->nombreCompletoFuncionario = $nombreCompleto;
		$this->nifFuncionario = $nif;
	}

	/**
	 * Establece los datos del ciudadano sobre el que se va a realizar la consulta.
	 *
	 * @access	public
	 * @param String $tipoDocumentacion Documentacin identificativa del titular. Puede ser: NIF, NIE, CIF
	 * @param String $documentacion Nmero de documento segn el tipo de documentacin indicado.
	 * @param String $nombreCompleto Nombre completo del titular de la solicitud
	 * @param String $nombre Nombre del titular de la solicitud
	 * @param String $apellido1 Primer Apellido del titular de la solicitud
	 * @param String $apellido2 Segundo Apellido del titular de la solicitud
	 */
	public function setTitular($tipoDocumentacion, $documentacion, $nombreCompleto = null, $nombre = null, $apellido1 = null, $apellido2 = null) {
		$this->tipoDocumentacion = $tipoDocumentacion;
		$this->documentacion = $documentacion;
		$this->nombreCompleto = $nombreCompleto;
		$this->nombre = $nombre;
		$this->apellido1 = $apellido1;
		$this->apellido2 = $apellido2;
	}

	/**
	 * Establece los datos del solicitante de la transmisin, as como la finalidad del mismo.
	 *
	 * @access	public
	 * @param String $identificadorSolicitante NIF del organismo solicitante
	 * @param String $nombreSolicitante Nombre o razn social del organismo solicitante
	 * @param String $consentimiento Valores admitidos: Si, Ley
	 * @param String $finalidad Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 * @param String $unidadTramitadora Nombre de la Unidad Tramitadora que realiza la peticin
	 * @param String $idExpediente Identificador del Expediente que justifica la consulta.
	 */
	public function setSolicitante($identificadorSolicitante, $nombreSolicitante, $consentimiento, $finalidad, $unidadTramitadora = null, $idExpediente = null) {
		$this->identificadorSolicitante = $identificadorSolicitante;
		$this->nombreSolicitante = $nombreSolicitante;
		$this->consentimiento = $consentimiento;
		$this->finalidad = $finalidad;
		$this->unidadTramitadora = $unidadTramitadora;
		$this->idExpediente = $idExpediente;
	}


	/**
	 * Devuelve una copia del objeto, que mantiene los datos generales de la peticin: Emisor, procedimiento, funcionario, titular y solicitante
	 *
	 * @access	public
	 * @return	objSolicitudTransmision	Nueva instancia con los datos copiados
	 */
	public function duplicarCabecera() {
		$oClon = new objSolicitudTransmision();
		$oClon->setEmisor($this->nifEmisor, $this->nombreEmisor);
		$oClon->setProcedimiento($this->codProcedimiento, $this->nombreProcedimiento);
		$oClon->setFuncionario($this->nombreCompletoFuncionario, $this->nifFuncionario);
		$oClon->setTitular($this->tipoDocumentacion, $this->documentacion, $this->nombreCompleto, $this->nombre, $this->apellido1, $this->apellido2);
		$oClon->setSolicitante($this->identificadorSolicitante, $this->nombreSolicitante, $this->consentimiento, $this->finalidad, $this->unidadTramitadora, $this->idExpediente);

		return $oClon;
	}


	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @access 	public
	 * @param string $IdPeticion Identificador de la peticin
	 * @param string $CodigoCertificado Cdigo del certificado del servicio que solicita la peticion
	 * @param string $numParcial Subidentificador de la peticin. Cuando se suministra, se concatena al identificador de la peticion.
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 */
	public function toSoap($IdPeticion, $CodigoCertificado, $numParcial = null)
	{
		$IdSolicitud = $IdPeticion;
		if (!is_null($numParcial)) {
			$IdSolicitud = $IdPeticion . '_' . $numParcial;
		}

		// $CodigoCertificado debera ser auto-generado
		// IdentificadorSolicitante = (Sugerido) CODxxxxxx
		// Consentimiento = Si | Ley
		// TipoDocumentacion = NIF | CIF | DNI | Pasaporte | NIE

		// Emisor
		$EmisorWSRequest = new ArrayObject();
		$EmisorWSRequest->append(new SoapVar($this->nifEmisor, XSD_STRING, null, null,'NifEmisor', self::$NAMESPACE_PET));
		$EmisorWSRequest->append(new SoapVar($this->nombreEmisor, XSD_STRING, null, null,'NombreEmisor', self::$NAMESPACE_PET));

		// Procedimiento
		$ProcedimientoWSRequest = new ArrayObject();
		$ProcedimientoWSRequest->append(new SoapVar($this->codProcedimiento, XSD_STRING, null, null,'CodProcedimiento', self::$NAMESPACE_PET));
		$ProcedimientoWSRequest->append(new SoapVar($this->nombreProcedimiento, XSD_STRING, null, null,'NombreProcedimiento', self::$NAMESPACE_PET));

		// Funcionario
		$FuncionarioWSRequest = new ArrayObject();
		$FuncionarioWSRequest->append(new SoapVar($this->nombreCompletoFuncionario, XSD_STRING, null, null,'NombreCompletoFuncionario', self::$NAMESPACE_PET));
		$FuncionarioWSRequest->append(new SoapVar($this->nifFuncionario, XSD_STRING, null, null,'NifFuncionario', self::$NAMESPACE_PET));

		// Solicitante
		$SolicitanteWSRequest = new ArrayObject();
		$SolicitanteWSRequest->append(new SoapVar($this->identificadorSolicitante, XSD_STRING, null, null,'IdentificadorSolicitante', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->nombreSolicitante, XSD_STRING, null, null,'NombreSolicitante', self::$NAMESPACE_PET));
		if (!is_null($this->unidadTramitadora)) {
			$SolicitanteWSRequest->append(new SoapVar($this->unidadTramitadora, XSD_STRING, null, null,'UnidadTramitadora', self::$NAMESPACE_PET));
		}
		$SolicitanteWSRequest->append(new SoapVar($ProcedimientoWSRequest, SOAP_ENC_OBJECT,null,null,'Procedimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->finalidad, XSD_STRING, null, null,'Finalidad', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->consentimiento, XSD_STRING, null, null,'Consentimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($FuncionarioWSRequest, SOAP_ENC_OBJECT,null,null,'Funcionario', self::$NAMESPACE_PET));
		if (!is_null($this->idExpediente)) {
			$SolicitanteWSRequest->append(new SoapVar($this->idExpediente, XSD_STRING, null, null,'IdExpediente', self::$NAMESPACE_PET));
		}

		// Titular
		$TitularWSRequest = new ArrayObject();
		$TitularWSRequest->append(new SoapVar($this->tipoDocumentacion, XSD_STRING, null, null,'TipoDocumentacion', self::$NAMESPACE_PET));
		$TitularWSRequest->append(new SoapVar($this->documentacion, XSD_STRING, null, null,'Documentacion', self::$NAMESPACE_PET));
		if (!is_null($this->nombreCompleto)) {
			$TitularWSRequest->append(new SoapVar($this->nombreCompleto, XSD_STRING, null, null,'NombreCompleto', self::$NAMESPACE_PET));
		}
		if (!is_null($this->nombre)) {
			$TitularWSRequest->append(new SoapVar($this->nombre, XSD_STRING, null, null,'Nombre', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido1)) {
			$TitularWSRequest->append(new SoapVar($this->apellido1, XSD_STRING, null, null,'Apellido1', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido2)) {
			$TitularWSRequest->append(new SoapVar($this->apellido2, XSD_STRING, null, null,'Apellido2', self::$NAMESPACE_PET));
		}

		// Transmision
		$TransmisionWSRequest = new ArrayObject();
		$TransmisionWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_PET));
		$TransmisionWSRequest->append(new SoapVar($IdSolicitud, XSD_STRING, null, null,'IdSolicitud', self::$NAMESPACE_PET));

		// DatosGenericos
		$DatosGenericosWSRequest = new ArrayObject();
		$DatosGenericosWSRequest->append(new SoapVar($EmisorWSRequest, SOAP_ENC_OBJECT,null,null,'Emisor', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($SolicitanteWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitante', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TitularWSRequest, SOAP_ENC_OBJECT,null,null,'Titular', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'Transmision', self::$NAMESPACE_PET));

		// DatosGenericos
		$DatosEspecificosWSRequest = new ArrayObject();
		
		$oSolicitud = new Solicitud();
		$oSolicitud->setEspanol($this->espanol);
		if (!is_null($this->provinciaResidencia) && !is_null($this->provinciaResidencia)) {
			$oResidencia = new Residencia();
			$oSolicitud->setResidencia($oResidencia);
			
			if (!is_null($this->provinciaResidencia)) {
				$oResidencia->setProvincia($this->provinciaResidencia);
			}
			if (!is_null($this->municipioResidencia)) {
				$oResidencia->setMunicipio($this->municipioResidencia);
			}
		}
		
		if (!is_null($this->fechaNacimiento) && !is_null($this->provinciaNacimiento) && !is_null($this->municipioNacimiento)) { 
			$oNacimiento = new Nacimiento();
			$oSolicitud->setNacimiento($oNacimiento);
			
			if (!is_null($this->fechaNacimiento)) {
				$oNacimiento->setFecha($this->fechaNacimiento);
			}
			if (!is_null($this->provinciaNacimiento)) {
				$oNacimiento->setProvincia($this->provinciaNacimiento);
			}
			if (!is_null($this->municipioNacimiento)) {
				$oNacimiento->setMunicipio($this->municipioNacimiento);
			}
		}

		$DatosEspecificosWSRequest->append( $oSolicitud->toSoap('Solicitud', self::$NAMESPACE_ESP) );
		
		// SolicitudTransmision
		$SolicitudTransmisionWSRequest = new ArrayObject();
		$SolicitudTransmisionWSRequest->append(new SoapVar($DatosGenericosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosGenericos', self::$NAMESPACE_PET));
		$SolicitudTransmisionWSRequest->append(new SoapVar($DatosEspecificosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosEspecificos', self::$NAMESPACE_ESP));

		// Devuelve la solicitud ya generada
		return new SoapVar($SolicitudTransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudTransmision', self::$NAMESPACE_PET);
	}

}


class SoapObject
{
	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new \stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array


	private function __anyType_SoapVar($childData, $fieldName, $namespace) {
		//var_dump($childData);
		if (is_a($childData, 'DateTime')) {
			//var_dump($childData);
			//die('DateTime: ' . $fieldName);
			return new \SoapVar($childData->format(\DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		} elseif (is_int($childData)) {
			//die('Integer: ' . $fieldName);
			return new \SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}

		//die('Generic: ' . $fieldName);
		return new \SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}

	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace) {
		switch ($basicType) {
			case XSD_DATETIME:
				return new \SoapVar($childData->format(\DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);

			default:
				return new \SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $value, $fieldName, $type, $namespace, $minOccurs, $maxOccurs)
	{
		//echo("__doChild: $type [$fieldName]<br>");
		$fieldSet = isset($value);
		if (!$fieldSet) {
			if ($minOccurs > 0) {
				throw new \Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			} else {
				return true;
			}
		}

		$vChildData = $value;
		if ($maxOccurs == 1) {
			$vChildData = array( $value );
		} else {
			if ($maxOccurs != 'unbounded') {
				if ($maxOccurs > sizeof($vChildData)) {
					throw new \Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			} else {
				//				var_dump($vChildData);die;
			}
		}

		//var_dump(array_keys($vChildData));
		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++) {
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet) {
				if (is_int($type) && $type != SOAP_ENC_OBJECT) {

					$basicType = $type;
					//echo("Basic: $type | $basicType [$fieldName]<br>");
					if ($basicType !== XSD_ANYTYPE) {
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					} else {
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append( $childSOAP );
					//					return true;

				} else { //if (isset($this->$funcName)) {
					$childSOAP = $childData->toSoap($fieldName, $namespace);
					$parentTag->append( $childSOAP );
					//					return true;
				}
			} else {
				return false;
			}

		}

		// TODO: HACER EL MULTIAPARICION!!!
		/*
		 var_dump($parentTag);
		 var_dump($vData);
		 var_dump($fieldName);
		 var_dump($type);
		 var_dump($namespace);
		 var_dump($minOccurs);
		 var_dump($maxOccurs);

		 die("FAIL!!!");
		 */

		return true;
	}



	static public function is_assoc($array) {
		foreach(array_keys($array) as $key) {
			if (!is_int($key)) return true;
		}
		return false;
	}

	static public function endsWith($haystack, $needle) {
		// search forward starting from end minus needle length characters
		return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
	}
}








class DatosEspecificos extends SoapObject {


	/**
	 * @var Retorno Propiedad de navegacion entre objetos SOAP
	 * name="Retorno" type="Retorno"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_retorno = null;
	private $_hasRetorno = false;
	public function setRetorno($value) {
		$this->_retorno = $value;
		$this->_hasRetorno = ($value !== null);
	}
	public function hasRetorno() {
		return $this->_hasRetorno;
	}
	public function getRetorno() {
		return $this->_retorno;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DatosEspecificos con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DatosEspecificos 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DatosEspecificos();
		if (!isset($vData['Retorno'])) {
			throw new Exception('El parametro Retorno es obligatorio');
		}
		if (isset($vData['Retorno'])) {

			$newClass = Retorno::fromSoap($vData['Retorno']);
			$newItem->setRetorno($newClass);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_retorno, 'Retorno', SOAP_ENC_OBJECT, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	


class Consulta extends SoapObject {
	

	/**
	 *
	 * Devuelve una instancia de la clase Consulta con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Consulta 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Consulta(); 

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();


		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Retorno extends SoapObject {
	

	/**
	 * @var Estado Propiedad de navegacion entre objetos SOAP
	 * name="Estado" type="Estado"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_estado = null;
	private $_hasEstado = false;
	public function setEstado($value) {
		$this->_estado = $value;
		$this->_hasEstado = ($value !== null);
	}
	public function hasEstado() {
		return $this->_hasEstado;
	}
	public function getEstado() {
		return $this->_estado;
	}


	/**
	 * @var Domicilio Propiedad de navegacion entre objetos SOAP
	 * name="Domicilio" type="Domicilio"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_domicilio = null;
	private $_hasDomicilio = false;
	public function setDomicilio($value) {
		$this->_domicilio = $value;
		$this->_hasDomicilio = ($value !== null);
	}
	public function hasDomicilio() {
		return $this->_hasDomicilio;
	}
	public function getDomicilio() {
		return $this->_domicilio;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Retorno con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Retorno 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Retorno(); 
		if (!isset($vData['Estado'])) {
			throw new Exception('El parametro Estado es obligatorio');
		}
		if (isset($vData['Estado'])) {
		
			$newClass = Estado::fromSoap($vData['Estado']);
			$newItem->setEstado($newClass);
		}
		if (isset($vData['Domicilio'])) {
		
			$newClass = Domicilio::fromSoap($vData['Domicilio']);
			$newItem->setDomicilio($newClass);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_estado, 'Estado', SOAP_ENC_OBJECT, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_domicilio, 'Domicilio', SOAP_ENC_OBJECT, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Estado extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="CodigoEstado" type="CodigoEstado"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_codigoEstado = null;
	private $_hasCodigoEstado = false;
	public function setCodigoEstado($value) {
		$this->_codigoEstado = $value;
		$this->_hasCodigoEstado = ($value !== null);
	}
	public function hasCodigoEstado() {
		return $this->_hasCodigoEstado;
	}
	public function getCodigoEstado() {
		return $this->_codigoEstado;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="CodigoEstadoSecundario" type="CodigoEstadoSecundario"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_codigoEstadoSecundario = null;
	private $_hasCodigoEstadoSecundario = false;
	public function setCodigoEstadoSecundario($value) {
		$this->_codigoEstadoSecundario = $value;
		$this->_hasCodigoEstadoSecundario = ($value !== null);
	}
	public function hasCodigoEstadoSecundario() {
		return $this->_hasCodigoEstadoSecundario;
	}
	public function getCodigoEstadoSecundario() {
		return $this->_codigoEstadoSecundario;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="LiteralError" type="LiteralError"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_literalError = null;
	private $_hasLiteralError = false;
	public function setLiteralError($value) {
		$this->_literalError = $value;
		$this->_hasLiteralError = ($value !== null);
	}
	public function hasLiteralError() {
		return $this->_hasLiteralError;
	}
	public function getLiteralError() {
		return $this->_literalError;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Estado con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Estado 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Estado(); 
		if (isset($vData['CodigoEstado'])) {
		
			$newItem->setCodigoEstado($vData['CodigoEstado']);
		}
		if (isset($vData['CodigoEstadoSecundario'])) {
		
			$newItem->setCodigoEstadoSecundario($vData['CodigoEstadoSecundario']);
		}
		if (isset($vData['LiteralError'])) {
		
			$newItem->setLiteralError($vData['LiteralError']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoEstado, 'CodigoEstado', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_codigoEstadoSecundario, 'CodigoEstadoSecundario', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_literalError, 'LiteralError', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Domicilio extends SoapObject {
	

	/**
	 * @var ProvinciaRespuesta Propiedad de navegacion entre objetos SOAP
	 * name="ProvinciaRespuesta" type="ProvinciaRespuesta"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_provinciaRespuesta = null;
	private $_hasProvinciaRespuesta = false;
	public function setProvinciaRespuesta($value) {
		$this->_provinciaRespuesta = $value;
		$this->_hasProvinciaRespuesta = ($value !== null);
	}
	public function hasProvinciaRespuesta() {
		return $this->_hasProvinciaRespuesta;
	}
	public function getProvinciaRespuesta() {
		return $this->_provinciaRespuesta;
	}


	/**
	 * @var MunicipioRespuesta Propiedad de navegacion entre objetos SOAP
	 * name="MunicipioRespuesta" type="MunicipioRespuesta"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_municipioRespuesta = null;
	private $_hasMunicipioRespuesta = false;
	public function setMunicipioRespuesta($value) {
		$this->_municipioRespuesta = $value;
		$this->_hasMunicipioRespuesta = ($value !== null);
	}
	public function hasMunicipioRespuesta() {
		return $this->_hasMunicipioRespuesta;
	}
	public function getMunicipioRespuesta() {
		return $this->_municipioRespuesta;
	}


	/**
	 * @var EntColectiva Propiedad de navegacion entre objetos SOAP
	 * name="EntColectiva" type="EntColectiva"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_entColectiva = null;
	private $_hasEntColectiva = false;
	public function setEntColectiva($value) {
		$this->_entColectiva = $value;
		$this->_hasEntColectiva = ($value !== null);
	}
	public function hasEntColectiva() {
		return $this->_hasEntColectiva;
	}
	public function getEntColectiva() {
		return $this->_entColectiva;
	}


	/**
	 * @var EntSingular Propiedad de navegacion entre objetos SOAP
	 * name="EntSingular" type="EntSingular"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_entSingular = null;
	private $_hasEntSingular = false;
	public function setEntSingular($value) {
		$this->_entSingular = $value;
		$this->_hasEntSingular = ($value !== null);
	}
	public function hasEntSingular() {
		return $this->_hasEntSingular;
	}
	public function getEntSingular() {
		return $this->_entSingular;
	}


	/**
	 * @var Nucleo Propiedad de navegacion entre objetos SOAP
	 * name="Nucleo" type="Nucleo"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_nucleo = null;
	private $_hasNucleo = false;
	public function setNucleo($value) {
		$this->_nucleo = $value;
		$this->_hasNucleo = ($value !== null);
	}
	public function hasNucleo() {
		return $this->_hasNucleo;
	}
	public function getNucleo() {
		return $this->_nucleo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="CodUnidadPoblacional" type="CodUnidadPoblacional"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_codUnidadPoblacional = null;
	private $_hasCodUnidadPoblacional = false;
	public function setCodUnidadPoblacional($value) {
		$this->_codUnidadPoblacional = $value;
		$this->_hasCodUnidadPoblacional = ($value !== null);
	}
	public function hasCodUnidadPoblacional() {
		return $this->_hasCodUnidadPoblacional;
	}
	public function getCodUnidadPoblacional() {
		return $this->_codUnidadPoblacional;
	}


	/**
	 * @var Direccion Propiedad de navegacion entre objetos SOAP
	 * name="Direccion" type="Direccion"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_direccion = null;
	private $_hasDireccion = false;
	public function setDireccion($value) {
		$this->_direccion = $value;
		$this->_hasDireccion = ($value !== null);
	}
	public function hasDireccion() {
		return $this->_hasDireccion;
	}
	public function getDireccion() {
		return $this->_direccion;
	}


	/**
	 * @var UltimaVariacion Propiedad de navegacion entre objetos SOAP
	 * name="UltimaVariacion" type="UltimaVariacion"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_ultimaVariacion = null;
	private $_hasUltimaVariacion = false;
	public function setUltimaVariacion($value) {
		$this->_ultimaVariacion = $value;
		$this->_hasUltimaVariacion = ($value !== null);
	}
	public function hasUltimaVariacion() {
		return $this->_hasUltimaVariacion;
	}
	public function getUltimaVariacion() {
		return $this->_ultimaVariacion;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Domicilio con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Domicilio 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Domicilio(); 
		if (isset($vData['ProvinciaRespuesta'])) {
		
			$newClass = ProvinciaRespuesta::fromSoap($vData['ProvinciaRespuesta']);
			$newItem->setProvinciaRespuesta($newClass);
		}
		if (isset($vData['MunicipioRespuesta'])) {
		
			$newClass = MunicipioRespuesta::fromSoap($vData['MunicipioRespuesta']);
			$newItem->setMunicipioRespuesta($newClass);
		}
		if (isset($vData['EntColectiva'])) {
		
			$newClass = EntColectiva::fromSoap($vData['EntColectiva']);
			$newItem->setEntColectiva($newClass);
		}
		if (isset($vData['EntSingular'])) {
		
			$newClass = EntSingular::fromSoap($vData['EntSingular']);
			$newItem->setEntSingular($newClass);
		}
		if (isset($vData['Nucleo'])) {
		
			$newClass = Nucleo::fromSoap($vData['Nucleo']);
			$newItem->setNucleo($newClass);
		}
		if (isset($vData['CodUnidadPoblacional'])) {
		
			$newItem->setCodUnidadPoblacional($vData['CodUnidadPoblacional']);
		}
		if (isset($vData['Direccion'])) {
		
			$newClass = Direccion::fromSoap($vData['Direccion']);
			$newItem->setDireccion($newClass);
		}
		if (isset($vData['UltimaVariacion'])) {
		
			$newClass = UltimaVariacion::fromSoap($vData['UltimaVariacion']);
			$newItem->setUltimaVariacion($newClass);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_provinciaRespuesta, 'ProvinciaRespuesta', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_municipioRespuesta, 'MunicipioRespuesta', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_entColectiva, 'EntColectiva', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_entSingular, 'EntSingular', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_nucleo, 'Nucleo', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_codUnidadPoblacional, 'CodUnidadPoblacional', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_direccion, 'Direccion', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_ultimaVariacion, 'UltimaVariacion', SOAP_ENC_OBJECT, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class ProvinciaRespuesta extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Codigo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_codigo = null;
	private $_hasCodigo = false;
	public function setCodigo($value) {
		$this->_codigo = $value;
		$this->_hasCodigo = ($value !== null);
	}
	public function hasCodigo() {
		return $this->_hasCodigo;
	}
	public function getCodigo() {
		return $this->_codigo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Nombre" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_nombre = null;
	private $_hasNombre = false;
	public function setNombre($value) {
		$this->_nombre = $value;
		$this->_hasNombre = ($value !== null);
	}
	public function hasNombre() {
		return $this->_hasNombre;
	}
	public function getNombre() {
		return $this->_nombre;
	}


	/**
	 *
	 * Devuelve una instancia de la clase ProvinciaRespuesta con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	ProvinciaRespuesta 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new ProvinciaRespuesta(); 
		if (!isset($vData['Codigo'])) {
			throw new Exception('El parametro Codigo es obligatorio');
		}
		if (isset($vData['Codigo'])) {
		
			$newItem->setCodigo($vData['Codigo']);
		}
		if (!isset($vData['Nombre'])) {
			throw new Exception('El parametro Nombre es obligatorio');
		}
		if (isset($vData['Nombre'])) {
		
			$newItem->setNombre($vData['Nombre']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_nombre, 'Nombre', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class MunicipioRespuesta extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Codigo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_codigo = null;
	private $_hasCodigo = false;
	public function setCodigo($value) {
		$this->_codigo = $value;
		$this->_hasCodigo = ($value !== null);
	}
	public function hasCodigo() {
		return $this->_hasCodigo;
	}
	public function getCodigo() {
		return $this->_codigo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Nombre" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_nombre = null;
	private $_hasNombre = false;
	public function setNombre($value) {
		$this->_nombre = $value;
		$this->_hasNombre = ($value !== null);
	}
	public function hasNombre() {
		return $this->_hasNombre;
	}
	public function getNombre() {
		return $this->_nombre;
	}


	/**
	 *
	 * Devuelve una instancia de la clase MunicipioRespuesta con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	MunicipioRespuesta 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new MunicipioRespuesta(); 
		if (!isset($vData['Codigo'])) {
			throw new Exception('El parametro Codigo es obligatorio');
		}
		if (isset($vData['Codigo'])) {
		
			$newItem->setCodigo($vData['Codigo']);
		}
		if (!isset($vData['Nombre'])) {
			throw new Exception('El parametro Nombre es obligatorio');
		}
		if (isset($vData['Nombre'])) {
		
			$newItem->setNombre($vData['Nombre']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_nombre, 'Nombre', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class EntColectiva extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Codigo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_codigo = null;
	private $_hasCodigo = false;
	public function setCodigo($value) {
		$this->_codigo = $value;
		$this->_hasCodigo = ($value !== null);
	}
	public function hasCodigo() {
		return $this->_hasCodigo;
	}
	public function getCodigo() {
		return $this->_codigo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Nombre" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_nombre = null;
	private $_hasNombre = false;
	public function setNombre($value) {
		$this->_nombre = $value;
		$this->_hasNombre = ($value !== null);
	}
	public function hasNombre() {
		return $this->_hasNombre;
	}
	public function getNombre() {
		return $this->_nombre;
	}


	/**
	 *
	 * Devuelve una instancia de la clase EntColectiva con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	EntColectiva 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new EntColectiva(); 
		if (!isset($vData['Codigo'])) {
			throw new Exception('El parametro Codigo es obligatorio');
		}
		if (isset($vData['Codigo'])) {
		
			$newItem->setCodigo($vData['Codigo']);
		}
		if (!isset($vData['Nombre'])) {
			throw new Exception('El parametro Nombre es obligatorio');
		}
		if (isset($vData['Nombre'])) {
		
			$newItem->setNombre($vData['Nombre']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_nombre, 'Nombre', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class EntSingular extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Codigo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_codigo = null;
	private $_hasCodigo = false;
	public function setCodigo($value) {
		$this->_codigo = $value;
		$this->_hasCodigo = ($value !== null);
	}
	public function hasCodigo() {
		return $this->_hasCodigo;
	}
	public function getCodigo() {
		return $this->_codigo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Nombre" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_nombre = null;
	private $_hasNombre = false;
	public function setNombre($value) {
		$this->_nombre = $value;
		$this->_hasNombre = ($value !== null);
	}
	public function hasNombre() {
		return $this->_hasNombre;
	}
	public function getNombre() {
		return $this->_nombre;
	}


	/**
	 *
	 * Devuelve una instancia de la clase EntSingular con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	EntSingular 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new EntSingular(); 
		if (!isset($vData['Codigo'])) {
			throw new Exception('El parametro Codigo es obligatorio');
		}
		if (isset($vData['Codigo'])) {
		
			$newItem->setCodigo($vData['Codigo']);
		}
		if (!isset($vData['Nombre'])) {
			throw new Exception('El parametro Nombre es obligatorio');
		}
		if (isset($vData['Nombre'])) {
		
			$newItem->setNombre($vData['Nombre']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_nombre, 'Nombre', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Nucleo extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Codigo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_codigo = null;
	private $_hasCodigo = false;
	public function setCodigo($value) {
		$this->_codigo = $value;
		$this->_hasCodigo = ($value !== null);
	}
	public function hasCodigo() {
		return $this->_hasCodigo;
	}
	public function getCodigo() {
		return $this->_codigo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Nombre" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_nombre = null;
	private $_hasNombre = false;
	public function setNombre($value) {
		$this->_nombre = $value;
		$this->_hasNombre = ($value !== null);
	}
	public function hasNombre() {
		return $this->_hasNombre;
	}
	public function getNombre() {
		return $this->_nombre;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Nucleo con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Nucleo 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Nucleo(); 
		if (!isset($vData['Codigo'])) {
			throw new Exception('El parametro Codigo es obligatorio');
		}
		if (isset($vData['Codigo'])) {
		
			$newItem->setCodigo($vData['Codigo']);
		}
		if (!isset($vData['Nombre'])) {
			throw new Exception('El parametro Nombre es obligatorio');
		}
		if (isset($vData['Nombre'])) {
		
			$newItem->setNombre($vData['Nombre']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_nombre, 'Nombre', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Direccion extends SoapObject {
	

	/**
	 * @var Via Propiedad de navegacion entre objetos SOAP
	 * name="Via" type="Via"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_via = null;
	private $_hasVia = false;
	public function setVia($value) {
		$this->_via = $value;
		$this->_hasVia = ($value !== null);
	}
	public function hasVia() {
		return $this->_hasVia;
	}
	public function getVia() {
		return $this->_via;
	}


	/**
	 * @var Numero Propiedad de navegacion entre objetos SOAP
	 * name="Numero" type="Numero"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_numero = null;
	private $_hasNumero = false;
	public function setNumero($value) {
		$this->_numero = $value;
		$this->_hasNumero = ($value !== null);
	}
	public function hasNumero() {
		return $this->_hasNumero;
	}
	public function getNumero() {
		return $this->_numero;
	}


	/**
	 * @var NumeroSuperior Propiedad de navegacion entre objetos SOAP
	 * name="NumeroSuperior" type="NumeroSuperior"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_numeroSuperior = null;
	private $_hasNumeroSuperior = false;
	public function setNumeroSuperior($value) {
		$this->_numeroSuperior = $value;
		$this->_hasNumeroSuperior = ($value !== null);
	}
	public function hasNumeroSuperior() {
		return $this->_hasNumeroSuperior;
	}
	public function getNumeroSuperior() {
		return $this->_numeroSuperior;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Kmt" type="Kmt"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_kmt = null;
	private $_hasKmt = false;
	public function setKmt($value) {
		$this->_kmt = $value;
		$this->_hasKmt = ($value !== null);
	}
	public function hasKmt() {
		return $this->_hasKmt;
	}
	public function getKmt() {
		return $this->_kmt;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Hmt" type="Hmt"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_hmt = null;
	private $_hasHmt = false;
	public function setHmt($value) {
		$this->_hmt = $value;
		$this->_hasHmt = ($value !== null);
	}
	public function hasHmt() {
		return $this->_hasHmt;
	}
	public function getHmt() {
		return $this->_hmt;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Bloque" type="Bloque"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_bloque = null;
	private $_hasBloque = false;
	public function setBloque($value) {
		$this->_bloque = $value;
		$this->_hasBloque = ($value !== null);
	}
	public function hasBloque() {
		return $this->_hasBloque;
	}
	public function getBloque() {
		return $this->_bloque;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Portal" type="Portal"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_portal = null;
	private $_hasPortal = false;
	public function setPortal($value) {
		$this->_portal = $value;
		$this->_hasPortal = ($value !== null);
	}
	public function hasPortal() {
		return $this->_hasPortal;
	}
	public function getPortal() {
		return $this->_portal;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Escalera" type="Escalera"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_escalera = null;
	private $_hasEscalera = false;
	public function setEscalera($value) {
		$this->_escalera = $value;
		$this->_hasEscalera = ($value !== null);
	}
	public function hasEscalera() {
		return $this->_hasEscalera;
	}
	public function getEscalera() {
		return $this->_escalera;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Planta" type="Planta"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_planta = null;
	private $_hasPlanta = false;
	public function setPlanta($value) {
		$this->_planta = $value;
		$this->_hasPlanta = ($value !== null);
	}
	public function hasPlanta() {
		return $this->_hasPlanta;
	}
	public function getPlanta() {
		return $this->_planta;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Puerta" type="Puerta"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_puerta = null;
	private $_hasPuerta = false;
	public function setPuerta($value) {
		$this->_puerta = $value;
		$this->_hasPuerta = ($value !== null);
	}
	public function hasPuerta() {
		return $this->_hasPuerta;
	}
	public function getPuerta() {
		return $this->_puerta;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="CodPostal" type="CodPostal"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_codPostal = null;
	private $_hasCodPostal = false;
	public function setCodPostal($value) {
		$this->_codPostal = $value;
		$this->_hasCodPostal = ($value !== null);
	}
	public function hasCodPostal() {
		return $this->_hasCodPostal;
	}
	public function getCodPostal() {
		return $this->_codPostal;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Direccion con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Direccion 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Direccion(); 
		if (isset($vData['Via'])) {
		
			$newClass = Via::fromSoap($vData['Via']);
			$newItem->setVia($newClass);
		}
		if (isset($vData['Numero'])) {
		
			$newClass = Numero::fromSoap($vData['Numero']);
			$newItem->setNumero($newClass);
		}
		if (isset($vData['NumeroSuperior'])) {
		
			$newClass = NumeroSuperior::fromSoap($vData['NumeroSuperior']);
			$newItem->setNumeroSuperior($newClass);
		}
		if (isset($vData['Kmt'])) {
		
			$newItem->setKmt($vData['Kmt']);
		}
		if (isset($vData['Hmt'])) {
		
			$newItem->setHmt($vData['Hmt']);
		}
		if (isset($vData['Bloque'])) {
		
			$newItem->setBloque($vData['Bloque']);
		}
		if (isset($vData['Portal'])) {
		
			$newItem->setPortal($vData['Portal']);
		}
		if (isset($vData['Escalera'])) {
		
			$newItem->setEscalera($vData['Escalera']);
		}
		if (isset($vData['Planta'])) {
		
			$newItem->setPlanta($vData['Planta']);
		}
		if (isset($vData['Puerta'])) {
		
			$newItem->setPuerta($vData['Puerta']);
		}
		if (isset($vData['CodPostal'])) {
		
			$newItem->setCodPostal($vData['CodPostal']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_via, 'Via', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_numero, 'Numero', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_numeroSuperior, 'NumeroSuperior', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_kmt, 'Kmt', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_hmt, 'Hmt', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_bloque, 'Bloque', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_portal, 'Portal', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_escalera, 'Escalera', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_planta, 'Planta', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_puerta, 'Puerta', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_codPostal, 'CodPostal', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Via extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Codigo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_codigo = null;
	private $_hasCodigo = false;
	public function setCodigo($value) {
		$this->_codigo = $value;
		$this->_hasCodigo = ($value !== null);
	}
	public function hasCodigo() {
		return $this->_hasCodigo;
	}
	public function getCodigo() {
		return $this->_codigo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Tipo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_tipo = null;
	private $_hasTipo = false;
	public function setTipo($value) {
		$this->_tipo = $value;
		$this->_hasTipo = ($value !== null);
	}
	public function hasTipo() {
		return $this->_hasTipo;
	}
	public function getTipo() {
		return $this->_tipo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Nombre" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_nombre = null;
	private $_hasNombre = false;
	public function setNombre($value) {
		$this->_nombre = $value;
		$this->_hasNombre = ($value !== null);
	}
	public function hasNombre() {
		return $this->_hasNombre;
	}
	public function getNombre() {
		return $this->_nombre;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Via con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Via 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Via(); 
		if (!isset($vData['Codigo'])) {
			throw new Exception('El parametro Codigo es obligatorio');
		}
		if (isset($vData['Codigo'])) {
		
			$newItem->setCodigo($vData['Codigo']);
		}
		if (!isset($vData['Tipo'])) {
			throw new Exception('El parametro Tipo es obligatorio');
		}
		if (isset($vData['Tipo'])) {
		
			$newItem->setTipo($vData['Tipo']);
		}
		if (!isset($vData['Nombre'])) {
			throw new Exception('El parametro Nombre es obligatorio');
		}
		if (isset($vData['Nombre'])) {
		
			$newItem->setNombre($vData['Nombre']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_tipo, 'Tipo', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_nombre, 'Nombre', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Numero extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Calificador" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_calificador = null;
	private $_hasCalificador = false;
	public function setCalificador($value) {
		$this->_calificador = $value;
		$this->_hasCalificador = ($value !== null);
	}
	public function hasCalificador() {
		return $this->_hasCalificador;
	}
	public function getCalificador() {
		return $this->_calificador;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Valor" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_valor = null;
	private $_hasValor = false;
	public function setValor($value) {
		$this->_valor = $value;
		$this->_hasValor = ($value !== null);
	}
	public function hasValor() {
		return $this->_hasValor;
	}
	public function getValor() {
		return $this->_valor;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Numero con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Numero 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Numero(); 
		if (!isset($vData['Calificador'])) {
			throw new Exception('El parametro Calificador es obligatorio');
		}
		if (isset($vData['Calificador'])) {
		
			$newItem->setCalificador($vData['Calificador']);
		}
		if (!isset($vData['Valor'])) {
			throw new Exception('El parametro Valor es obligatorio');
		}
		if (isset($vData['Valor'])) {
		
			$newItem->setValor($vData['Valor']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_calificador, 'Calificador', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_valor, 'Valor', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class NumeroSuperior extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Calificador" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_calificador = null;
	private $_hasCalificador = false;
	public function setCalificador($value) {
		$this->_calificador = $value;
		$this->_hasCalificador = ($value !== null);
	}
	public function hasCalificador() {
		return $this->_hasCalificador;
	}
	public function getCalificador() {
		return $this->_calificador;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Valor" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_valor = null;
	private $_hasValor = false;
	public function setValor($value) {
		$this->_valor = $value;
		$this->_hasValor = ($value !== null);
	}
	public function hasValor() {
		return $this->_hasValor;
	}
	public function getValor() {
		return $this->_valor;
	}


	/**
	 *
	 * Devuelve una instancia de la clase NumeroSuperior con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	NumeroSuperior 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new NumeroSuperior(); 
		if (!isset($vData['Calificador'])) {
			throw new Exception('El parametro Calificador es obligatorio');
		}
		if (isset($vData['Calificador'])) {
		
			$newItem->setCalificador($vData['Calificador']);
		}
		if (!isset($vData['Valor'])) {
			throw new Exception('El parametro Valor es obligatorio');
		}
		if (isset($vData['Valor'])) {
		
			$newItem->setValor($vData['Valor']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_calificador, 'Calificador', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_valor, 'Valor', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class UltimaVariacion extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Codigo" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_codigo = null;
	private $_hasCodigo = false;
	public function setCodigo($value) {
		$this->_codigo = $value;
		$this->_hasCodigo = ($value !== null);
	}
	public function hasCodigo() {
		return $this->_hasCodigo;
	}
	public function getCodigo() {
		return $this->_codigo;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Descripcion" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_descripcion = null;
	private $_hasDescripcion = false;
	public function setDescripcion($value) {
		$this->_descripcion = $value;
		$this->_hasDescripcion = ($value !== null);
	}
	public function hasDescripcion() {
		return $this->_hasDescripcion;
	}
	public function getDescripcion() {
		return $this->_descripcion;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Fecha" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_fecha = null;
	private $_hasFecha = false;
	public function setFecha($value) {
		$this->_fecha = $value;
		$this->_hasFecha = ($value !== null);
	}
	public function hasFecha() {
		return $this->_hasFecha;
	}
	public function getFecha() {
		return $this->_fecha;
	}


	/**
	 *
	 * Devuelve una instancia de la clase UltimaVariacion con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	UltimaVariacion 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new UltimaVariacion(); 
		if (isset($vData['Codigo'])) {
		
			$newItem->setCodigo($vData['Codigo']);
		}
		if (isset($vData['Descripcion'])) {
		
			$newItem->setDescripcion($vData['Descripcion']);
		}
		if (isset($vData['Fecha'])) {
		
			$newItem->setFecha($vData['Fecha']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_descripcion, 'Descripcion', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_fecha, 'Fecha', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Solicitud extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Espanol" type="Espanol"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_espanol = null;
	private $_hasEspanol = false;
	public function setEspanol($value) {
		$this->_espanol = $value;
		$this->_hasEspanol = ($value !== null);
	}
	public function hasEspanol() {
		return $this->_hasEspanol;
	}
	public function getEspanol() {
		return $this->_espanol;
	}


	/**
	 * @var Residencia Propiedad de navegacion entre objetos SOAP
	 * name="Residencia" type="Residencia"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_residencia = null;
	private $_hasResidencia = false;
	public function setResidencia($value) {
		$this->_residencia = $value;
		$this->_hasResidencia = ($value !== null);
	}
	public function hasResidencia() {
		return $this->_hasResidencia;
	}
	public function getResidencia() {
		return $this->_residencia;
	}


	/**
	 * @var Nacimiento Propiedad de navegacion entre objetos SOAP
	 * name="Nacimiento" type="Nacimiento"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_nacimiento = null;
	private $_hasNacimiento = false;
	public function setNacimiento($value) {
		$this->_nacimiento = $value;
		$this->_hasNacimiento = ($value !== null);
	}
	public function hasNacimiento() {
		return $this->_hasNacimiento;
	}
	public function getNacimiento() {
		return $this->_nacimiento;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Solicitud con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Solicitud 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Solicitud(); 
		if (!isset($vData['Espanol'])) {
			throw new Exception('El parametro Espanol es obligatorio');
		}
		if (isset($vData['Espanol'])) {
		
			$newItem->setEspanol($vData['Espanol']);
		}
		if (isset($vData['Residencia'])) {
		
			$newClass = Residencia::fromSoap($vData['Residencia']);
			$newItem->setResidencia($newClass);
		}
		if (isset($vData['Nacimiento'])) {
		
			$newClass = Nacimiento::fromSoap($vData['Nacimiento']);
			$newItem->setNacimiento($newClass);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_espanol, 'Espanol', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_residencia, 'Residencia', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_nacimiento, 'Nacimiento', SOAP_ENC_OBJECT, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Nacimiento extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Fecha" type="Fecha"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_fecha = null;
	private $_hasFecha = false;
	public function setFecha($value) {
		$this->_fecha = $value;
		$this->_hasFecha = ($value !== null);
	}
	public function hasFecha() {
		return $this->_hasFecha;
	}
	public function getFecha() {
		return $this->_fecha;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Provincia" type="Provincia"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_provincia = null;
	private $_hasProvincia = false;
	public function setProvincia($value) {
		$this->_provincia = $value;
		$this->_hasProvincia = ($value !== null);
	}
	public function hasProvincia() {
		return $this->_hasProvincia;
	}
	public function getProvincia() {
		return $this->_provincia;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Municipio" type="Municipio"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_municipio = null;
	private $_hasMunicipio = false;
	public function setMunicipio($value) {
		$this->_municipio = $value;
		$this->_hasMunicipio = ($value !== null);
	}
	public function hasMunicipio() {
		return $this->_hasMunicipio;
	}
	public function getMunicipio() {
		return $this->_municipio;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Nacimiento con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Nacimiento 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Nacimiento(); 
		if (isset($vData['Fecha'])) {
		
			$newItem->setFecha($vData['Fecha']);
		}
		if (isset($vData['Provincia'])) {
		
			$newItem->setProvincia($vData['Provincia']);
		}
		if (isset($vData['Municipio'])) {
		
			$newItem->setMunicipio($vData['Municipio']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_fecha, 'Fecha', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_provincia, 'Provincia', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_municipio, 'Municipio', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		
			
class Residencia extends SoapObject {
	

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Provincia" type="Provincia"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_provincia = null;
	private $_hasProvincia = false;
	public function setProvincia($value) {
		$this->_provincia = $value;
		$this->_hasProvincia = ($value !== null);
	}
	public function hasProvincia() {
		return $this->_hasProvincia;
	}
	public function getProvincia() {
		return $this->_provincia;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Municipio" type="Municipio"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_municipio = null;
	private $_hasMunicipio = false;
	public function setMunicipio($value) {
		$this->_municipio = $value;
		$this->_hasMunicipio = ($value !== null);
	}
	public function hasMunicipio() {
		return $this->_hasMunicipio;
	}
	public function getMunicipio() {
		return $this->_municipio;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Residencia con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Residencia 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Residencia(); 
		if (isset($vData['Provincia'])) {
		
			$newItem->setProvincia($vData['Provincia']);
		}
		if (isset($vData['Municipio'])) {
		
			$newItem->setMunicipio($vData['Municipio']);
		}

		return $newItem;
	}
	
	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_provincia, 'Provincia', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_municipio, 'Municipio', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);		
	}
}		

?>