<?php
namespace WSCOMUN\SS\VIDA_LABORAL;

use Exception;
use SoapVar;
use ArrayObject;
use stdClass;


const unbounded = 'unbounded';


class objSolicitudTransmision
{
	/**
	 * Contantes para los NS
	 */
	private static $NAMESPACE_ESP  = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	private static $NAMESPACE_PET  = 'http://intermediacion.redsara.es/scsp/esquemas/V3/peticion';
	private static $NAMESPACE_SR   = 'http://intermediacion.redsara.es/scsp/esquemas/V3/solicitudRespuesta';
	private static $NAMESPACE_RESP = 'http://intermediacion.redsara.es/scsp/esquemas/V3/respuesta';

	/**
	 * @var String
	 * Nif del Emisor
	 */
	private $nifEmisor = null;

	/**
	 * @var String
	 * Nombre o razn social del emisor
	 */
	private $nombreEmisor = null;

	/**
	 * @var String
	 * Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $codProcedimiento = null;

	/**
	 * @var String
	 * Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $nombreProcedimiento = null;

	/**
	 * @var String
	 * Nombre completo del empleado pblico que realiza la solicitud.
	 */
	private $nombreCompletoFuncionario = null;

	/**
	 * @var String
	 * NIF del empleado pblico que realiza la solicitud.
	 */
	private $nifFuncionario = null;

	/**
	 * @var String
	 * Documentacin identificativa del titular. Puede ser: DNI, NIE
	 */
	private $tipoDocumentacion = null;

	/**
	 * @var String
	 * Nmero de documento segn el <TipoDocumentacion>
	 */
	private $documentacion = null;

	/**
	 * @var String
	 * Nombre completo del titular de la solicitud
	 */
	private $nombreCompleto = null;

	/**
	 * @var String
	 * Nombre del titular de la solicitud
	 */
	private $nombre = null;

	/**
	 * @var String
	 * Primer Apellido del titular de la solicitud
	 */
	private $apellido1 = null;

	/**
	 * @var String
	 * Segundo Apellido del titular de la solicitud
	 */
	private $apellido2 = null;

	/**
	 * @var String
	 * NIF del organismo
	 */
	private $identificadorSolicitante = null;

	/**
	 * @var String
	 * Nombre o razn social del organismo
	 */
	private $nombreSolicitante = null;

	/**
	 * @var String
	 * Nombre de la Unidad Tramitadora que realiza la peticin
	 */
	private $unidadTramitadora = null;

	/**
	 * @var String
	 * Codigo de la Unidad Tramitadora que realiza la peticin
	 */
	private $codigoUnidadTramitadora = null;
	
	/**
	 * @var String
	 * Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 */
	private $finalidad = null;

	/**
	 * @var String
	 * Valores admitidos: Si, Ley
	 */
	private $consentimiento = null;

	/**
	 * @var String
	 * Identificador del Expediente que justifica la consulta.
	 */
	private $idExpediente = null;
	



	/**
	 * Establece los datos del organismo emisor que ofrece el servicio.
	 *
	 * @access	public
	 * @param String $nif Nif del Emisor
	 * @param String $nombre Nombre o razn social del emisor
	 */
	public function setEmisor($nif, $nombre) {
		$this->nifEmisor = $nif;
		$this->nombreEmisor = $nombre;
	}

	/**
	 * Establece los datos del procedimiento que autoriza la consulta.
	 *
	 * @access	public
	 * @param String $codigo Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 * @param String $nombre Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	public function setProcedimiento($codigo, $nombre) {
		$this->codProcedimiento = $codigo;
		$this->nombreProcedimiento = $nombre;
	}

	/**
	 * Establece los datos del empleado pblico que realiza la solicitud.
	 *
	 * @access	public
	 * @param String $nombreCompleto Nombre completo del empleado pblico que realiza la solicitud.
	 * @param String $nif NIF del empleado pblico que realiza la solicitud.
	 */
	public function setFuncionario($nombreCompleto, $nif) {
		$this->nombreCompletoFuncionario = $nombreCompleto;
		$this->nifFuncionario = $nif;
	}

	/**
	 * Establece los datos del ciudadano sobre el que se va a realizar la consulta.
	 *
	 * @access	public
	 * @param String $tipoDocumentacion Documentacin identificativa del titular. Puede ser: NIF, NIE, CIF
	 * @param String $documentacion Nmero de documento segn el tipo de documentacin indicado.
	 * @param String $nombreCompleto Nombre completo del titular de la solicitud
	 * @param String $nombre Nombre del titular de la solicitud
	 * @param String $apellido1 Primer Apellido del titular de la solicitud
	 * @param String $apellido2 Segundo Apellido del titular de la solicitud
	 */
	public function setTitular($tipoDocumentacion, $documentacion, $nombreCompleto = null, $nombre = null, $apellido1 = null, $apellido2 = null) {
		$this->tipoDocumentacion = $tipoDocumentacion;
		$this->documentacion = $documentacion;
		$this->nombreCompleto = $nombreCompleto;
		$this->nombre = $nombre;
		$this->apellido1 = $apellido1;
		$this->apellido2 = $apellido2;
	}

	/**
	 * Establece los datos del solicitante de la transmisin, as como la finalidad del mismo.
	 *
	 * @access	public
	 * @param String $identificadorSolicitante NIF del organismo solicitante
	 * @param String $nombreSolicitante Nombre o razn social del organismo solicitante
	 * @param String $consentimiento Valores admitidos: Si, Ley
	 * @param String $finalidad Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 * @param String $unidadTramitadora Nombre de la Unidad Tramitadora que realiza la peticin
	 * @param String $codigoUnidadTramitadora Codigo de la Unidad Tramitadora que realiza la peticin
	 * @param String $idExpediente Identificador del Expediente que justifica la consulta.
	 */
	public function setSolicitante($identificadorSolicitante, $nombreSolicitante, $consentimiento, $finalidad, $unidadTramitadora = null, $codigoUnidadTramitadora = null, $idExpediente = null) {
		$this->identificadorSolicitante = $identificadorSolicitante;
		$this->nombreSolicitante = $nombreSolicitante;
		$this->consentimiento = $consentimiento;
		$this->finalidad = $finalidad;
		$this->unidadTramitadora = $unidadTramitadora;
		$this->codigoUnidadTramitadora = $codigoUnidadTramitadora;
		$this->idExpediente = $idExpediente;
	}
	
	
	/**
	 * Devuelve una copia del objeto, que mantiene los datos generales de la peticin: Emisor, procedimiento, funcionario, titular y solicitante
	 *
	 * @access	public
	 * @return	objSolicitudTransmision	Nueva instancia con los datos copiados
	 */
	public function duplicarCabecera() {
		$oClon = new objSolicitudTransmision();
		$oClon->setEmisor($this->nifEmisor, $this->nombreEmisor);
		$oClon->setProcedimiento($this->codProcedimiento, $this->nombreProcedimiento);
		$oClon->setFuncionario($this->nombreCompletoFuncionario, $this->nifFuncionario);
		$oClon->setTitular($this->tipoDocumentacion, $this->documentacion, $this->nombreCompleto, $this->nombre, $this->apellido1, $this->apellido2);
		$oClon->setSolicitante($this->identificadorSolicitante, $this->nombreSolicitante, $this->consentimiento, $this->finalidad, $this->unidadTramitadora, $this->codigoUnidadTramitadora, $this->idExpediente);

		return $oClon;
	}


	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @access 	public
	 * @param string $IdPeticion Identificador de la peticin
	 * @param string $CodigoCertificado Cdigo del certificado del servicio que solicita la peticion
	 * @param string $numParcial Subidentificador de la peticin. Cuando se suministra, se concatena al identificador de la peticion.
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 */
	public function toSoap($IdPeticion, $CodigoCertificado, $numParcial = null)
	{
		$IdSolicitud = $IdPeticion;
		if (!is_null($numParcial)) {
			$IdSolicitud = $IdPeticion . '_' . $numParcial;
		}

		// $CodigoCertificado debera ser auto-generado
		// IdentificadorSolicitante = (Sugerido) CODxxxxxx
		// Consentimiento = Si | Ley
		// TipoDocumentacion = NIF | CIF | DNI | Pasaporte | NIE

		// Emisor
		$EmisorWSRequest = new ArrayObject();
		$EmisorWSRequest->append(new SoapVar($this->nifEmisor, XSD_STRING, null, null,'NifEmisor', self::$NAMESPACE_PET));
		$EmisorWSRequest->append(new SoapVar($this->nombreEmisor, XSD_STRING, null, null,'NombreEmisor', self::$NAMESPACE_PET));

		// Procedimiento
		$ProcedimientoWSRequest = new ArrayObject();
		$ProcedimientoWSRequest->append(new SoapVar($this->codProcedimiento, XSD_STRING, null, null,'CodProcedimiento', self::$NAMESPACE_PET));
		$ProcedimientoWSRequest->append(new SoapVar($this->nombreProcedimiento, XSD_STRING, null, null,'NombreProcedimiento', self::$NAMESPACE_PET));

		// Funcionario
		$FuncionarioWSRequest = new ArrayObject();
		$FuncionarioWSRequest->append(new SoapVar($this->nombreCompletoFuncionario, XSD_STRING, null, null,'NombreCompletoFuncionario', self::$NAMESPACE_PET));
		$FuncionarioWSRequest->append(new SoapVar($this->nifFuncionario, XSD_STRING, null, null,'NifFuncionario', self::$NAMESPACE_PET));

		// Solicitante
		$SolicitanteWSRequest = new ArrayObject();
		$SolicitanteWSRequest->append(new SoapVar($this->identificadorSolicitante, XSD_STRING, null, null,'IdentificadorSolicitante', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->nombreSolicitante, XSD_STRING, null, null,'NombreSolicitante', self::$NAMESPACE_PET));
		if (!is_null($this->unidadTramitadora)) {
			$SolicitanteWSRequest->append(new SoapVar($this->unidadTramitadora, XSD_STRING, null, null,'UnidadTramitadora', self::$NAMESPACE_PET));
		}
			if (!is_null($this->codigoUnidadTramitadora)) {
			$SolicitanteWSRequest->append(new SoapVar($this->codigoUnidadTramitadora, XSD_STRING, null, null,'CodigoUnidadTramitadora', self::$NAMESPACE_PET));
		}
		$SolicitanteWSRequest->append(new SoapVar($ProcedimientoWSRequest, SOAP_ENC_OBJECT,null,null,'Procedimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->finalidad, XSD_STRING, null, null,'Finalidad', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->consentimiento, XSD_STRING, null, null,'Consentimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($FuncionarioWSRequest, SOAP_ENC_OBJECT,null,null,'Funcionario', self::$NAMESPACE_PET));
		if (!is_null($this->idExpediente)) {
			$SolicitanteWSRequest->append(new SoapVar($this->idExpediente, XSD_STRING, null, null,'IdExpediente', self::$NAMESPACE_PET));
		}

		// Titular
		$TitularWSRequest = new ArrayObject();
		$TitularWSRequest->append(new SoapVar($this->tipoDocumentacion, XSD_STRING, null, null,'TipoDocumentacion', self::$NAMESPACE_PET));
		$TitularWSRequest->append(new SoapVar($this->documentacion, XSD_STRING, null, null,'Documentacion', self::$NAMESPACE_PET));
		if (!is_null($this->nombreCompleto)) {
			$TitularWSRequest->append(new SoapVar($this->nombreCompleto, XSD_STRING, null, null,'NombreCompleto', self::$NAMESPACE_PET));
		}
		if (!is_null($this->nombre)) {
			$TitularWSRequest->append(new SoapVar($this->nombre, XSD_STRING, null, null,'Nombre', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido1)) {
			$TitularWSRequest->append(new SoapVar($this->apellido1, XSD_STRING, null, null,'Apellido1', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido2)) {
			$TitularWSRequest->append(new SoapVar($this->apellido2, XSD_STRING, null, null,'Apellido2', self::$NAMESPACE_PET));
		}

		// Transmision
		$TransmisionWSRequest = new ArrayObject();
		$TransmisionWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_PET));
		$TransmisionWSRequest->append(new SoapVar($IdSolicitud, XSD_STRING, null, null,'IdSolicitud', self::$NAMESPACE_PET));

		// DatosGenericos
		$DatosGenericosWSRequest = new ArrayObject();
		$DatosGenericosWSRequest->append(new SoapVar($EmisorWSRequest, SOAP_ENC_OBJECT,null,null,'Emisor', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($SolicitanteWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitante', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TitularWSRequest, SOAP_ENC_OBJECT,null,null,'Titular', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'Transmision', self::$NAMESPACE_PET));

		// SolicitudTransmision
		$SolicitudTransmisionWSRequest = new ArrayObject();
		$SolicitudTransmisionWSRequest->append(new SoapVar($DatosGenericosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosGenericos', self::$NAMESPACE_PET));

		// Devuelve la solicitud ya generada
		return new SoapVar($SolicitudTransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudTransmision', self::$NAMESPACE_PET);
	}

}


class SoapObject
{
	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new \stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array


	private function __anyType_SoapVar($childData, $fieldName, $namespace) {
		//var_dump($childData);
		if (is_a($childData, 'DateTime')) {
			//var_dump($childData);
			//die('DateTime: ' . $fieldName);
			return new \SoapVar($childData->format(\DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		} elseif (is_int($childData)) {
			//die('Integer: ' . $fieldName);
			return new \SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}

		//die('Generic: ' . $fieldName);
		return new \SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}

	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace) {
		switch ($basicType) {
			case XSD_DATETIME:
				return new \SoapVar($childData->format(\DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);

			default:
				return new \SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $value, $fieldName, $type, $namespace, $minOccurs, $maxOccurs)
	{
		//echo("__doChild: $type [$fieldName]<br>");
		$fieldSet = isset($value);
		if (!$fieldSet) {
			if ($minOccurs > 0) {
				throw new \Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			} else {
				return true;
			}
		}

		$vChildData = $value;
		if ($maxOccurs == 1) {
			$vChildData = array( $value );
		} else {
			if ($maxOccurs != 'unbounded') {
				if ($maxOccurs > sizeof($vChildData)) {
					throw new \Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			} else {
				//				var_dump($vChildData);die;
			}
		}

		//var_dump(array_keys($vChildData));
		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++) {
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet) {
				if (is_int($type) && $type != SOAP_ENC_OBJECT) {

					$basicType = $type;
					//echo("Basic: $type | $basicType [$fieldName]<br>");
					if ($basicType !== XSD_ANYTYPE) {
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					} else {
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append( $childSOAP );
					//					return true;

				} else { //if (isset($this->$funcName)) {
					$childSOAP = $childData->toSoap($fieldName, $namespace);
					$parentTag->append( $childSOAP );
					//					return true;
				}
			} else {
				return false;
			}

		}

		// TODO: HACER EL MULTIAPARICION!!!
		/*
		 var_dump($parentTag);
		 var_dump($vData);
		 var_dump($fieldName);
		 var_dump($type);
		 var_dump($namespace);
		 var_dump($minOccurs);
		 var_dump($maxOccurs);

		 die("FAIL!!!");
		 */

		return true;
	}



	static public function is_assoc($array) {
		foreach(array_keys($array) as $key) {
			if (!is_int($key)) return true;
		}
		return false;
	}

	static public function endsWith($haystack, $needle) {
		// search forward starting from end minus needle length characters
		return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
	}
}








class DatosEspecificos extends SoapObject {


	/**
	 * @var Retorno Propiedad de navegacion entre objetos SOAP
	 * name="Retorno" type="Retorno"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_retorno = null;
	private $_hasRetorno = false;
	public function setRetorno($value) {
		$this->_retorno = $value;
		$this->_hasRetorno = ($value !== null);
	}
	public function hasRetorno() {
		return $this->_hasRetorno;
	}
	public function getRetorno() {
		return $this->_retorno;
	}


	/**
	 *
	 * Devuelve una instancia de la clase DatosEspecificos con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DatosEspecificos 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DatosEspecificos();
		if (!isset($vData['Retorno'])) {
			throw new Exception('El parametro Retorno es obligatorio');
		}
		if (isset($vData['Retorno'])) {

			$newClass = Retorno::fromSoap($vData['Retorno']);
			$newItem->setRetorno($newClass);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_retorno, 'Retorno', SOAP_ENC_OBJECT, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class Consulta extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="FechaDesde" type="FechaDesde"[109] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_fechaDesde = null;
	private $_hasFechaDesde = false;
	public function setFechaDesde($value) {
		$this->_fechaDesde = $value;
		$this->_hasFechaDesde = ($value !== null);
	}
	public function hasFechaDesde() {
		return $this->_hasFechaDesde;
	}
	public function getFechaDesde() {
		return $this->_fechaDesde;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="FechaHasta" type="FechaHasta"[109] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_fechaHasta = null;
	private $_hasFechaHasta = false;
	public function setFechaHasta($value) {
		$this->_fechaHasta = $value;
		$this->_hasFechaHasta = ($value !== null);
	}
	public function hasFechaHasta() {
		return $this->_hasFechaHasta;
	}
	public function getFechaHasta() {
		return $this->_fechaHasta;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Consulta con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Consulta 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Consulta();
		if (!isset($vData['FechaDesde'])) {
			throw new Exception('El parametro FechaDesde es obligatorio');
		}
		if (isset($vData['FechaDesde'])) {

			$newItem->setFechaDesde($vData['FechaDesde']);
		}
		if (!isset($vData['FechaHasta'])) {
			throw new Exception('El parametro FechaHasta es obligatorio');
		}
		if (isset($vData['FechaHasta'])) {

			$newItem->setFechaHasta($vData['FechaHasta']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_fechaDesde, 'FechaDesde', 109, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_fechaHasta, 'FechaHasta', 109, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class Retorno extends SoapObject {


	/**
	 * @var Estado Propiedad de navegacion entre objetos SOAP
	 * name="Estado" type="Estado"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_estado = null;
	private $_hasEstado = false;
	public function setEstado($value) {
		$this->_estado = $value;
		$this->_hasEstado = ($value !== null);
	}
	public function hasEstado() {
		return $this->_hasEstado;
	}
	public function getEstado() {
		return $this->_estado;
	}


	/**
	 * @var Consulta Propiedad de navegacion entre objetos SOAP
	 * name="Consulta" type="Consulta"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_consulta = null;
	private $_hasConsulta = false;
	public function setConsulta($value) {
		$this->_consulta = $value;
		$this->_hasConsulta = ($value !== null);
	}
	public function hasConsulta() {
		return $this->_hasConsulta;
	}
	public function getConsulta() {
		return $this->_consulta;
	}


	/**
	 * @var VidaLaboral Propiedad de navegacion entre objetos SOAP
	 * name="VidaLaboral" type="VidaLaboral"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_vidaLaboral = null;
	private $_hasVidaLaboral = false;
	public function setVidaLaboral($value) {
		$this->_vidaLaboral = $value;
		$this->_hasVidaLaboral = ($value !== null);
	}
	public function hasVidaLaboral() {
		return $this->_hasVidaLaboral;
	}
	public function getVidaLaboral() {
		return $this->_vidaLaboral;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Retorno con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Retorno 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Retorno();
		if (!isset($vData['Estado'])) {
			throw new Exception('El parametro Estado es obligatorio');
		}
		if (isset($vData['Estado'])) {

			$newClass = Estado::fromSoap($vData['Estado']);
			$newItem->setEstado($newClass);
		}
		if (!isset($vData['Consulta'])) {
			throw new Exception('El parametro Consulta es obligatorio');
		}
		if (isset($vData['Consulta'])) {

			$newClass = Consulta::fromSoap($vData['Consulta']);
			$newItem->setConsulta($newClass);
		}
		if (isset($vData['VidaLaboral'])) {

			$newClass = VidaLaboral::fromSoap($vData['VidaLaboral']);
			$newItem->setVidaLaboral($newClass);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_estado, 'Estado', SOAP_ENC_OBJECT, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_consulta, 'Consulta', SOAP_ENC_OBJECT, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_vidaLaboral, 'VidaLaboral', SOAP_ENC_OBJECT, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class Estado extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="CodigoEstado" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_codigoEstado = null;
	private $_hasCodigoEstado = false;
	public function setCodigoEstado($value) {
		$this->_codigoEstado = $value;
		$this->_hasCodigoEstado = ($value !== null);
	}
	public function hasCodigoEstado() {
		return $this->_hasCodigoEstado;
	}
	public function getCodigoEstado() {
		return $this->_codigoEstado;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="CodigoEstadoSecundario" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_codigoEstadoSecundario = null;
	private $_hasCodigoEstadoSecundario = false;
	public function setCodigoEstadoSecundario($value) {
		$this->_codigoEstadoSecundario = $value;
		$this->_hasCodigoEstadoSecundario = ($value !== null);
	}
	public function hasCodigoEstadoSecundario() {
		return $this->_hasCodigoEstadoSecundario;
	}
	public function getCodigoEstadoSecundario() {
		return $this->_codigoEstadoSecundario;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Literal" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_literal = null;
	private $_hasLiteral = false;
	public function setLiteral($value) {
		$this->_literal = $value;
		$this->_hasLiteral = ($value !== null);
	}
	public function hasLiteral() {
		return $this->_hasLiteral;
	}
	public function getLiteral() {
		return $this->_literal;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Estado con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Estado 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Estado();
		if (!isset($vData['CodigoEstado'])) {
			throw new Exception('El parametro CodigoEstado es obligatorio');
		}
		if (isset($vData['CodigoEstado'])) {

			$newItem->setCodigoEstado($vData['CodigoEstado']);
		}
		if (isset($vData['CodigoEstadoSecundario'])) {

			$newItem->setCodigoEstadoSecundario($vData['CodigoEstadoSecundario']);
		}
		if (!isset($vData['Literal'])) {
			throw new Exception('El parametro Literal es obligatorio');
		}
		if (isset($vData['Literal'])) {

			$newItem->setLiteral($vData['Literal']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoEstado, 'CodigoEstado', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_codigoEstadoSecundario, 'CodigoEstadoSecundario', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_literal, 'Literal', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class VidaLaboral extends SoapObject {


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="NumeroSituaciones" type="NumeroSituaciones"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_numeroSituaciones = null;
	private $_hasNumeroSituaciones = false;
	public function setNumeroSituaciones($value) {
		$this->_numeroSituaciones = $value;
		$this->_hasNumeroSituaciones = ($value !== null);
	}
	public function hasNumeroSituaciones() {
		return $this->_hasNumeroSituaciones;
	}
	public function getNumeroSituaciones() {
		return $this->_numeroSituaciones;
	}


	/**
	 * @var Cabecera Propiedad de navegacion entre objetos SOAP
	 * name="Cabecera" type="Cabecera"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_cabecera = null;
	private $_hasCabecera = false;
	public function setCabecera($value) {
		$this->_cabecera = $value;
		$this->_hasCabecera = ($value !== null);
	}
	public function hasCabecera() {
		return $this->_hasCabecera;
	}
	public function getCabecera() {
		return $this->_cabecera;
	}


	/**
	 * @var Resumen Propiedad de navegacion entre objetos SOAP
	 * name="Resumen" type="Resumen"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_resumen = null;
	private $_hasResumen = false;
	public function setResumen($value) {
		$this->_resumen = $value;
		$this->_hasResumen = ($value !== null);
	}
	public function hasResumen() {
		return $this->_hasResumen;
	}
	public function getResumen() {
		return $this->_resumen;
	}


	/**
	 * @var ListaSituaciones Propiedad de navegacion entre objetos SOAP
	 * name="ListaSituaciones" type="ListaSituaciones"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_listaSituaciones = null;
	private $_hasListaSituaciones = false;
	public function setListaSituaciones($value) {
		$this->_listaSituaciones = $value;
		$this->_hasListaSituaciones = ($value !== null);
	}
	public function hasListaSituaciones() {
		return $this->_hasListaSituaciones;
	}
	public function getListaSituaciones() {
		return $this->_listaSituaciones;
	}


	/**
	 *
	 * Devuelve una instancia de la clase VidaLaboral con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	VidaLaboral 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new VidaLaboral();
		if (!isset($vData['NumeroSituaciones'])) {
			throw new Exception('El parametro NumeroSituaciones es obligatorio');
		}
		if (isset($vData['NumeroSituaciones'])) {

			$newItem->setNumeroSituaciones($vData['NumeroSituaciones']);
		}
		if (!isset($vData['Cabecera'])) {
			throw new Exception('El parametro Cabecera es obligatorio');
		}
		if (isset($vData['Cabecera'])) {

			$newClass = Cabecera::fromSoap($vData['Cabecera']);
			$newItem->setCabecera($newClass);
		}
		if (isset($vData['Resumen'])) {

			$newClass = Resumen::fromSoap($vData['Resumen']);
			$newItem->setResumen($newClass);
		}
		if (isset($vData['ListaSituaciones'])) {

			$newClass = ListaSituaciones::fromSoap($vData['ListaSituaciones']);
			$newItem->setListaSituaciones($newClass);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_numeroSituaciones, 'NumeroSituaciones', 135, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_cabecera, 'Cabecera', SOAP_ENC_OBJECT, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_resumen, 'Resumen', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_listaSituaciones, 'ListaSituaciones', SOAP_ENC_OBJECT, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class Cabecera extends SoapObject {


	/**
	 * @var ListaNumerosAfiliacion Propiedad de navegacion entre objetos SOAP
	 * name="ListaNumerosAfiliacion" type="ListaNumerosAfiliacion"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_listaNumerosAfiliacion = null;
	private $_hasListaNumerosAfiliacion = false;
	public function setListaNumerosAfiliacion($value) {
		$this->_listaNumerosAfiliacion = $value;
		$this->_hasListaNumerosAfiliacion = ($value !== null);
	}
	public function hasListaNumerosAfiliacion() {
		return $this->_hasListaNumerosAfiliacion;
	}
	public function getListaNumerosAfiliacion() {
		return $this->_listaNumerosAfiliacion;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="FechaNacimiento" type="FechaNacimiento"[109] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_fechaNacimiento = null;
	private $_hasFechaNacimiento = false;
	public function setFechaNacimiento($value) {
		$this->_fechaNacimiento = $value;
		$this->_hasFechaNacimiento = ($value !== null);
	}
	public function hasFechaNacimiento() {
		return $this->_hasFechaNacimiento;
	}
	public function getFechaNacimiento() {
		return $this->_fechaNacimiento;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="TransferenciaDerechosCEE" type="TransferenciaDerechosCEE"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_transferenciaDerechosCEE = null;
	private $_hasTransferenciaDerechosCEE = false;
	public function setTransferenciaDerechosCEE($value) {
		$this->_transferenciaDerechosCEE = $value;
		$this->_hasTransferenciaDerechosCEE = ($value !== null);
	}
	public function hasTransferenciaDerechosCEE() {
		return $this->_hasTransferenciaDerechosCEE;
	}
	public function getTransferenciaDerechosCEE() {
		return $this->_transferenciaDerechosCEE;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Cabecera con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Cabecera 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Cabecera();
		if (isset($vData['ListaNumerosAfiliacion'])) {

			$newClass = ListaNumerosAfiliacion::fromSoap($vData['ListaNumerosAfiliacion']);
			$newItem->setListaNumerosAfiliacion($newClass);
		}
		if (!isset($vData['FechaNacimiento'])) {
			throw new Exception('El parametro FechaNacimiento es obligatorio');
		}
		if (isset($vData['FechaNacimiento'])) {

			$newItem->setFechaNacimiento($vData['FechaNacimiento']);
		}
		if (!isset($vData['TransferenciaDerechosCEE'])) {
			throw new Exception('El parametro TransferenciaDerechosCEE es obligatorio');
		}
		if (isset($vData['TransferenciaDerechosCEE'])) {

			$newItem->setTransferenciaDerechosCEE($vData['TransferenciaDerechosCEE']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_listaNumerosAfiliacion, 'ListaNumerosAfiliacion', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_fechaNacimiento, 'FechaNacimiento', 109, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_transferenciaDerechosCEE, 'TransferenciaDerechosCEE', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class Resumen extends SoapObject {


	/**
	 * @var Totales Propiedad de navegacion entre objetos SOAP
	 * name="Totales" type="Totales"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_totales = null;
	private $_hasTotales = false;
	public function setTotales($value) {
		$this->_totales = $value;
		$this->_hasTotales = ($value !== null);
	}
	public function hasTotales() {
		return $this->_hasTotales;
	}
	public function getTotales() {
		return $this->_totales;
	}


	/**
	 * @var Pluriempleo Propiedad de navegacion entre objetos SOAP
	 * name="Pluriempleo" type="Pluriempleo"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_pluriempleo = null;
	private $_hasPluriempleo = false;
	public function setPluriempleo($value) {
		$this->_pluriempleo = $value;
		$this->_hasPluriempleo = ($value !== null);
	}
	public function hasPluriempleo() {
		return $this->_hasPluriempleo;
	}
	public function getPluriempleo() {
		return $this->_pluriempleo;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Resumen con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Resumen 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Resumen();
		if (!isset($vData['Totales'])) {
			throw new Exception('El parametro Totales es obligatorio');
		}
		if (isset($vData['Totales'])) {

			$newClass = Totales::fromSoap($vData['Totales']);
			$newItem->setTotales($newClass);
		}
		if (!isset($vData['Pluriempleo'])) {
			throw new Exception('El parametro Pluriempleo es obligatorio');
		}
		if (isset($vData['Pluriempleo'])) {

			$newClass = Pluriempleo::fromSoap($vData['Pluriempleo']);
			$newItem->setPluriempleo($newClass);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_totales, 'Totales', SOAP_ENC_OBJECT, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_pluriempleo, 'Pluriempleo', SOAP_ENC_OBJECT, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class Totales extends SoapObject {


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="TotalDiasAlta" type="TotalDiasAlta"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_totalDiasAlta = null;
	private $_hasTotalDiasAlta = false;
	public function setTotalDiasAlta($value) {
		$this->_totalDiasAlta = $value;
		$this->_hasTotalDiasAlta = ($value !== null);
	}
	public function hasTotalDiasAlta() {
		return $this->_hasTotalDiasAlta;
	}
	public function getTotalDiasAlta() {
		return $this->_totalDiasAlta;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="DiasPluriempleo" type="DiasPluriempleo"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_diasPluriempleo = null;
	private $_hasDiasPluriempleo = false;
	public function setDiasPluriempleo($value) {
		$this->_diasPluriempleo = $value;
		$this->_hasDiasPluriempleo = ($value !== null);
	}
	public function hasDiasPluriempleo() {
		return $this->_hasDiasPluriempleo;
	}
	public function getDiasPluriempleo() {
		return $this->_diasPluriempleo;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="AniosAlta" type="AniosAlta"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_aniosAlta = null;
	private $_hasAniosAlta = false;
	public function setAniosAlta($value) {
		$this->_aniosAlta = $value;
		$this->_hasAniosAlta = ($value !== null);
	}
	public function hasAniosAlta() {
		return $this->_hasAniosAlta;
	}
	public function getAniosAlta() {
		return $this->_aniosAlta;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="MesesAlta" type="MesesAlta"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_mesesAlta = null;
	private $_hasMesesAlta = false;
	public function setMesesAlta($value) {
		$this->_mesesAlta = $value;
		$this->_hasMesesAlta = ($value !== null);
	}
	public function hasMesesAlta() {
		return $this->_hasMesesAlta;
	}
	public function getMesesAlta() {
		return $this->_mesesAlta;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="DiasAlta" type="DiasAlta"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_diasAlta = null;
	private $_hasDiasAlta = false;
	public function setDiasAlta($value) {
		$this->_diasAlta = $value;
		$this->_hasDiasAlta = ($value !== null);
	}
	public function hasDiasAlta() {
		return $this->_hasDiasAlta;
	}
	public function getDiasAlta() {
		return $this->_diasAlta;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Totales con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Totales 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Totales();
		if (!isset($vData['TotalDiasAlta'])) {
			throw new Exception('El parametro TotalDiasAlta es obligatorio');
		}
		if (isset($vData['TotalDiasAlta'])) {

			$newItem->setTotalDiasAlta($vData['TotalDiasAlta']);
		}
		if (!isset($vData['DiasPluriempleo'])) {
			throw new Exception('El parametro DiasPluriempleo es obligatorio');
		}
		if (isset($vData['DiasPluriempleo'])) {

			$newItem->setDiasPluriempleo($vData['DiasPluriempleo']);
		}
		if (!isset($vData['AniosAlta'])) {
			throw new Exception('El parametro AniosAlta es obligatorio');
		}
		if (isset($vData['AniosAlta'])) {

			$newItem->setAniosAlta($vData['AniosAlta']);
		}
		if (!isset($vData['MesesAlta'])) {
			throw new Exception('El parametro MesesAlta es obligatorio');
		}
		if (isset($vData['MesesAlta'])) {

			$newItem->setMesesAlta($vData['MesesAlta']);
		}
		if (!isset($vData['DiasAlta'])) {
			throw new Exception('El parametro DiasAlta es obligatorio');
		}
		if (isset($vData['DiasAlta'])) {

			$newItem->setDiasAlta($vData['DiasAlta']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_totalDiasAlta, 'TotalDiasAlta', 135, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_diasPluriempleo, 'DiasPluriempleo', 135, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_aniosAlta, 'AniosAlta', 135, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_mesesAlta, 'MesesAlta', 135, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_diasAlta, 'DiasAlta', 135, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class Pluriempleo extends SoapObject {


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="TotalDiasAlta" type="TotalDiasAlta"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_totalDiasAlta = null;
	private $_hasTotalDiasAlta = false;
	public function setTotalDiasAlta($value) {
		$this->_totalDiasAlta = $value;
		$this->_hasTotalDiasAlta = ($value !== null);
	}
	public function hasTotalDiasAlta() {
		return $this->_hasTotalDiasAlta;
	}
	public function getTotalDiasAlta() {
		return $this->_totalDiasAlta;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="AniosAlta" type="AniosAlta"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_aniosAlta = null;
	private $_hasAniosAlta = false;
	public function setAniosAlta($value) {
		$this->_aniosAlta = $value;
		$this->_hasAniosAlta = ($value !== null);
	}
	public function hasAniosAlta() {
		return $this->_hasAniosAlta;
	}
	public function getAniosAlta() {
		return $this->_aniosAlta;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="MesesAlta" type="MesesAlta"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_mesesAlta = null;
	private $_hasMesesAlta = false;
	public function setMesesAlta($value) {
		$this->_mesesAlta = $value;
		$this->_hasMesesAlta = ($value !== null);
	}
	public function hasMesesAlta() {
		return $this->_hasMesesAlta;
	}
	public function getMesesAlta() {
		return $this->_mesesAlta;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="DiasAlta" type="DiasAlta"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_diasAlta = null;
	private $_hasDiasAlta = false;
	public function setDiasAlta($value) {
		$this->_diasAlta = $value;
		$this->_hasDiasAlta = ($value !== null);
	}
	public function hasDiasAlta() {
		return $this->_hasDiasAlta;
	}
	public function getDiasAlta() {
		return $this->_diasAlta;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Pluriempleo con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Pluriempleo 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Pluriempleo();
		if (!isset($vData['TotalDiasAlta'])) {
			throw new Exception('El parametro TotalDiasAlta es obligatorio');
		}
		if (isset($vData['TotalDiasAlta'])) {

			$newItem->setTotalDiasAlta($vData['TotalDiasAlta']);
		}
		if (!isset($vData['AniosAlta'])) {
			throw new Exception('El parametro AniosAlta es obligatorio');
		}
		if (isset($vData['AniosAlta'])) {

			$newItem->setAniosAlta($vData['AniosAlta']);
		}
		if (!isset($vData['MesesAlta'])) {
			throw new Exception('El parametro MesesAlta es obligatorio');
		}
		if (isset($vData['MesesAlta'])) {

			$newItem->setMesesAlta($vData['MesesAlta']);
		}
		if (!isset($vData['DiasAlta'])) {
			throw new Exception('El parametro DiasAlta es obligatorio');
		}
		if (isset($vData['DiasAlta'])) {

			$newItem->setDiasAlta($vData['DiasAlta']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_totalDiasAlta, 'TotalDiasAlta', 135, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_aniosAlta, 'AniosAlta', 135, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_mesesAlta, 'MesesAlta', 135, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_diasAlta, 'DiasAlta', 135, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class ListaNumerosAfiliacion extends SoapObject {

	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="NumeroAfiliacion" type="NumeroAfiliacion"[101] minOccurs="1" maxOccurs="10" nillable="false"
	 */
	private $_numeroAfiliacion = array();
	private $_hasNumeroAfiliacion = false;
	public function replaceArrayNumeroAfiliacion($value) {
		$this->_numeroAfiliacion = $value;
		$this->_hasNumeroAfiliacion = (isset($this->_numeroAfiliacion) && !empty($this->_numeroAfiliacion));
	}
	public function retrieveArrayNumeroAfiliacion() {
		return $this->_numeroAfiliacion;
	}
	public function addNumeroAfiliacion($value) {
		array_push($this->_numeroAfiliacion, $value);
		$this->_hasNumeroAfiliacion = (isset($this->_numeroAfiliacion) && !empty($this->_numeroAfiliacion));
	}
	public function hasNumeroAfiliacion() {
		return $this->_hasNumeroAfiliacion;
	}
	public function getNumeroAfiliacion($index) {
		return $this->_numeroAfiliacion[$index];
	}
	public function countNumeroAfiliacion() {
		return count($this->_numeroAfiliacion);
	}


	/**
	 *
	 * Devuelve una instancia de la clase ListaNumerosAfiliacion con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	ListaNumerosAfiliacion 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new ListaNumerosAfiliacion();
		if (!isset($vData['NumeroAfiliacion'])) {
			throw new Exception('El parametro NumeroAfiliacion es obligatorio');
		}
		if (isset($vData['NumeroAfiliacion']) && !empty($vData['NumeroAfiliacion'])) {

			if (SoapObject::is_assoc($vData['NumeroAfiliacion'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newItem->addNumeroAfiliacion($vData['NumeroAfiliacion']);
			} else {
				$newItem->replaceArrayNumeroAfiliacion($vData['NumeroAfiliacion']);
			}
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_numeroAfiliacion, 'NumeroAfiliacion', 101, $namespace, 1, 10, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class ListaSituaciones extends SoapObject {

	/**
	 * @var Situacion Propiedad de navegacion entre objetos SOAP
	 * name="Situacion" type="Situacion"[COMPLEXTYPE] minOccurs="1" maxOccurs="unbounded" nillable="false"
	 */
	private $_situacion = array();
	private $_hasSituacion = false;
	public function replaceArraySituacion($value) {
		$this->_situacion = $value;
		$this->_hasSituacion = (isset($this->_situacion) && !empty($this->_situacion));
	}
	public function retrieveArraySituacion() {
		return $this->_situacion;
	}
	public function addSituacion($value) {
		array_push($this->_situacion, $value);
		$this->_hasSituacion = (isset($this->_situacion) && !empty($this->_situacion));
	}
	public function hasSituacion() {
		return $this->_hasSituacion;
	}
	public function getSituacion($index) {
		return $this->_situacion[$index];
	}
	public function countSituacion() {
		return count($this->_situacion);
	}


	/**
	 *
	 * Devuelve una instancia de la clase ListaSituaciones con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	ListaSituaciones 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new ListaSituaciones();
		if (!isset($vData['Situacion'])) {
			throw new Exception('El parametro Situacion es obligatorio');
		}
		if (isset($vData['Situacion']) && !empty($vData['Situacion'])) {
			if (SoapObject::is_assoc($vData['Situacion'])) {
					
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = Situacion::fromSoap($vData['Situacion']);
				$newItem->addSituacion($newClass);
			} else {
					
				foreach ($vData['Situacion'] as $oVar) {
					$newClass = Situacion::fromSoap($oVar);
					$newItem->addSituacion($newClass);
				}
			}
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_situacion, 'Situacion', SOAP_ENC_OBJECT, $namespace, 1, unbounded, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	
class Situacion extends SoapObject {


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="NumeroAfiliacion" type="NumeroAfiliacion"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_numeroAfiliacion = null;
	private $_hasNumeroAfiliacion = false;
	public function setNumeroAfiliacion($value) {
		$this->_numeroAfiliacion = $value;
		$this->_hasNumeroAfiliacion = ($value !== null);
	}
	public function hasNumeroAfiliacion() {
		return $this->_hasNumeroAfiliacion;
	}
	public function getNumeroAfiliacion() {
		return $this->_numeroAfiliacion;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Regimen" type="Regimen"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_regimen = null;
	private $_hasRegimen = false;
	public function setRegimen($value) {
		$this->_regimen = $value;
		$this->_hasRegimen = ($value !== null);
	}
	public function hasRegimen() {
		return $this->_hasRegimen;
	}
	public function getRegimen() {
		return $this->_regimen;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Empresa" type="Empresa"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_empresa = null;
	private $_hasEmpresa = false;
	public function setEmpresa($value) {
		$this->_empresa = $value;
		$this->_hasEmpresa = ($value !== null);
	}
	public function hasEmpresa() {
		return $this->_hasEmpresa;
	}
	public function getEmpresa() {
		return $this->_empresa;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="CodigoCuentaCotizacion" type="CodigoCuentaCotizacion"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_codigoCuentaCotizacion = null;
	private $_hasCodigoCuentaCotizacion = false;
	public function setCodigoCuentaCotizacion($value) {
		$this->_codigoCuentaCotizacion = $value;
		$this->_hasCodigoCuentaCotizacion = ($value !== null);
	}
	public function hasCodigoCuentaCotizacion() {
		return $this->_hasCodigoCuentaCotizacion;
	}
	public function getCodigoCuentaCotizacion() {
		return $this->_codigoCuentaCotizacion;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="Provincia" type="Provincia"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_provincia = null;
	private $_hasProvincia = false;
	public function setProvincia($value) {
		$this->_provincia = $value;
		$this->_hasProvincia = ($value !== null);
	}
	public function hasProvincia() {
		return $this->_hasProvincia;
	}
	public function getProvincia() {
		return $this->_provincia;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="FechaAlta" type="FechaAlta"[109] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_fechaAlta = null;
	private $_hasFechaAlta = false;
	public function setFechaAlta($value) {
		$this->_fechaAlta = $value;
		$this->_hasFechaAlta = ($value !== null);
	}
	public function hasFechaAlta() {
		return $this->_hasFechaAlta;
	}
	public function getFechaAlta() {
		return $this->_fechaAlta;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="FechaEfectos" type="FechaEfectos"[109] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_fechaEfectos = null;
	private $_hasFechaEfectos = false;
	public function setFechaEfectos($value) {
		$this->_fechaEfectos = $value;
		$this->_hasFechaEfectos = ($value !== null);
	}
	public function hasFechaEfectos() {
		return $this->_hasFechaEfectos;
	}
	public function getFechaEfectos() {
		return $this->_fechaEfectos;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="FechaBaja" type="FechaBaja"[109] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_fechaBaja = null;
	private $_hasFechaBaja = false;
	public function setFechaBaja($value) {
		$this->_fechaBaja = $value;
		$this->_hasFechaBaja = ($value !== null);
	}
	public function hasFechaBaja() {
		return $this->_hasFechaBaja;
	}
	public function getFechaBaja() {
		return $this->_fechaBaja;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="ContratoTrabajo" type="ContratoTrabajo"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_contratoTrabajo = null;
	private $_hasContratoTrabajo = false;
	public function setContratoTrabajo($value) {
		$this->_contratoTrabajo = $value;
		$this->_hasContratoTrabajo = ($value !== null);
	}
	public function hasContratoTrabajo() {
		return $this->_hasContratoTrabajo;
	}
	public function getContratoTrabajo() {
		return $this->_contratoTrabajo;
	}


	/**
	 * @var double Propiedad de navegacion entre objetos SOAP
	 * name="ContratoTiempoParcial" type="ContratoTiempoParcial"[103] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_contratoTiempoParcial = null;
	private $_hasContratoTiempoParcial = false;
	public function setContratoTiempoParcial($value) {
		$this->_contratoTiempoParcial = $value;
		$this->_hasContratoTiempoParcial = ($value !== null);
	}
	public function hasContratoTiempoParcial() {
		return $this->_hasContratoTiempoParcial;
	}
	public function getContratoTiempoParcial() {
		return $this->_contratoTiempoParcial;
	}


	/**
	 * @var string Propiedad de navegacion entre objetos SOAP
	 * name="GrupoCotizacion" type="GrupoCotizacion"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_grupoCotizacion = null;
	private $_hasGrupoCotizacion = false;
	public function setGrupoCotizacion($value) {
		$this->_grupoCotizacion = $value;
		$this->_hasGrupoCotizacion = ($value !== null);
	}
	public function hasGrupoCotizacion() {
		return $this->_hasGrupoCotizacion;
	}
	public function getGrupoCotizacion() {
		return $this->_grupoCotizacion;
	}


	/**
	 * @var integer Propiedad de navegacion entre objetos SOAP
	 * name="DiasAlta" type="DiasAlta"[135] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_diasAlta = null;
	private $_hasDiasAlta = false;
	public function setDiasAlta($value) {
		$this->_diasAlta = $value;
		$this->_hasDiasAlta = ($value !== null);
	}
	public function hasDiasAlta() {
		return $this->_hasDiasAlta;
	}
	public function getDiasAlta() {
		return $this->_diasAlta;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Situacion con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Situacion 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	static public function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Situacion();
		if (!isset($vData['NumeroAfiliacion'])) {
			throw new Exception('El parametro NumeroAfiliacion es obligatorio');
		}
		if (isset($vData['NumeroAfiliacion'])) {

			$newItem->setNumeroAfiliacion($vData['NumeroAfiliacion']);
		}
		if (isset($vData['Regimen'])) {

			$newItem->setRegimen($vData['Regimen']);
		}
		if (!isset($vData['Empresa'])) {
			throw new Exception('El parametro Empresa es obligatorio');
		}
		if (isset($vData['Empresa'])) {

			$newItem->setEmpresa($vData['Empresa']);
		}
		if (isset($vData['CodigoCuentaCotizacion'])) {

			$newItem->setCodigoCuentaCotizacion($vData['CodigoCuentaCotizacion']);
		}
		if (isset($vData['Provincia'])) {

			$newItem->setProvincia($vData['Provincia']);
		}
		if (isset($vData['FechaAlta'])) {

			$newItem->setFechaAlta($vData['FechaAlta']);
		}
		if (isset($vData['FechaEfectos'])) {

			$newItem->setFechaEfectos($vData['FechaEfectos']);
		}
		if (isset($vData['FechaBaja'])) {

			$newItem->setFechaBaja($vData['FechaBaja']);
		}
		if (isset($vData['ContratoTrabajo'])) {

			$newItem->setContratoTrabajo($vData['ContratoTrabajo']);
		}
		if (isset($vData['ContratoTiempoParcial'])) {

			$newItem->setContratoTiempoParcial($vData['ContratoTiempoParcial']);
		}
		if (isset($vData['GrupoCotizacion'])) {

			$newItem->setGrupoCotizacion($vData['GrupoCotizacion']);
		}
		if (isset($vData['DiasAlta'])) {

			$newItem->setDiasAlta($vData['DiasAlta']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_numeroAfiliacion, 'NumeroAfiliacion', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_regimen, 'Regimen', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_empresa, 'Empresa', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_codigoCuentaCotizacion, 'CodigoCuentaCotizacion', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_provincia, 'Provincia', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_fechaAlta, 'FechaAlta', 109, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_fechaEfectos, 'FechaEfectos', 109, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_fechaBaja, 'FechaBaja', 109, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_contratoTrabajo, 'ContratoTrabajo', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_contratoTiempoParcial, 'ContratoTiempoParcial', 103, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_grupoCotizacion, 'GrupoCotizacion', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_diasAlta, 'DiasAlta', 135, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
	

?>