<?php
/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder a Web Services Comunes ofrecidos en la {@link http://esirca.gva.es/es/web/esirca/descripcion-intermediacion PAI} (Plataforma Aut. de Intermediacin) del proyecto {@link http://esirca.gva.es/es/web/esirca e-SIRCA} de la {@link http://www.cjap.gva.es/portal/web/dgti DGTI}
 *
 * @package		WSCOMUN
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @author 		Pablo Belenguer <belenguer_pab@externos.gva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2015 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
*/
namespace WSCOMUN;
use WSCMIME\WSCMimeParser;
use WSCOMUN\CATASTRO\WSClientCatastro;
use WSCOMUN\DGT\CONDUCTORVEHICULOS\WSClientConductorVehiculos;
use WSCOMUN\DGT\DATOSVEHICULO\WSClientDatosVehiculo;
use WSCOMUN\DGP\CONSULTAIDENTIDAD\WSClientDGPConsultaIdentidad;
use WSCOMUN\CSV\WSClientCSV;
use WSCOMUN\GDE\WSClientGDE;
use WSCOMUN\GDE\WSClientGDE2;
use WSCOMUN\GVLOGIN\WSClientGVLogin;
use WSCOMUN\PORTAFIRMAS\WSClientPortafirmas;
use WSCOMUN\SALT\WSClientSALT;
use WSCOMUN\REGDEPARTAMENTAL\WSClientRegDepartamental;
use WSCOMUN\AEAT\IRPF\WSClientIRPF;
use WSCOMUN\INE\VERIFICACION_RESIDENCIA\WSClientVerificacionResidencia;
use WSCOMUN\SS\VIDA_LABORAL\WSClientVidaLaboral;
use DOMDocument;
use Exception;
use WSClientAutentica;
use WSClientAutoriza;
use WSClientFirma;
use stdClass;


/**
 * Activa/Desactiva el Debug
*/

define('DEBUG', false);

/**
 * Carga de la clase generica para soporte a clientes SOAP WS-Secure
 */
require_once 'WSSSoapClient.php';
/**
 * Paquetes para gestion MTOM
 */
require_once 'WSCMIME/WSCMime.php';


/**
 * Clase cliente que permite el consumo los WS seguros del proyecto e-Sirca
 *
 * La clase siguiente accede a los WS seguros ofrecidos por la
 * {@link http://esirca.gva.es/es/web/esirca/descripcion-intermediacion PAI} (Plataforma Aut. de Intermediacin)
 * englobada dentro del proyecto {@link http://esirca.gva.es/es/web/esirca e-SIRCA}.
 * Esta clase se organiza como una factora, para instanciar subclases de cada servicio
 *
 * El cliente se conecta a tres servicios SOAP-WS, cada uno de ellos con su WDSL de descripcin
 * La documentacin de los mismos puede encontrarse en el proyecto e-SIRCA.
 * Dividiremos por tanto nuestro paquete en varios mdulos o subpaquetes:
 * Mdulo o servicio de Autenticacion
 * Mdulo o servicio de Autorizacin
 * Mdulo o servicio de Firma
 * Mdulo o servicio del Gestor Documental electrnico (GDE)
 * Mdulo o servicio del Portafirmas
 * Mdulo o servicio de Catastro
 *
 * Para la implementacin en PHP se ha utilizado la extensin {@link http://php.net/manual/es/book.soap.php SOAP}
 *
 * @author		David Pascual <pascual_dav@externosgva.es>
 * @author 		Pablo Belenguer <belenguer_pab@externos.gva.es>
 * @see			\SoapClient
 * @since		Class disponible desde Release 1.0.0
 */
class WSComunFClient
{
	/**
	 * Constantes para el tipo de cliente
	 */
	const KEYCLIENTE_AUTENTICA = 'autentica';
	const KEYCLIENTE_AUTORIZA = 'autoriza';
	const KEYCLIENTE_FIRMA = 'firma';
	const KEYCLIENTE_GDE = 'gde';
	const KEYCLIENTE_SALT = 'salt';
	const KEYCLIENTE_CSV = 'csv';
	const KEYCLIENTE_CATASTRO = 'catastro';
	const KEYCLIENTE_CATASTRO_BIENES = 'catbienes';
	const KEYCLIENTE_GDE2 = 'gde2';
	const KEYCLIENTE_PF = 'pfcons';
	const KEYCLIENTE_PF_MOD = 'pfmod';
	const KEYCLIENTE_PF_ADM = 'pfadm';
	const KEYCLIENTE_GVLOGIN = 'gvlogin';
	const KEYCLIENTE_REGDEPARTAMENTAL = 'regdepartamental';
	const KEYCLIENTE_DGT_CONDUCTORVEHICULOS = 'dgt_conductorvehiculos';
	const KEYCLIENTE_DGT_DATOSVEHICULO = 'dgt_datosvehiculo';
	const KEYCLIENTE_AEAT_IRPF = 'aeat_irpf';
	const KEYCLIENTE_SS_VIDALABORAL = 'ss_vidalaboral';
	const KEYCLIENTE_INE_VERIFICACIONRESIDENCIA = 'ine_verificacionresidencia';
	const KEYCLIENTE_DGP_CONSULTAIDENTIDAD = 'dgp_consultaidentidad';


	/**
	 * Constantes para el parmetro tipo de bsqueda en el mdulo de autorizacin
	 */
	const TIPOBUSQUEDA_USUARIO = 'USUARIO';
	const TIPOBUSQUEDA_GRUPO = 'GRUPO';



	/**
	 * Constantes para el control de opciones del cliente SOAP
	 * slo hay que variarlas para desarrollo, relacionadas con
	 * el modo DEBUG a true
	 */
	protected static $MYSOAPOP_TRACE = true; //Necesario para tratar las cabeceras MTOM
	protected static $MYSOAPOP_WSDL_CACHE = WSDL_CACHE_BOTH;//Desarrollo WSDL_CACHE_NONE, produccion WSDL_CACHE_BOTH
	protected static $MYSOAPOP_SOAP_VERSION = SOAP_1_1;//Los end points son soap 1, no soap 2



	/**
	 * Contantes para los NS
	 */
	protected static $NAMESPACE_GVA = 'http://dgm.gva.es/ayf/war/schemas/v2_00';
	protected static $NAMESPACE_GDE = 'urn:es:gva:dgm:tra:gde:vista:model';
	protected static $NAMESPACE_SALT = 'http://salt.ws.edu.gva.es/';
	protected static $NAMESPACE_CSVGVA = 'urn:es:gva:dgm:tra:csvgva';
	protected static $NAMESPACE_GDE2 = 'urn:es:gva:dgm:tra:gde:vista:v2:model';
	protected static $NAMESPACE_CAT_ESP = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	protected static $NAMESPACE_CAT_PET = 'http://intermediacion.redsara.es/scsp/esquemas/V3/peticion';
	protected static $NAMESPACE_CAT_SR = 'http://intermediacion.redsara.es/scsp/esquemas/V3/solicitudRespuesta';
	protected static $NAMESPACE_PF = null;	// 'urn:juntadeandalucia:cice:pfirma:type:v2.0';
	protected static $NAMESPACE_PF_MOD = null;	// 'urn:juntadeandalucia:cice:pfirma:type:v2.0';
	protected static $NAMESPACE_PF_ADM = null;	// 'urn:juntadeandalucia:cice:pfirma:type:v2.0';
	protected static $NAMESPACE_LOGIN = 'urn:es:gva:gvlogin:sso:model';
	protected static $NAMESPACE_REGDEPARTAMENTAL = 'urn:es:gva:mastin:departamental:model';
	protected static $NAMESPACE_DGT_CONDUCTORVEHICULOS = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	protected static $NAMESPACE_DGT_DATOSVEHICULO = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';


	/**
	 * Array de URIs WSDL correspondiente a cada cliente
	 * @var array Array de clientes (uno para cada servicio)
	 */
	private $v_wsdl;


	/**
	 * Tiempo de espera mximo (en segundos) para acceder a un WSDL
	 * @access private
	 * @var integer Tiempo en segundos
	 */
	private $WSDLTimeOut;

	/**
	 *
	 * Array de clientes WEB
	 * @var array Array de clientes (uno para cada servicio)
	 */
	protected $v_clienteWS;


	/**
	 * Ruta del fichero de la clave privada
	 * @access private
	 * @var string
	 */
	private $keyFile='';

	/**
	 * Passphrase de la clave privada
	 * @access private
	 * @var string
	 */
	protected $passPhrase=null;

	/**
	 * Ruta del fichero del certificado
	 * @access private
	 * @var string
	 */
	private $certFile='';



	/**
	 * Registra si el modo DEBUG est activo o no
	 * @access private
	 * @var boolean
	 */
	private $_debugMode;

	/**
	 * Array asociativo donde se registra informacin de debug del cliente
	 * @access private
	 * @var array
	 */
	private static $_debugInfo;

	/**
	 * Array asociativo [nsCert|idApp] para trazabilidad PAI
	 * @access protected
	 * @var array
	 */
	protected $vTrazabilidad;


	/**
	 * idApp para la trazabilidad PAI
	 * @access protected
	 * @var string
	 */
	private $idApp;


	/**
	 * nsCert
	 * @access protected
	 * @var string
	 */
	private $nsCert;


	/**
	 * @var $userToken string Nombre de usuario a emplear en el userToken
	 * @access protected
	 * @var string
	 */
	protected $userToken = '';


	/**
	 * @var $passUserToken string Contrasea a emplear en el userToken
	 * @access protected
	 * @var string
	 */
	protected $passUserToken = '';


	/**
	 * @var $enableTrazabilidadPAI boolean Indica si genera y utiliza el idTrazabilidad
	 * @access protected
	 * @var boolean
	 */
	protected $enableTrazabilidadPAI = true;


	/**
	 * @var $enableWSSecurity boolean Indica si se utiliza WSSecurity
	 * @access protected
	 * @var boolean
	 */
	protected $enableWSSecurity = true;


	/**
	 * @var $enableXMLSecurityDSig boolean Indica si se enva el cuerpo del mensaje firmado con XMLDsig
	 * @access protected
	 * @var boolean
	 */
	protected $enableXMLSecurityDSig = false;

	/* ----------------------------------------------------------------------- */
	/* --------------------------- Mtodos pblicos -------------------------- */
	/* ----------------------------------------------------------------------- */


	/**
	 * Contructor. Recibe los parmetros necesarios para poner en marcha el cliente.
	 *
	 * El cliente puede llegar a conectarse a tres servicios distintos (mdulos),
	 * autenticacin, autorizacin y firma. Cada uno de ellos tiene su correspondiente WSDL.
	 * Las URI de los msimos se pasan como parmetros.
	 *
	 * @param  	array	$v_wsdl	Array asociativo [autentica,autoriza,firma] con las URLS a los WSDLs correspondientes a cada servicio
	 * @param  	string	$v_opciones	Array asociativo de opciones [enableWSSecurity, enableXMLSecurityDSig, enableTrazabilidadPAI, idAPP, certFile, keyFile, passPhrase].
	 * @access 	public
	 */
	public function __construct($v_wsdl, $v_opciones=null)
	{
		if (!is_array($v_wsdl))
		{
			throw new Exception (
					__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'.
					'v_wsdl debe ser un array asociativo (autenticacion,autorizacion,firma) con las URI de los WSDL'
					);
		}
		//Inicializamos el array asociativo de URIs WSDL
		$this->v_wsdl = $v_wsdl;

		//Inicializamos el array asociativo de clientes
		$this->v_clienteWS = array
		(
				self::KEYCLIENTE_AUTENTICA => null,
				self::KEYCLIENTE_AUTORIZA => null,
				self::KEYCLIENTE_CATASTRO => null,
				self::KEYCLIENTE_CATASTRO_BIENES => null,
				self::KEYCLIENTE_CSV => null,
				self::KEYCLIENTE_FIRMA => null,
				self::KEYCLIENTE_GDE => null,
				self::KEYCLIENTE_GDE2 => null,
				self::KEYCLIENTE_PF => null,
				self::KEYCLIENTE_PF_ADM => null,
				self::KEYCLIENTE_PF_MOD => null,
				self::KEYCLIENTE_SALT => null,
				self::KEYCLIENTE_GVLOGIN => null,
				self::KEYCLIENTE_REGDEPARTAMENTAL => null,
				self::KEYCLIENTE_DGT_CONDUCTORVEHICULOS => null,
				self::KEYCLIENTE_DGT_DATOSVEHICULO => null,
				self::KEYCLIENTE_AEAT_IRPF => null,
				self::KEYCLIENTE_DGP_CONSULTAIDENTIDAD => null,
				self::KEYCLIENTE_SS_VIDALABORAL => null,
				self::KEYCLIENTE_INE_VERIFICACIONRESIDENCIA => null
		);


		$this->nsCert = null;
		$this->enableWSSecurity = true;
		$this->enableXMLSecurityDSig = false;
		$this->enableTrazabilidadPAI = true;
		$this->idApp=null;

		if (is_array($v_opciones))
		{
			//Fijamos datos del certificado
			if (array_key_exists('certFile', $v_opciones))
			{
				$this->setCertFile($v_opciones['certFile']);
				$this->nsCert = $this->getCertificateSerial();
			}

			if (array_key_exists('keyFile', $v_opciones))
			{
				$this->setKeyFile($v_opciones['keyFile']);
			}

			if (array_key_exists('passPhrase', $v_opciones))
			{
				$this->setPassPhrase($v_opciones['passPhrase']);
			}

			if (array_key_exists('enableWSSecurity', $v_opciones))
			{
				$this->enableWSSecurity = $v_opciones['enableWSSecurity'] && true;
			}

			if (array_key_exists('enableXMLSecurityDSig', $v_opciones))
			{
				$this->enableXMLSecurityDSig = $v_opciones['enableXMLSecurityDSig'];
			}

			if (array_key_exists('userToken', $v_opciones))
			{
					$this->userToken = $v_opciones['userToken'];
			}

			if (array_key_exists('passUserToken', $v_opciones))
			{
					$this->passUserToken = $v_opciones['passUserToken'];
				}

			if (array_key_exists('enableTrazabilidadPAI', $v_opciones))
			{
				$this->enableTrazabilidadPAI = $v_opciones['enableTrazabilidadPAI'] && true;
			}


			if (array_key_exists('idApp', $v_opciones))
			{
				$this->idApp = $v_opciones['idApp'];
			}
		}//Fin opciones

		$this->vTrazabilidad = array
		(
				'idApp'	=>	$this->idApp,
				'nsCert'=>	$this->nsCert
		);

		/* Opciones de DEBUG y tiempos de espera */
		$this->setDebugMode(DEBUG);
		$this->_debugInfo = array();
		$this->WSDLTimeOut = 20;
	}//Fin __construct


	/**
	 * Factora. Devuelve el cliente del WS especificado. Recibe los parmetros necesarios para poner en marcha el cliente.
	 *
	 * El cliente puede llegar a conectarse a mltiples servicios distintos (mdulos).
	 * Cada uno de ellos tiene su correspondiente WSDL.
	 * Las URI de los mismos se pasan como parmetros.
	 *
	 * @param  	string		$wsID	Identificador del WS solicitado
	 * @param  	array		$v_wsdl	Array asociativo [autentica,autoriza,firma] con las URLS a los WSDLs correspondientes a cada servicio
	 * @param  	string		$v_opciones	Array asociativo con distintos datos [enableWSSecurity, enableXMLSecurityDSig, enableTrazabilidadPAI, idAPP, certFile, keyFile, passPhrase]. Los dos primeros son rutas a los ficheros PEM y el tercero una cadena de constrasea
	 * @return 	object		$wsClient Instancia del cliente WS solicitado, o NULL en su defecto
	 * @access 	public
	 */
	public static function makeWSClient($wsID, $v_wsdl, $v_opciones=null)
	{
		$wsClient = NULL;

		switch ($wsID)
		{
			//CATASTRO
			case self::KEYCLIENTE_CATASTRO:
			case self::KEYCLIENTE_CATASTRO_BIENES:
				require_once 'WS/CATASTRO/WSClientCatastro.php';
				require_once 'WS/CATASTRO/ComposerCatastro.php';
				require_once 'WS/CATASTRO/objCatastro.php';
				/** @var \WSCOMUN\CATASTRO\WSClientCatastro $wsClient */
				$wsClient = new WSClientCatastro($v_wsdl, $v_opciones);
			break;

			//CSV
			case self::KEYCLIENTE_CSV:
				require_once 'WS/CSV/WSClientCSV.php';
				/** @var \WSCOMUN\CSV\WSClientCSV $wsClient */
				$wsClient = new WSClientCSV($v_wsdl, $v_opciones);
			break;

			//SAFE
			case self::KEYCLIENTE_AUTENTICA:
				require_once 'WS/SAFE/WSClientAutentica.php';
				$wsClient = new WSClientAutentica($v_wsdl, $v_opciones);
			break;

			case self::KEYCLIENTE_AUTORIZA:
				require_once 'WS/SAFE/WSClientAutoriza.php';
				$wsClient = new WSClientAutoriza($v_wsdl, $v_opciones);
			break;

			case self::KEYCLIENTE_FIRMA:
				require_once 'WS/SAFE/WSClientFirma.php';
				$wsClient = new WSClientFirma($v_wsdl, $v_opciones);
			break;

			//GDE
			case self::KEYCLIENTE_GDE:
				require_once 'WS/GDE/WSClientGDE.php';
				/** @var \WSCOMUN\GDE\WSClientGDE $wsClient */
				$wsClient = new WSClientGDE($v_wsdl, $v_opciones);
			break;
			case self::KEYCLIENTE_GDE2:
				require_once 'WS/GDE/WSClientGDE2.php';
				require_once 'WS/GDE/ComposerGDE2.php';
				/** @var \WSCOMUN\GDE\WSClientGDE2 $wsClient */
				$wsClient = new WSClientGDE2($v_wsdl, $v_opciones);
			break;

			//SALT
			case self::KEYCLIENTE_SALT:
				require_once 'WS/SALT/WSClientSALT.php';
				/**  @var \WSCOMUN\SALT\WSClientSALT $wsClient */
				$wsClient = new WSClientSALT($v_wsdl, $v_opciones);
			break;

			//GVLOGIN
			case self::KEYCLIENTE_GVLOGIN:
				require_once 'WS/GVLOGIN/WSClientGVLogin.php';
				/** @var \WSCOMUN\GVLOGIN\WSClientGVLogin $wsClient */
				$wsClient = new WSClientGVLogin($v_wsdl, $v_opciones);
			break;

			//PORTAFIRMAS
			case self::KEYCLIENTE_PF:
			case self::KEYCLIENTE_PF_MOD:
			case self::KEYCLIENTE_PF_ADM:
				require_once 'WS/PORTAFIRMAS/WSClientPortafirmas.php';
				require_once 'WS/PORTAFIRMAS/ComposerPortafirmas.php';
				/** @var \WSCOMUN\PORTAFIRMAS\WSClientPortafirmas $wsClient */
				$wsClient = new WSClientPortafirmas($v_wsdl, $v_opciones);
			break;

			// REGISTRO DEPARTAMENTAL
			case self::KEYCLIENTE_REGDEPARTAMENTAL:
				require_once 'WS/REGDEPARTAMENTAL/WSClientRegDepartamental.php';
				require_once 'WS/REGDEPARTAMENTAL/ComposerRegDepartamental.php';
				/** @var \WSCOMUN\REGDEPARTAMENTAL\WSClientRegDepartamental $wsClient */
				$wsClient = new WSClientRegDepartamental($v_wsdl, $v_opciones);
			break;

			// DGT_CONDUCTORVEHICULOS
			case self::KEYCLIENTE_DGT_CONDUCTORVEHICULOS:
				require_once 'WS/DGT/CONDUCTORVEHICULOS/WSClientConductorVehiculos.php';
				require_once 'WS/DGT/CONDUCTORVEHICULOS/Composer.php';
				/** @var \WSCOMUN\CONDUCTORVEHICULOS\WSClientConductorVehiculos $wsClient */
				$wsClient = new WSClientConductorVehiculos($v_wsdl, $v_opciones);
			break;

			// DGT_DATOSVEHICULO
			case self::KEYCLIENTE_DGT_DATOSVEHICULO:
				require_once 'WS/DGT/DATOSVEHICULO/WSClientDatosVehiculo.php';
				require_once 'WS/DGT/DATOSVEHICULO/Composer.php';
				/** @var \WSCOMUN\DATOSVEHICULO\WSClientDatosVehiculo $wsClient */
				$wsClient = new WSClientDatosVehiculo($v_wsdl, $v_opciones);
			break;

			// AEAT_IRPF
			case self::KEYCLIENTE_AEAT_IRPF:
				require_once 'WS/AEAT/IRPF/WSClientIRPF.php';
				require_once 'WS/AEAT/IRPF/Composer.php';
				/** @var \WSCOMUN\AEAT\IRPF\WSClientIRPF $wsClient */
				$wsClient = new WSClientIRPF($v_wsdl, $v_opciones);
			break;

			// DGP_CONSULTAIDENTIDAD
			case self::KEYCLIENTE_DGP_CONSULTAIDENTIDAD:
				require_once 'WS/DGP/CONSULTAIDENTIDAD/WSClientDGPConsultaIdentidad.php';
				require_once 'WS/DGP/CONSULTAIDENTIDAD/Composer.php';
				/** @var \WSCOMUN\CONSULTAIDENTIDAD\WSClientDGPConsultaIdentidad $wsClient */
				$wsClient = new WSClientDGPConsultaIdentidad($v_wsdl, $v_opciones);
			break;
			
			// INE Verificacion residencia
			case self::KEYCLIENTE_INE_VERIFICACIONRESIDENCIA:
				require_once 'WS/INE/VERIFICACION_RESIDENCIA/WSClientVerificacionResidencia.php';
				require_once 'WS/INE/VERIFICACION_RESIDENCIA/Composer.php';
				/** @var \WSCOMUN\INE\VERIFICACION_RESIDENCIA\WSClientVerificacionResidencia $wsClient */
				$wsClient = new WSClientVerificacionResidencia($v_wsdl, $v_opciones);
			break;				
				
			// SS Vida Laboral
			case self::KEYCLIENTE_SS_VIDALABORAL:
				require_once 'WS/SS/VIDA_LABORAL/WSClientVidaLaboral.php';
				require_once 'WS/SS/VIDA_LABORAL/Composer.php';
				/** @var \WSCOMUN\SS\VIDA_LABORAL\WSClientVL $wsClient */
				$wsClient = new WSClientVidaLaboral($v_wsdl, $v_opciones);
			break;

			default:
				if (self::getDebugMode())
				{
					$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
					$mensaje.= "La clave $wsID no se corresponde con ningun tipo cliente.";
					throw new \Exception($mensaje);
				}
			break;
		}

		if (is_array($v_opciones))
		{
			//Fijamos datos del certificado
			if (array_key_exists('certFile', $v_opciones))
			{
				$wsClient->setCertFile($v_opciones['certFile']);
				$wsClient->nsCert = $wsClient->getCertificateSerial();
			}

			if (array_key_exists('keyFile', $v_opciones))
			{
				$wsClient->setKeyFile($v_opciones['keyFile']);
			}

			if (array_key_exists('passPhrase', $v_opciones))
			{
				$wsClient->setPassPhrase($v_opciones['passPhrase']);
			}

			if (array_key_exists('enableWSSecurity', $v_opciones))
			{
				$wsClient->enableWSSecurity = $v_opciones['enableWSSecurity'] && true;
			}

			if (array_key_exists('enableXMLSecurityDSig', $v_opciones))
			{
				$wsClient->enableXMLSecurityDSig = $v_opciones['enableXMLSecurityDSig'];
			}

			if (array_key_exists('userToken', $v_opciones))
			{
					$wsClient->userToken = $v_opciones['userToken'];
			}

			if (array_key_exists('passUserToken', $v_opciones))
			{
					$wsClient->passUserToken = $v_opciones['passUserToken'];
				}

			if (array_key_exists('enableTrazabilidadPAI', $v_opciones))
			{
				$wsClient->enableTrazabilidadPAI = $v_opciones['enableTrazabilidadPAI'] && true;
			}


			if (array_key_exists('idApp', $v_opciones))
			{
				$wsClient->idApp = $v_opciones['idApp'];
			}

			$wsClient->loadTracertPAI($v_opciones);
		}//Fin opciones

		return $wsClient;

	}//Fin makeWSClient


	/**
	 * Devuelve si est activado el modo DEBUG o no
	 *
	 * $return 	boolean	true si activo, falso en otro caso
	 * @access 	public
	 */
	public function getDebugMode()
	{
		return($this->_debugMode);
	}//getDebugMode


	/**
	 * Devuelve el array que contiene las trazas del DEBUG
	 *
	 * $return 	array	Array de cadenas (XML o no) con la informacion de traza
	 * @access 	public
	 */
	public function getDebugInfo()
	{
		return $this->_debugInfo;
	}//Fin getDebugInfo



	/**
	 * Fija el modo debug a TRUE. Implica opciones SoapClient [cache_wsdl = WSDL_CACHE_NONE]
	 *
	 * @param  	boolean	$activo	true/false para fijar activar el modo o no
	 * @access 	public
	 */
	public function setDebugMode($activo)
	{
		self::$MYSOAPOP_TRACE = true;//Necesario para tratar MTOM
		$this->_debugMode = $activo;
		if ($activo)
		{
			self::$MYSOAPOP_WSDL_CACHE = WSDL_CACHE_NONE;
		}
		else
		{
			self::$MYSOAPOP_WSDL_CACHE = WSDL_CACHE_MEMORY;//Slo en memoria
			$this->_debugInfo = array();//Vaciamos las trazas de debug
		}
	}//setDebugMode


	/**
	 * Aade informacin al Debug
	 *
	 * @param  	string	$info	Cadena con informacin de debug
	 * @access 	public
	 */
	public function addDebugInfo($info)
	{
		if (!empty($info))
		{
			$this->_debugInfo[] = $info;
		}

	}//addDebugInfo



	/**
	 * Recibe la ruta al fichero que contiene la clave (unicamente la clave y en formato PEM)
	 *
	 * @param  	string	$pathKey	Ruta al fichero que contiene la key
	 * @access 	public
	 */
	public function setKeyFile($pathKey)
	{
		$this->keyFile = $pathKey;
	}//setKeyFile


	/**
	 * Recibe la frase que permite utilizar la key
	 *
	 * @param  	string	$passphrase	Frase de paso para utilizar la clave (key)
	 * @access 	public
	 */
	public function setPassPhrase($passphrase)
	{
		$this->passPhrase = $passphrase;
	}//setPassPhrase


	/**
	 * Recibe la ruta al fichero que contiene el cetificado (unicamente el certificado y en formato PEM)
	 *
	 * @param  	string	$pathCert	Ruta al fichero que contiene el certificado
	 * @access 	public
	 */
	public function setCertFile($pathCert)
	{
		$this->certFile = $pathCert;
	}//setCertFile


	/**
	 * Fija el tiempo (segundos) de espera mximo para acceder a WSDL
	 *
	 * @param  	integer	$segs	Nmero de segundos
	 * @access 	public
	 */
	public function setWSDLTimeOut($segs)
	{
		$this->WSDLTimeOut = $segs;
	}//setCertFile



	/**
	 * Devuelve el nmero de serie del certificado leyndolo del propio fichero PEM
	 *
	 * @return	string	EL nmero de serie del certificado como cadena (en hexadecimal)
	 * @access	public
	 */
	public function getCertificateSerial($set=true)
	{
		if (empty($this->certFile))
		{
			throw new Exception('No se ha fijado valor para el certificado o el mismo no existe.');
		}

		$certFile = realpath($this->certFile);
		if ($certFile === false)
		{
			throw new Exception('No existe el fichero de cetificado: '.$this->certFile);
		}

		$cert = file_get_contents($certFile);
		if ($cert === false)
		{
			throw new Exception('No puede leerse el certificado : '.$certFile);
		}

		$v_certData = openssl_x509_parse($cert, true);
		$nsCert = strtoupper(self::numberBaseConvert($v_certData['serialNumber']));
		if ($set==true)
		{
			$this->nsCert = $nsCert;
		}
		return $nsCert;
	}//getCertificateSerial


	/**
	 * Devuelve un array asociativo con la informacin del certificado X509 de acuerdo a su formato
	 * @param 	string 	Formato [PEM, ]
	 * @return	array	Array asociativo con la informacin extrada del certificado
	 * @access	public
	 */
	public static function getCertificateInfo($ruta, $formato = null)
	{
		$certPath = null;
		$cert = null;
		$certContent = null;

		$certPath = realpath($ruta);

		$certContent = file_get_contents($certPath);
		if ($certContent === false)
		{
			throw new Exception (
					__CLASS__.':'.__METHOD__.'['.__FILE__.']-L'.__LINE__.
					'. El certificado no se encuentra en la ruta: '.$certPath
				);
		}

		if (empty($formato))
		{
			$formato = pathinfo($certPath, PATHINFO_EXTENSION);
		}

		$formato = trim(strtoupper($formato));
		switch ($formato)
		{
			case 'PK12':
			case 'P12':
				$v_certPEM = array();
				openssl_pkcs12_read($certContent, $v_certPEM, '');
				$cert = $v_certPEM['cert'];
			break;

			case 'PEM':
			case 'CRT':
				$cert = $certContent;
			break;
		}

		$v_certData = openssl_x509_parse($cert, true);
		if ($v_certData === false)
		{
			throw new Exception (
					__CLASS__.':'.__METHOD__.'['.__FILE__.']-L'.__LINE__.'.'.
					'El formato del certificado no se corresponde con '.$formato
					);
		}
		$v_certData['stringSerialNumber'] = strtoupper(self::numberBaseConvert($v_certData['serialNumber']));
		return $v_certData;
	}//getCertificateInfo

	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	stdClass	Devuelve el objeto equivalente
	 */
	public static function array2ObjectTree($array)
	{
		if (!is_array($array)) return;

		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = self::array2ObjectTree($value);
			}
			return $array;
		}
		$Object = new stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = self::array2ObjectTree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	object	$obj	Objeto a convertir
	 * @return	array	Devuelve el array asociativo equivalente al objeto
	 */
	public static function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = self::objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array





	/**
	 * Carga  informacin para cabeceras de trazabilidad en la PAI.
	 *
	 * @param  	array	$vTrazabilidadPAI	Array asociativo {idApp|[nsCert]} con el ID CATI de la aplicacin y el nmero de serie (opcional)
	 * @access 	public
	 */
	public function loadTracertPAI($vTrazabilidadPAI)
	{
		if (!is_array($vTrazabilidadPAI))
		{
			throw new Exception('Las opciones de trazabilidad deben ser un array asociativo [idApp, nsCert]');
		}

		if (array_key_exists('idApp', $vTrazabilidadPAI))
		{
			$this->idApp = $vTrazabilidadPAI['idApp'];
		}

		if (array_key_exists('nsCert', $vTrazabilidadPAI))
		{
			$this->nsCert = $vTrazabilidadPAI['nsCert'];
		}
	}//loadTracertPAI


	/**
	 * Activa el uso de WSSecurity
	 * @access 	public
	 */
	public function enableWSSecurity()
	{
		$this->enableWSSecurity = true;
	}//enableWSSecurity


	/**
	 * Desactiva el uso de WSSecurity
	 * @access 	public
	 */
	public function disableWSSecurity()
	{
		$this->enableWSSecurity = false;
	}//disableWSSecurity


	/**
	 * Activa el uso de la firma XMLDsig
	 * @access 	public
	 */
	public function enableXMLSecurityDSig()
	{
		$this->enableXMLSecurityDSig = true;
	}//enableXMLSecurityDSig


	/**
	 * Desactiva el uso de la firma XMLDsig
	 * @access 	public
	 */
	public function disableXMLSecurityDSig()
	{
		$this->enableXMLSecurityDSig = false;
	}//disableXMLSecurityDSig


	/**
	 * Activa el uso de la trazabilidad en la PAI
	 * @access 	public
	 */
	public function enableTrazabilidadPAI()
	{
		$this->enableTrazabilidadPAI = true;
	}//enableTrazabilidadPAI


	/**
	 * Desactiva el uso de la trazabilidad en la PAI
	 * @access 	public
	 */
	public function disableTrazabilidadPAI()
	{
		$this->enableTrazabilidadPAI = false;
	}//disableTrazabilidadPAI



	/**
	 * Devuelve la instancia del cliente WSSSoapClient recibido por parmetro, o null si no existe.
	 *
	 * @access	private
	 * @param  	string			$tipo	Cadena con los valores (autentica, autoriza, firma, GDE)
	 * @return	WSSSoapClient	Devuelve el objeto o null si error
	 */
	public function __getClient($tipo)
	{
		// Si esta vaco el tipo, nada
		if (empty($tipo)) return null;

		$tipo = trim(strtolower($tipo));
		try
		{
			$this->__clienteOn($tipo);

			if (!is_object($this->v_clienteWS[$tipo]))
				return null;
				else
					return ($this->v_clienteWS[$tipo]);
		}
		catch (Exception $e)
		{
			throw $e;
		}
	}// Fin __getClient




	/* ----------------------------------------------------------------------- */
	/* --------------------- Mtodos privados / protegidos ------------------- */
	/* ----------------------------------------------------------------------- */

	// --------------- Mtodos propios de la clase ---------------- */

	/**
	 * Construye una instancia del cliente SOAP correspondiente al tipo recibido por parmetro, o todos si nulo
	 *
	 * @access	protected
	 * @param  	string	$tipo	Cadena con los valores (autentica, autoriza, firma, GDE) o null si todos
	 * @param  	boolean	$trazabilidadPai	Booleano que indica si se debe incluir o no la trazabilidad de la PAI
	 *
	 */
	protected function __clienteOn($tipo, $trazabilidadPai=true, $opcionesClienteWS = null)
	{
		$vTiposCliente = array();
		if (!empty($tipo))
		{
			$tipo = trim(strtolower($tipo));

			if (array_key_exists($tipo, $this->v_clienteWS))
			{
				$vTiposCliente = array($tipo);
			}
			else
			{
				if ($this->getDebugMode())
				{
					$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'.' Tipo de cliente WS ('.$tipo.') no reconocido.');
				}
				throw new Exception (
						__CLASS__.':'.__METHOD__.'['.__FILE__.']-L'.__LINE__.'.'.
						'Tipo de cliente WS ('.$tipo.')  no reconocido'
						);
			}
		}

		$streamContext = stream_context_create (
				array (
						'ssl' => array (
								'verify_peer' => false,
								'verify_peer_name' => false,
								'allow_self_signed' => true
						)
						,'http'=>array (
								'user_agent' => 'WSSSoapClient',
								'timeout' => $this->WSDLTimeOut
						)
						,'https' => array (
								'timeout' => $this->WSDLTimeOut
						)
				)
				);

		if (!is_array($opcionesClienteWS))//Opciones SOAP por DEFECTO
		{
			/*
				Creamos un contexto para perfilar la conexin HTTP/HTTPS del cliente
				con las opciones siguientes facilitamos el acceso a WS servidor va HTTPS
			*/
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1,
					'stream_context' => $streamContext,
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE //NECESARIO PARA TRATAR MTOM
			);
		}
		else //Opciones que se sobrecargan por necesidad
		{
			$opcionesClienteWS['soap_version'] = SOAP_1_1;//v1.1
			if (!array_key_exists('stream_context', $opcionesClienteWS))
			{
				$opcionesClienteWS['stream_context'] = $streamContext;
			}
			$opcionesClienteWS['user_agent'] = 'WSSSoapClient';
			$opcionesClienteWS['exceptions'] = true;
			$opcionesClienteWS['cache_wsdl'] = self::$MYSOAPOP_WSDL_CACHE;
			$opcionesClienteWS['trace'] = self::$MYSOAPOP_TRACE; //NECESARIO PARA TRATAR MTOM
		}

		if ($this->getDebugMode())
		{
			$this->addDebugInfo("Opciones:\n ".print_r($opcionesClienteWS, true));
		}

		foreach ($vTiposCliente as $claveTipo)
		{
			if (is_object($this->v_clienteWS[$claveTipo])) continue;

			if ($this->getDebugMode())//Si est activado el DEBUG
			{
				$mensaje ='';
				$url = $this->v_wsdl[$claveTipo];
				//Comprobamos accesibilidad de la URL va FOPEN
				if (ini_get('allow_url_fopen') == true)//Si tenemos acceso a allow_url_open
				{
					$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
					$mensaje.='allow_url_fopen activo.';
					$this->addDebugInfo($mensaje);

					$fd = fopen($url, 'r', false, $streamContext);
					if ($fd==false)
					{
						$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
						$mensaje.='La URL '.$url.' NO PUEDE alcanzarse con fopen.';
						$this->addDebugInfo($mensaje);
					}
					else
					{
						$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
						$mensaje.='La URL se alcanza con fopen.';
					}
					fclose($fd);
				}
				else
				{
					$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
					$mensaje.='allow_url_fopen NO ACTIVO';
				}
				$this->addDebugInfo($mensaje);

				//Comprobamos accesibilidad a la URL va CURL
				$mensaje ='';
				if (function_exists('curl_version'))//Si tenemos acceso CURL utilizamos la extensin
				{
					$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
					$mensaje.='CURL activo.';
					$this->addDebugInfo($mensaje);
					$ch = curl_init();
					curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);//TRUE para comprobar los certificados
					curl_setopt($ch, CURLOPT_URL, $url);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
					curl_setopt($ch, CURLOPT_FAILONERROR, TRUE); // To fail silently if the HTTP code returned is greater than or equal to 400.
					curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE); // To follow any "Location: " header that the server sends as part of the HTTP header.
					curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE); // To automatically set the Referer: field in requests where it follows a Location: redirect.
					curl_setopt($ch, CURLOPT_TIMEOUT, 10); // The maximum number of seconds to allow cURL functions to execute.
					curl_setopt($ch, CURLOPT_MAXREDIRS, 5); // The maximum number of redirects
					curl_setopt($ch, CURLOPT_USERAGENT, 'WSSSoapClient');
					$output = curl_exec($ch);
					if($output === false)
					{
						$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
						$mensaje.='La URL '.$url.' NO PUEDE alcanzarse con CURL:';
						$msg='';while ($msg = openssl_error_string()!==false){$msg.= openssl_error_string();};
						$mensaje.="[$msg]";

					}
					else
					{
						$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
						$mensaje.='La URL '.$url.' se alcanza con CURL:';
					}
					curl_close($ch);
				}//Fin CURL
				$this->addDebugInfo($mensaje);

				//Comprobaciones de acceso con SimpleXML
				$mensaje ='';
				libxml_set_streams_context($streamContext);
				libxml_disable_entity_loader(false); //PErmite la carga de entidades externas AFECTA a SoapClient
				$xml = simplexml_load_file($url);
				if (!$xml)
				{
					$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
					$mensaje.='La URL '.$url.' NO PUEDE alcanzarse con SimpleXML:';
					$errors = libxml_get_errors();
					$msg='';while ($msg = openssl_error_string()!==false){$msg.='['.openssl_error_string().']';};
					foreach ($errors as $error)
					{
						$msg.='{[' . $error->level . '-' . $error->line . ',' . $error->column . ']: ' . $error->message . "}\n";
					}
					libxml_clear_errors();
					$mensaje.=$msg;
				}
				else
				{
					$mensaje ="\n".__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']';
					$mensaje.='La URL '.$url.' se alcanza con SimleXML';
				}
				$this->addDebugInfo($mensaje);
			}//Fin if debug

			try
			{
				/** @var WSSSoapClient $clienteWS */
				$clienteWS = new WSSSoapClient($this->v_wsdl[$claveTipo], $opcionesClienteWS);

				if ($this->enableWSSecurity == true)
				{
					$clienteWS->setCertFile($this->certFile); //Certificado (sin key) PEM
					$clienteWS->setKeyFile($this->keyFile); //Acceso al fichero .key extraido del pk12 formato PEM
					$clienteWS->setPassPhrase($this->passPhrase);
					$clienteWS->setUserToken($this->userToken, $this->passUserToken);
					$clienteWS->getCertificateSerial();
					$clienteWS->enableWSSecurity();
				}
				else
				{
					$clienteWS->disableWSSecurity();
				}

				if ($this->enableXMLSecurityDSig == true) {
					$clienteWS->setCertFile($this->certFile); //Certificado (sin key) PEM
					$clienteWS->setKeyFile($this->keyFile); //Acceso al fichero .key extraido del pk12 formato PEM
					$clienteWS->setPassPhrase($this->passPhrase);
					$clienteWS->getCertificateSerial();
					$clienteWS->enableXMLSecurityDSig();
				} else {
					$clienteWS->disableXMLSecurityDSig();
				}

				if ($this->enableTrazabilidadPAI)
				{
					$clienteWS->loadTracertPAI($this->vTrazabilidad);
				}
				$this->v_clienteWS[$claveTipo] = $clienteWS;
			}
			catch (Exception $e)
			{
				if ($this->getDebugMode())
				{
					$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
					if (is_object($clienteWS))
					{
						$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
						$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
						$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
						$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
					}
					else
					{
						$this->addDebugInfo("\n");
					}
				}
				throw $e;
			}
		}//Fin foreach
	}// Fin __clienteOn


	protected function tratarExcepcionEstandar($e, $clienteWS)
	{
		// En modo debug, guarda informacin de las comunicaciones
		if ($this->getDebugMode())
		{
			$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
			if (is_object($clienteWS))
			{
				$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
				$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
				$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
				$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
			}
		}

		// Comprueba si es una excepcion de PAI, y la lanza en dicho caso como excepcion especifica de PAI
		WSComunPAIException::tryToThrow($e);

		// Tratamiento estandar
		throw $e;
	}//tratarExcepcionEstandar



	/**
	 * Trata los mensajes MTOM y reconvierte la respuesta a fomato NO MOTOM. Si tiene anexos los codifica como B64
	 *
	 * Limitacin. El SoapClient de PHP no permite ver la cabecera HTTP original, sino solo la cabecera SOAP. Esto limita
	 * la forma de detectar contenido MTOM, que sigue el estandar Multipart
	 * @param array 	$response Respuesta original del WSService invocado (con contenido MTOM)
	 * @param string	$itemToReturn Elemento del cuerpo del RESPONSE a partir del cual se debe construir el array de la respuesta
	 * @return array Array asociativo de respuesta reconstrida a formato no MTOM
	 */
	protected function tratarMTOMEstandar($response, $itemToReturn = null)
	{
		//Comprobamos si existen anexos
		$mimeBoundary = '--MIME_Boundary';//Probamos con --MIME Boundary hasta mejora de deteccin
		$vBodyResponse = explode($mimeBoundary, $response); //Fraccionamos la respuesta.
		$numElementos = count($vBodyResponse);

		$srcData='';
		if ($numElementos<=1)
		{
			$mimeBoundary = '--uuid:';//Probamos de nuevo con --uuid hasta mejora de deteccin
			$vBodyResponse = explode($mimeBoundary, $response); //Fraccionamos la respuesta.
			$numElementos = count($vBodyResponse);
			$srcData = $response;
		}
		elseif ($numElementos>1)
		{
			$srcData = $vBodyResponse[1];
		}

		$vRespuesta = array();
		ini_set('pcre.backtrack_limit','100000000'); //Valor por defecto = 1000000 (aprox. 100KBytes)
		preg_match("/<[a-z]*:Envelope.*?>(.*)<\/[a-z]*:Envelope>/is", $srcData, $vRespuesta);
		if (preg_last_error()!=PREG_NO_ERROR)
		{
			//Si falta intentamos obtener el anexo con otro sistema
			$start = stripos($srcData, ':Envelope');
			$start = strripos($srcData, '<', $start - strlen($srcData));
			$end = strripos($srcData, ':Envelope>');
			$cadenaRespuesta = substr($srcData, $start, $end);
		}
		elseif (count($vRespuesta)<1)
		{
			throw new Exception('No puede ubicarse RESPONSE dentro de MTOM');
		}
		else
		{
			$cadenaRespuesta = $vRespuesta[0];
			unset($vRespuesta);
		}

		$dom = new DOMDocument('1.0');
		$dom->loadXML($cadenaRespuesta);//Cargamo el XML
		$xpath = new \DOMXpath($dom);
		$vNodoRespuesta = $xpath->query("/*[local-name()='Envelope']/*[local-name()='Body']/*/*[local-name()='respuesta']");
		$subStrXpath='';
		if (!empty($itemToReturn))
		{
			$subStrXpath = "/*[local-name()='{$itemToReturn}']";
		}
		$vNodoRespuesta = $xpath->query("/*[local-name()='Envelope']/*[local-name()='Body']/*".$subStrXpath);
		$nodoRespuesta = $vNodoRespuesta->item(0);

		if ($numElementos>0)
		{
			$oMimeParser = new WSCMimeParser();
			$oMime = $oMimeParser->decodeMTOM($vBodyResponse);
			unset($oMime->body);$oMime->body=null;gc_collect_cycles();

			$vNodoInclude = $xpath->query("//*[local-name()='Include']");
			foreach ($vNodoInclude as $nodoItem)//Recorremos los nodosXML include y sustituidmos por el contenido
			{
				$subIdBuscado = (string) $nodoItem->getAttribute('href');
				$subIdBuscado = urldecode($subIdBuscado);
				$idBuscado = '<'.substr($subIdBuscado, 4).'>';
				foreach ($oMime->parts as &$parte)
				{
					if ($idBuscado == ($parte->headers['content-id']))
					{
						if ( strtolower(substr($parte->mimetype, 0, 4)) !== 'text')//Si el tipo mime no es texto, convertimos a B64 por ser contenido binario
						{
							$parte->body = base64_encode($parte->body);
						}
						$textNode = $dom->createTextNode(($parte->body));
						$nodoItem->parentNode->replaceChild($textNode, $nodoItem);
					}
				}//Fin for partes
			}//Fin for nodos
		}
		return($this->xml_to_array($nodoRespuesta));
	}//tratarMTOMEstandar




	protected function xml_to_array(&$root)
	{
		$result = array();
		if ($root->hasAttributes())
		{
			$attrs = $root->attributes;
			foreach ($attrs as $attr)
			{
				$result['@attributes'][$attr->name] = $attr->value;
			}
		}
		if ($root->hasChildNodes())
		{
			$children = $root->childNodes;
			if ($children->length == 1)
			{
				$child = $children->item(0);
				if ($child->nodeType == XML_TEXT_NODE)
				{
					$result['_value'] = $child->nodeValue;
					return count($result) == 1 ? $result['_value'] : $result;
				}
			}
			$groups = array();
			foreach ($children as $child)
			{
				if (!isset($result[$child->nodeName]))
				{
					$result[$child->nodeName] = $this->xml_to_array($child);
				}
				else
				{
					if (!isset($groups[$child->nodeName]))
					{
						$result[$child->nodeName] = array($result[$child->nodeName]);
						$groups[$child->nodeName] = 1;
					}
					$result[$child->nodeName][] = $this->xml_to_array($child);
				}
			}
		}
		return $result;
	}//xml_to_array


	/**
	 * Recibe un string que representa un nmero, la base en la que se expresa y la base destino
	 *
	 * Utilizado debido a las limitaciones en ciertos entorno trabajando con nmeros grandes y donde puede
	 * no estar disponible la librera BC Math
	 *
	 * @param string $numstring representacin del nmero (como cadena)
	 * @param integer $frombase base origen (decimal por defecto)
	 * @param integer $tobase bse destino (hexadecimal por defecto)
	 * @return string
	 */
	public static function numberBaseConvert($numstring, $frombase=10, $tobase=16)
	{
		$chars = "0123456789abcdefghijklmnopqrstuvwxyz";
		$tostring = substr($chars, 0, $tobase);
		$length = strlen($numstring);
		$result = '';
		$number = array();
		for ($i = 0; $i < $length; $i++)
		{
			$number[$i] = strpos($chars, $numstring{$i});
		}
		do
		{
			$divide = 0;
			$newlen = 0;
			for ($i = 0; $i < $length; $i++)
			{
				$divide = $divide * $frombase + $number[$i];
				if ($divide >= $tobase)
				{
					$number[$newlen++] = (int)($divide / $tobase);
					$divide = $divide % $tobase;
				} elseif ($newlen > 0)
				{
					$number[$newlen++] = 0;
				}
			}
			$length = $newlen;
			$result = $tostring{$divide} . $result;
		} while ($newlen != 0);

		return $result;
	}//numberBaseConvert

	/**
	 * Trata de obtener la IP correcta del cliente
	 *
	 * @return string
	 */
	public static function getClientIP()
	{
		if (getenv('HTTP_CLIENT_IP'))
		{
			$ip = getenv('HTTP_CLIENT_IP');
		}
		else if(getenv('HTTP_X_FORWARDED_FOR'))
		{
			$ip = getenv('HTTP_X_FORWARDED_FOR');
		}
		else if (getenv('HTTP_X_FORWARDED'))
		{
			$ip = getenv('HTTP_X_FORWARDED');
		}
		else if(getenv('HTTP_FORWARDED_FOR'))
		{
			$ip = getenv('HTTP_FORWARDED_FOR');
		}
		else if(getenv('HTTP_FORWARDED'))
		{
			$ip = getenv('HTTP_FORWARDED');
		}
		else if(getenv('REMOTE_ADDR'))
		{
			$ip = getenv('REMOTE_ADDR');
		}
		else
		{
			$ip = 'UNKNOWN';
		}
		return $ip;
	}//Fin getClientIP




}//Fin WSComunFClient




/**
 *
 * WSComunPAIException
 *
 */

class WSComunPAIException extends Exception
{

	const ERROR_SERVICIO = '0101';
	const TIMESTAMP_INVALIDO = '0230';
	const ORGANISMO_NO_AUTORIZADO = '0301';
	const CERTIFICADO_CADUCADO = '0302';
	const CERTIFICADO_REVOCADO = '0303';
	const FIRMA_PETICION_NO_VALIDA = '0305';
	const PETICION_SIN_NODO_FIRMA = '0307';
	const ESTRUCURA_XML_NO_CORRESPONDE_A_ESQUEMA = '0401';
	const MENSAJE_XML_INVALIDO = '0403';
	const OPERACION_SOLICITADA_INCORRECTA = '0800';
	const FALTA_CABECERA_TRAZABILIDAD = '0807';
	const INFO_TRAZABILIDAD_INCOHERENTE = '0808';
	const ERROR_GENERAL_INDEFINIDO = '0904';


	private $CodigoEstado = '';
	private $CodigoEstadoSecundario = '';
	private $LiteralError = '';
	private $LiteralErrorSec = '';

	/**
	 * Devuelve el cdigo de estado
	 * @return string
	 */
	public function getCodigoEstado() {
		return $this->CodigoEstado;
	}

	/**
	 *
	 * @return string
	 */
	public function getCodigoEstadoSecundario() {
		return $this->CodigoEstadoSecundario;
	}

	/**
	 *
	 * @return string
	 */
	public function getLiteralError() {
		return $this->LiteralError;
	}

	/**
	 *
	 * @return string
	 */
	public function getLiteralErrorSec() {
		return $this->LiteralErrorSec;
	}



	public function __construct($soapFault) {
		// Extrae la informacion bsica del error
		$faultCode = intval($soapFault->detail->Atributos->Estado->CodigoEstado);
		$faultString = $soapFault->detail->Atributos->Estado->LiteralError;

		// asegrese de que todo est asignado apropiadamente
		parent::__construct($faultString, $faultCode, $soapFault);

		// Extrae informacin detallada del error
		$this->CodigoEstado = $soapFault->detail->Atributos->Estado->CodigoEstado;
		$this->CodigoEstadoSecundario = $soapFault->detail->Atributos->Estado->CodigoEstadoSecundario;
		$this->LiteralError = $soapFault->detail->Atributos->Estado->LiteralError;
		$this->LiteralErrorSec = $soapFault->detail->Atributos->Estado->LiteralErrorSec;

		$this->message.=' .[SOAP FAULT EXTENDED INFO]::';
		$this->message.='[CodEstado='.$this->CodigoEstado;
		$this->message.='][CodEstadoSecundario='.$this->CodigoEstadoSecundario;
		$this->message.='][LiteralError='.$this->LiteralError;
		$this->message.='][LiteralErrorSec='.$this->LiteralErrorSec.']';
	}

	public function __toString() {
		return __CLASS__ . ": [{$this->code}] {$this->message}\n";
	}



	/**
	 * Si la excepcion que se suministra cumple los criterios para ser una excepcion de la PAI, la transforma
	 * al tipo especifico, y la vuelve a lanzar como una WSComunPAIException
	 *
	 * @param	Exception	$e	Excepcion a comprobar
	 * @return	boolean		Si no se lanza excepcion, devuelve false
	 */
	public static function tryToThrow($e) {
		// Si es un SoapFault y su codigo es soap-env:PAI, asumimos que se trata de una excepcion especifica
		if (($e instanceof \SoapFault) && ($e->faultcode == 'soap-env:PAI')) {
			// Excepcion especifica detallada
			throw new WSComunPAIException($e);
		}
		return false;
	}

}

?>